/****************************************************************************
** Meta object code from reading C++ file 'dinputdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dinputdialog.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dinputdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget12DInputDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DInputDialog::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget12DInputDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DInputDialog",
        "textValueChanged",
        "",
        "text",
        "textValueSelected",
        "intValueChanged",
        "value",
        "intValueSelected",
        "doubleValueChanged",
        "doubleValueSelected",
        "cancelButtonClicked",
        "okButtonClicked",
        "comboBoxCurrentIndexChanged",
        "comboBoxCurrentIndex",
        "textAlertChanged",
        "textAlert",
        "setInputMode",
        "InputMode",
        "mode",
        "setTextValue",
        "setTextEchoMode",
        "QLineEdit::EchoMode",
        "setComboBoxEditable",
        "editable",
        "setComboBoxItems",
        "items",
        "setComboBoxCurrentIndex",
        "setIntValue",
        "setIntMinimum",
        "min",
        "setIntMaximum",
        "max",
        "setIntRange",
        "setIntStep",
        "step",
        "setDoubleValue",
        "setDoubleMinimum",
        "setDoubleMaximum",
        "setDoubleRange",
        "setDoubleDecimals",
        "decimals",
        "setOkButtonText",
        "setOkButtonEnabled",
        "enable",
        "setCancelButtonText",
        "setTextAlert",
        "inputMode",
        "textValue",
        "intValue",
        "doubleValue",
        "textEchoMode",
        "comboBoxEditable",
        "comboBoxItems",
        "intMinimum",
        "intMaximum",
        "intStep",
        "doubleMinimum",
        "doubleMaximum",
        "doubleDecimals",
        "okButtonText",
        "cancelButtonText"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textValueChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'textValueSelected'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'intValueChanged'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'intValueSelected'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'doubleValueChanged'
        QtMocHelpers::SignalData<void(double)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 6 },
        }}),
        // Signal 'doubleValueSelected'
        QtMocHelpers::SignalData<void(double)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 6 },
        }}),
        // Signal 'cancelButtonClicked'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'okButtonClicked'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'comboBoxCurrentIndexChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'textAlertChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setInputMode'
        QtMocHelpers::SlotData<void(enum InputMode)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setTextValue'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setTextEchoMode'
        QtMocHelpers::SlotData<void(QLineEdit::EchoMode)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 18 },
        }}),
        // Slot 'setComboBoxEditable'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setComboBoxItems'
        QtMocHelpers::SlotData<void(const QStringList &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 25 },
        }}),
        // Slot 'setComboBoxCurrentIndex'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'setIntValue'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'setIntMinimum'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'setIntMaximum'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Slot 'setIntRange'
        QtMocHelpers::SlotData<void(int, int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 31 },
        }}),
        // Slot 'setIntStep'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'setDoubleValue'
        QtMocHelpers::SlotData<void(double)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 6 },
        }}),
        // Slot 'setDoubleMinimum'
        QtMocHelpers::SlotData<void(double)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 29 },
        }}),
        // Slot 'setDoubleMaximum'
        QtMocHelpers::SlotData<void(double)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 31 },
        }}),
        // Slot 'setDoubleRange'
        QtMocHelpers::SlotData<void(double, double)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 29 }, { QMetaType::Double, 31 },
        }}),
        // Slot 'setDoubleDecimals'
        QtMocHelpers::SlotData<void(int)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Slot 'setOkButtonText'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setOkButtonEnabled'
        QtMocHelpers::SlotData<void(const bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'setCancelButtonText'
        QtMocHelpers::SlotData<void(const QString &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setTextAlert'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'inputMode'
        QtMocHelpers::PropertyData<enum InputMode>(46, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'textValue'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'intValue'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'doubleValue'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'textEchoMode'
        QtMocHelpers::PropertyData<QLineEdit::EchoMode>(50, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'comboBoxEditable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'comboBoxItems'
        QtMocHelpers::PropertyData<QStringList>(52, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'comboBoxCurrentIndex'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'intMinimum'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'intMaximum'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'intStep'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'doubleMinimum'
        QtMocHelpers::PropertyData<double>(56, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'doubleMaximum'
        QtMocHelpers::PropertyData<double>(57, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'doubleDecimals'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'okButtonText'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'cancelButtonText'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'textAlert'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DInputDialog, qt_meta_tag_ZN3Dtk6Widget12DInputDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk6Widget12DInputDialogE[] = {
    QMetaObject::SuperData::link<QLineEdit::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Widget::DInputDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<DDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DInputDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DInputDialogE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk6Widget12DInputDialogE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget12DInputDialogE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DInputDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DInputDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textValueChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->textValueSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->intValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->intValueSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->doubleValueChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->doubleValueSelected((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->cancelButtonClicked(); break;
        case 7: _t->okButtonClicked(); break;
        case 8: _t->comboBoxCurrentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->textAlertChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setInputMode((*reinterpret_cast<std::add_pointer_t<enum InputMode>>(_a[1]))); break;
        case 11: _t->setTextValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->setTextEchoMode((*reinterpret_cast<std::add_pointer_t<QLineEdit::EchoMode>>(_a[1]))); break;
        case 13: _t->setComboBoxEditable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setComboBoxItems((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 15: _t->setComboBoxCurrentIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->setIntValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setIntMinimum((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setIntMaximum((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->setIntRange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 20: _t->setIntStep((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->setDoubleValue((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 22: _t->setDoubleMinimum((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 23: _t->setDoubleMaximum((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 24: _t->setDoubleRange((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 25: _t->setDoubleDecimals((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->setOkButtonText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->setOkButtonEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->setCancelButtonText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->setTextAlert((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)(const QString & )>(_a, &DInputDialog::textValueChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)(const QString & )>(_a, &DInputDialog::textValueSelected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)(int )>(_a, &DInputDialog::intValueChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)(int )>(_a, &DInputDialog::intValueSelected, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)(double )>(_a, &DInputDialog::doubleValueChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)(double )>(_a, &DInputDialog::doubleValueSelected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)()>(_a, &DInputDialog::cancelButtonClicked, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)()>(_a, &DInputDialog::okButtonClicked, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)(int )>(_a, &DInputDialog::comboBoxCurrentIndexChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DInputDialog::*)(bool )>(_a, &DInputDialog::textAlertChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum InputMode*>(_v) = _t->inputMode(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->textValue(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->intValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->doubleValue(); break;
        case 4: *reinterpret_cast<QLineEdit::EchoMode*>(_v) = _t->textEchoMode(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isComboBoxEditable(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->comboBoxItems(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->comboBoxCurrentIndex(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->intMinimum(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->intMaximum(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->intStep(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->doubleMinimum(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->doubleMaximum(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->doubleDecimals(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->okButtonText(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->cancelButtonText(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isTextAlert(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInputMode(*reinterpret_cast<enum InputMode*>(_v)); break;
        case 1: _t->setTextValue(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setIntValue(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setDoubleValue(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setTextEchoMode(*reinterpret_cast<QLineEdit::EchoMode*>(_v)); break;
        case 5: _t->setComboBoxEditable(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setComboBoxItems(*reinterpret_cast<QStringList*>(_v)); break;
        case 7: _t->setComboBoxCurrentIndex(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setIntMinimum(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setIntMaximum(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setIntStep(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setDoubleMinimum(*reinterpret_cast<double*>(_v)); break;
        case 12: _t->setDoubleMaximum(*reinterpret_cast<double*>(_v)); break;
        case 13: _t->setDoubleDecimals(*reinterpret_cast<int*>(_v)); break;
        case 14: _t->setOkButtonText(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setCancelButtonText(*reinterpret_cast<QString*>(_v)); break;
        case 16: _t->setTextAlert(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DInputDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DInputDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DInputDialogE_t>.strings))
        return static_cast<void*>(this);
    return DDialog::qt_metacast(_clname);
}

int Dtk::Widget::DInputDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DInputDialog::textValueChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DInputDialog::textValueSelected(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Dtk::Widget::DInputDialog::intValueChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Dtk::Widget::DInputDialog::intValueSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Dtk::Widget::DInputDialog::doubleValueChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Dtk::Widget::DInputDialog::doubleValueSelected(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Dtk::Widget::DInputDialog::cancelButtonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Widget::DInputDialog::okButtonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Widget::DInputDialog::comboBoxCurrentIndexChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Dtk::Widget::DInputDialog::textAlertChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
