/****************************************************************************
** Meta object code from reading C++ file 'dtitlebar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dtitlebar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dtitlebar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget9DTitlebarE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DTitlebar::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget9DTitlebarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DTitlebar",
        "optionClicked",
        "",
        "doubleClicked",
        "mousePressed",
        "Qt::MouseButtons",
        "buttons",
        "mouseMoving",
        "Qt::MouseButton",
        "button",
        "setFixedHeight",
        "h",
        "setBackgroundTransparent",
        "transparent",
        "setSeparatorVisible",
        "visible",
        "setTitle",
        "title",
        "setIcon",
        "QIcon",
        "icon",
        "toggleWindowState",
        "setBlurBackground",
        "blurBackground",
        "showMenu",
        "_q_toggleWindowState",
        "_q_showMinimized",
        "_q_onTopWindowMotifHintsChanged",
        "_q_closeWindow",
        "_q_addDefaultMenuItems",
        "_q_helpActionTriggered",
        "_q_feedbackActionTriggered",
        "_q_aboutActionTriggered",
        "_q_quitActionTriggered",
        "_q_switchThemeActionTriggered",
        "QAction*",
        "_q_toolBarActionTriggered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'optionClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mousePressed'
        QtMocHelpers::SignalData<void(Qt::MouseButtons)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'mouseMoving'
        QtMocHelpers::SignalData<void(Qt::MouseButton)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setFixedHeight'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'setBackgroundTransparent'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'setSeparatorVisible'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setIcon'
        QtMocHelpers::SlotData<void(const QIcon &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'toggleWindowState'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBlurBackground'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'showMenu'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_toggleWindowState'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_showMinimized'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_onTopWindowMotifHintsChanged'
        QtMocHelpers::SlotData<void(quint32)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 2 },
        }}),
        // Slot '_q_closeWindow'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_addDefaultMenuItems'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_helpActionTriggered'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_feedbackActionTriggered'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_aboutActionTriggered'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_quitActionTriggered'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_switchThemeActionTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 2 },
        }}),
        // Slot '_q_toolBarActionTriggered'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'blurBackground'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DTitlebar, qt_meta_tag_ZN3Dtk6Widget9DTitlebarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DTitlebar::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget9DTitlebarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget9DTitlebarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget9DTitlebarE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DTitlebar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DTitlebar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->optionClicked(); break;
        case 1: _t->doubleClicked(); break;
        case 2: _t->mousePressed((*reinterpret_cast<std::add_pointer_t<Qt::MouseButtons>>(_a[1]))); break;
        case 3: _t->mouseMoving((*reinterpret_cast<std::add_pointer_t<Qt::MouseButton>>(_a[1]))); break;
        case 4: _t->setFixedHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setBackgroundTransparent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setSeparatorVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setIcon((*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[1]))); break;
        case 9: _t->toggleWindowState(); break;
        case 10: _t->setBlurBackground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->showMenu(); break;
        case 12: _t->d_func()->_q_toggleWindowState(); break;
        case 13: _t->d_func()->_q_showMinimized(); break;
        case 14: _t->d_func()->_q_onTopWindowMotifHintsChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 15: _t->d_func()->_q_closeWindow(); break;
        case 16: _t->d_func()->_q_addDefaultMenuItems(); break;
        case 17: _t->d_func()->_q_helpActionTriggered(); break;
        case 18: _t->d_func()->_q_feedbackActionTriggered(); break;
        case 19: _t->d_func()->_q_aboutActionTriggered(); break;
        case 20: _t->d_func()->_q_quitActionTriggered(); break;
        case 21: _t->d_func()->_q_switchThemeActionTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 22: _t->d_func()->_q_toolBarActionTriggered(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DTitlebar::*)()>(_a, &DTitlebar::optionClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTitlebar::*)()>(_a, &DTitlebar::doubleClicked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTitlebar::*)(Qt::MouseButtons )>(_a, &DTitlebar::mousePressed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTitlebar::*)(Qt::MouseButton )>(_a, &DTitlebar::mouseMoving, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->blurBackground(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBlurBackground(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DTitlebar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DTitlebar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget9DTitlebarE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QFrame::qt_metacast(_clname);
}

int Dtk::Widget::DTitlebar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DTitlebar::optionClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DTitlebar::doubleClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DTitlebar::mousePressed(Qt::MouseButtons _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Dtk::Widget::DTitlebar::mouseMoving(Qt::MouseButton _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
