/****************************************************************************
** Meta object code from reading C++ file 'dsimplelistview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dsimplelistview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dsimplelistview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget15DSimpleListViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DSimpleListView::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget15DSimpleListViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DSimpleListView",
        "rightClickItems",
        "",
        "QPoint",
        "pos",
        "QList<DSimpleListItem*>",
        "items",
        "changeColumnVisible",
        "index",
        "visible",
        "QList<bool>",
        "columnVisibles",
        "changeSortingStatus",
        "sortingOrder",
        "changeHoverItem",
        "DSimpleListItem*",
        "item",
        "columnIndex",
        "mouseHoverChanged",
        "oldItem",
        "newItem",
        "mousePressChanged",
        "mouseReleaseChanged",
        "hideScrollbar"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rightClickItems'
        QtMocHelpers::SignalData<void(QPoint, QList<DSimpleListItem*>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'changeColumnVisible'
        QtMocHelpers::SignalData<void(int, bool, QList<bool>)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Bool, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'changeSortingStatus'
        QtMocHelpers::SignalData<void(int, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Bool, 13 },
        }}),
        // Signal 'changeHoverItem'
        QtMocHelpers::SignalData<void(QPoint, DSimpleListItem *, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 15, 16 }, { QMetaType::Int, 17 },
        }}),
        // Signal 'mouseHoverChanged'
        QtMocHelpers::SignalData<void(DSimpleListItem *, DSimpleListItem *, int, QPoint)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 19 }, { 0x80000000 | 15, 20 }, { QMetaType::Int, 17 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'mousePressChanged'
        QtMocHelpers::SignalData<void(DSimpleListItem *, int, QPoint)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Int, 17 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'mouseReleaseChanged'
        QtMocHelpers::SignalData<void(DSimpleListItem *, int, QPoint)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Int, 17 }, { 0x80000000 | 3, 4 },
        }}),
        // Slot 'hideScrollbar'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DSimpleListView, qt_meta_tag_ZN3Dtk6Widget15DSimpleListViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DSimpleListView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DSimpleListViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DSimpleListViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget15DSimpleListViewE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DSimpleListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DSimpleListView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rightClickItems((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<DSimpleListItem*>>>(_a[2]))); break;
        case 1: _t->changeColumnVisible((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<bool>>>(_a[3]))); break;
        case 2: _t->changeSortingStatus((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->changeHoverItem((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DSimpleListItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->mouseHoverChanged((*reinterpret_cast<std::add_pointer_t<DSimpleListItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DSimpleListItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[4]))); break;
        case 5: _t->mousePressChanged((*reinterpret_cast<std::add_pointer_t<DSimpleListItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3]))); break;
        case 6: _t->mouseReleaseChanged((*reinterpret_cast<std::add_pointer_t<DSimpleListItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3]))); break;
        case 7: _t->hideScrollbar(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<DSimpleListItem*> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<bool> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DSimpleListItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DSimpleListItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DSimpleListItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DSimpleListItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DSimpleListView::*)(QPoint , QList<DSimpleListItem*> )>(_a, &DSimpleListView::rightClickItems, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DSimpleListView::*)(int , bool , QList<bool> )>(_a, &DSimpleListView::changeColumnVisible, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DSimpleListView::*)(int , bool )>(_a, &DSimpleListView::changeSortingStatus, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DSimpleListView::*)(QPoint , DSimpleListItem * , int )>(_a, &DSimpleListView::changeHoverItem, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DSimpleListView::*)(DSimpleListItem * , DSimpleListItem * , int , QPoint )>(_a, &DSimpleListView::mouseHoverChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DSimpleListView::*)(DSimpleListItem * , int , QPoint )>(_a, &DSimpleListView::mousePressChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DSimpleListView::*)(DSimpleListItem * , int , QPoint )>(_a, &DSimpleListView::mouseReleaseChanged, 6))
            return;
    }
}

const QMetaObject *Dtk::Widget::DSimpleListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DSimpleListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DSimpleListViewE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::DSimpleListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DSimpleListView::rightClickItems(QPoint _t1, QList<DSimpleListItem*> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Dtk::Widget::DSimpleListView::changeColumnVisible(int _t1, bool _t2, QList<bool> _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Dtk::Widget::DSimpleListView::changeSortingStatus(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Dtk::Widget::DSimpleListView::changeHoverItem(QPoint _t1, DSimpleListItem * _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void Dtk::Widget::DSimpleListView::mouseHoverChanged(DSimpleListItem * _t1, DSimpleListItem * _t2, int _t3, QPoint _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 5
void Dtk::Widget::DSimpleListView::mousePressChanged(DSimpleListItem * _t1, int _t2, QPoint _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Dtk::Widget::DSimpleListView::mouseReleaseChanged(DSimpleListItem * _t1, int _t2, QPoint _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
