/****************************************************************************
** Meta object code from reading C++ file 'dprintpreviewwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dprintpreviewwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dprintpreviewwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DPrintPreviewWidget_t {
    QByteArrayData data[24];
    char stringdata0[311];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DPrintPreviewWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DPrintPreviewWidget_t qt_meta_stringdata_Dtk__Widget__DPrintPreviewWidget = {
    {
QT_MOC_LITERAL(0, 0, 32), // "Dtk::Widget::DPrintPreviewWidget"
QT_MOC_LITERAL(1, 33, 14), // "paintRequested"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 9), // "DPrinter*"
QT_MOC_LITERAL(4, 59, 7), // "printer"
QT_MOC_LITERAL(5, 67, 12), // "QVector<int>"
QT_MOC_LITERAL(6, 80, 9), // "pageRange"
QT_MOC_LITERAL(7, 90, 14), // "previewChanged"
QT_MOC_LITERAL(8, 105, 18), // "currentPageChanged"
QT_MOC_LITERAL(9, 124, 4), // "page"
QT_MOC_LITERAL(10, 129, 10), // "totalPages"
QT_MOC_LITERAL(11, 140, 17), // "pagesCountChanged"
QT_MOC_LITERAL(12, 158, 5), // "pages"
QT_MOC_LITERAL(13, 164, 13), // "updatePreview"
QT_MOC_LITERAL(14, 178, 9), // "turnFront"
QT_MOC_LITERAL(15, 188, 8), // "turnBack"
QT_MOC_LITERAL(16, 197, 9), // "turnBegin"
QT_MOC_LITERAL(17, 207, 7), // "turnEnd"
QT_MOC_LITERAL(18, 215, 14), // "setCurrentPage"
QT_MOC_LITERAL(19, 230, 5), // "print"
QT_MOC_LITERAL(20, 236, 14), // "isSavedPicture"
QT_MOC_LITERAL(21, 251, 16), // "themeTypeChanged"
QT_MOC_LITERAL(22, 268, 32), // "DGuiApplicationHelper::ColorType"
QT_MOC_LITERAL(23, 301, 9) // "themeType"

    },
    "Dtk::Widget::DPrintPreviewWidget\0"
    "paintRequested\0\0DPrinter*\0printer\0"
    "QVector<int>\0pageRange\0previewChanged\0"
    "currentPageChanged\0page\0totalPages\0"
    "pagesCountChanged\0pages\0updatePreview\0"
    "turnFront\0turnBack\0turnBegin\0turnEnd\0"
    "setCurrentPage\0print\0isSavedPicture\0"
    "themeTypeChanged\0DGuiApplicationHelper::ColorType\0"
    "themeType"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DPrintPreviewWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   89,    2, 0x06 /* Public */,
       1,    2,   92,    2, 0x06 /* Public */,
       7,    0,   97,    2, 0x06 /* Public */,
       8,    1,   98,    2, 0x06 /* Public */,
      10,    1,  101,    2, 0x06 /* Public */,
      11,    1,  104,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    0,  107,    2, 0x0a /* Public */,
      14,    0,  108,    2, 0x0a /* Public */,
      15,    0,  109,    2, 0x0a /* Public */,
      16,    0,  110,    2, 0x0a /* Public */,
      17,    0,  111,    2, 0x0a /* Public */,
      18,    1,  112,    2, 0x0a /* Public */,
      19,    1,  115,    2, 0x0a /* Public */,
      19,    0,  118,    2, 0x2a /* Public | MethodCloned */,
      21,    1,  119,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   12,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 22,   23,

       0        // eod
};

void Dtk::Widget::DPrintPreviewWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DPrintPreviewWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->paintRequested((*reinterpret_cast< DPrinter*(*)>(_a[1]))); break;
        case 1: _t->paintRequested((*reinterpret_cast< DPrinter*(*)>(_a[1])),(*reinterpret_cast< const QVector<int>(*)>(_a[2]))); break;
        case 2: _t->previewChanged(); break;
        case 3: _t->currentPageChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->totalPages((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->pagesCountChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->updatePreview(); break;
        case 7: _t->turnFront(); break;
        case 8: _t->turnBack(); break;
        case 9: _t->turnBegin(); break;
        case 10: _t->turnEnd(); break;
        case 11: _t->setCurrentPage((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->print((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->print(); break;
        case 14: _t->themeTypeChanged((*reinterpret_cast< DGuiApplicationHelper::ColorType(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<int> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DPrintPreviewWidget::*)(DPrinter * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPrintPreviewWidget::paintRequested)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DPrintPreviewWidget::*)(DPrinter * , const QVector<int> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPrintPreviewWidget::paintRequested)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DPrintPreviewWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPrintPreviewWidget::previewChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DPrintPreviewWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPrintPreviewWidget::currentPageChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DPrintPreviewWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPrintPreviewWidget::totalPages)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DPrintPreviewWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPrintPreviewWidget::pagesCountChanged)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DPrintPreviewWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DFrame::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DPrintPreviewWidget.data,
    qt_meta_data_Dtk__Widget__DPrintPreviewWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DPrintPreviewWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DPrintPreviewWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DPrintPreviewWidget.stringdata0))
        return static_cast<void*>(this);
    return DFrame::qt_metacast(_clname);
}

int Dtk::Widget::DPrintPreviewWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DPrintPreviewWidget::paintRequested(DPrinter * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Widget::DPrintPreviewWidget::paintRequested(DPrinter * _t1, const QVector<int> & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Widget::DPrintPreviewWidget::previewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Widget::DPrintPreviewWidget::currentPageChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Dtk::Widget::DPrintPreviewWidget::totalPages(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Dtk::Widget::DPrintPreviewWidget::pagesCountChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
