/****************************************************************************
** Meta object code from reading C++ file 'danchors.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/danchors.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'danchors.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DAnchorsBase_t {
    QByteArrayData data[75];
    char stringdata0[1035];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DAnchorsBase_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DAnchorsBase_t qt_meta_stringdata_Dtk__Widget__DAnchorsBase = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Dtk::Widget::DAnchorsBase"
QT_MOC_LITERAL(1, 26, 14), // "enabledChanged"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 7), // "enabled"
QT_MOC_LITERAL(4, 50, 10), // "topChanged"
QT_MOC_LITERAL(5, 61, 18), // "const DAnchorInfo*"
QT_MOC_LITERAL(6, 80, 3), // "top"
QT_MOC_LITERAL(7, 84, 13), // "bottomChanged"
QT_MOC_LITERAL(8, 98, 6), // "bottom"
QT_MOC_LITERAL(9, 105, 11), // "leftChanged"
QT_MOC_LITERAL(10, 117, 4), // "left"
QT_MOC_LITERAL(11, 122, 12), // "rightChanged"
QT_MOC_LITERAL(12, 135, 5), // "right"
QT_MOC_LITERAL(13, 141, 23), // "horizontalCenterChanged"
QT_MOC_LITERAL(14, 165, 16), // "horizontalCenter"
QT_MOC_LITERAL(15, 182, 21), // "verticalCenterChanged"
QT_MOC_LITERAL(16, 204, 14), // "verticalCenter"
QT_MOC_LITERAL(17, 219, 11), // "fillChanged"
QT_MOC_LITERAL(18, 231, 8), // "QWidget*"
QT_MOC_LITERAL(19, 240, 4), // "fill"
QT_MOC_LITERAL(20, 245, 15), // "centerInChanged"
QT_MOC_LITERAL(21, 261, 8), // "centerIn"
QT_MOC_LITERAL(22, 270, 14), // "marginsChanged"
QT_MOC_LITERAL(23, 285, 7), // "margins"
QT_MOC_LITERAL(24, 293, 16), // "topMarginChanged"
QT_MOC_LITERAL(25, 310, 9), // "topMargin"
QT_MOC_LITERAL(26, 320, 19), // "bottomMarginChanged"
QT_MOC_LITERAL(27, 340, 12), // "bottomMargin"
QT_MOC_LITERAL(28, 353, 17), // "leftMarginChanged"
QT_MOC_LITERAL(29, 371, 10), // "leftMargin"
QT_MOC_LITERAL(30, 382, 18), // "rightMarginChanged"
QT_MOC_LITERAL(31, 401, 11), // "rightMargin"
QT_MOC_LITERAL(32, 413, 29), // "horizontalCenterOffsetChanged"
QT_MOC_LITERAL(33, 443, 22), // "horizontalCenterOffset"
QT_MOC_LITERAL(34, 466, 27), // "verticalCenterOffsetChanged"
QT_MOC_LITERAL(35, 494, 20), // "verticalCenterOffset"
QT_MOC_LITERAL(36, 515, 24), // "alignWhenCenteredChanged"
QT_MOC_LITERAL(37, 540, 17), // "alignWhenCentered"
QT_MOC_LITERAL(38, 558, 10), // "setEnabled"
QT_MOC_LITERAL(39, 569, 9), // "setAnchor"
QT_MOC_LITERAL(40, 579, 15), // "Qt::AnchorPoint"
QT_MOC_LITERAL(41, 595, 1), // "p"
QT_MOC_LITERAL(42, 597, 6), // "target"
QT_MOC_LITERAL(43, 604, 5), // "point"
QT_MOC_LITERAL(44, 610, 6), // "setTop"
QT_MOC_LITERAL(45, 617, 9), // "setBottom"
QT_MOC_LITERAL(46, 627, 7), // "setLeft"
QT_MOC_LITERAL(47, 635, 8), // "setRight"
QT_MOC_LITERAL(48, 644, 19), // "setHorizontalCenter"
QT_MOC_LITERAL(49, 664, 17), // "setVerticalCenter"
QT_MOC_LITERAL(50, 682, 7), // "setFill"
QT_MOC_LITERAL(51, 690, 11), // "setCenterIn"
QT_MOC_LITERAL(52, 702, 13), // "DAnchorsBase*"
QT_MOC_LITERAL(53, 716, 10), // "setMargins"
QT_MOC_LITERAL(54, 727, 12), // "setTopMargin"
QT_MOC_LITERAL(55, 740, 15), // "setBottomMargin"
QT_MOC_LITERAL(56, 756, 13), // "setLeftMargin"
QT_MOC_LITERAL(57, 770, 14), // "setRightMargin"
QT_MOC_LITERAL(58, 785, 25), // "setHorizontalCenterOffset"
QT_MOC_LITERAL(59, 811, 23), // "setVerticalCenterOffset"
QT_MOC_LITERAL(60, 835, 20), // "setAlignWhenCentered"
QT_MOC_LITERAL(61, 856, 3), // "arg"
QT_MOC_LITERAL(62, 860, 7), // "moveTop"
QT_MOC_LITERAL(63, 868, 10), // "moveBottom"
QT_MOC_LITERAL(64, 879, 8), // "moveLeft"
QT_MOC_LITERAL(65, 888, 9), // "moveRight"
QT_MOC_LITERAL(66, 898, 20), // "moveHorizontalCenter"
QT_MOC_LITERAL(67, 919, 18), // "moveVerticalCenter"
QT_MOC_LITERAL(68, 938, 10), // "moveCenter"
QT_MOC_LITERAL(69, 949, 14), // "updateVertical"
QT_MOC_LITERAL(70, 964, 16), // "updateHorizontal"
QT_MOC_LITERAL(71, 981, 10), // "updateFill"
QT_MOC_LITERAL(72, 992, 14), // "updateCenterIn"
QT_MOC_LITERAL(73, 1007, 7), // "anchors"
QT_MOC_LITERAL(74, 1015, 19) // "const DAnchorsBase*"

    },
    "Dtk::Widget::DAnchorsBase\0enabledChanged\0"
    "\0enabled\0topChanged\0const DAnchorInfo*\0"
    "top\0bottomChanged\0bottom\0leftChanged\0"
    "left\0rightChanged\0right\0horizontalCenterChanged\0"
    "horizontalCenter\0verticalCenterChanged\0"
    "verticalCenter\0fillChanged\0QWidget*\0"
    "fill\0centerInChanged\0centerIn\0"
    "marginsChanged\0margins\0topMarginChanged\0"
    "topMargin\0bottomMarginChanged\0"
    "bottomMargin\0leftMarginChanged\0"
    "leftMargin\0rightMarginChanged\0rightMargin\0"
    "horizontalCenterOffsetChanged\0"
    "horizontalCenterOffset\0"
    "verticalCenterOffsetChanged\0"
    "verticalCenterOffset\0alignWhenCenteredChanged\0"
    "alignWhenCentered\0setEnabled\0setAnchor\0"
    "Qt::AnchorPoint\0p\0target\0point\0setTop\0"
    "setBottom\0setLeft\0setRight\0"
    "setHorizontalCenter\0setVerticalCenter\0"
    "setFill\0setCenterIn\0DAnchorsBase*\0"
    "setMargins\0setTopMargin\0setBottomMargin\0"
    "setLeftMargin\0setRightMargin\0"
    "setHorizontalCenterOffset\0"
    "setVerticalCenterOffset\0setAlignWhenCentered\0"
    "arg\0moveTop\0moveBottom\0moveLeft\0"
    "moveRight\0moveHorizontalCenter\0"
    "moveVerticalCenter\0moveCenter\0"
    "updateVertical\0updateHorizontal\0"
    "updateFill\0updateCenterIn\0anchors\0"
    "const DAnchorsBase*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DAnchorsBase[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      54,   14, // methods
      19,  454, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      17,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  284,    2, 0x06 /* Public */,
       4,    1,  287,    2, 0x06 /* Public */,
       7,    1,  290,    2, 0x06 /* Public */,
       9,    1,  293,    2, 0x06 /* Public */,
      11,    1,  296,    2, 0x06 /* Public */,
      13,    1,  299,    2, 0x06 /* Public */,
      15,    1,  302,    2, 0x06 /* Public */,
      17,    1,  305,    2, 0x06 /* Public */,
      20,    1,  308,    2, 0x06 /* Public */,
      22,    1,  311,    2, 0x06 /* Public */,
      24,    1,  314,    2, 0x06 /* Public */,
      26,    1,  317,    2, 0x06 /* Public */,
      28,    1,  320,    2, 0x06 /* Public */,
      30,    1,  323,    2, 0x06 /* Public */,
      32,    1,  326,    2, 0x06 /* Public */,
      34,    1,  329,    2, 0x06 /* Public */,
      36,    1,  332,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      38,    1,  335,    2, 0x0a /* Public */,
      39,    3,  338,    2, 0x0a /* Public */,
      44,    1,  345,    2, 0x0a /* Public */,
      45,    1,  348,    2, 0x0a /* Public */,
      46,    1,  351,    2, 0x0a /* Public */,
      47,    1,  354,    2, 0x0a /* Public */,
      48,    1,  357,    2, 0x0a /* Public */,
      49,    1,  360,    2, 0x0a /* Public */,
      50,    1,  363,    2, 0x0a /* Public */,
      51,    1,  366,    2, 0x0a /* Public */,
      50,    1,  369,    2, 0x0a /* Public */,
      51,    1,  372,    2, 0x0a /* Public */,
      53,    1,  375,    2, 0x0a /* Public */,
      54,    1,  378,    2, 0x0a /* Public */,
      55,    1,  381,    2, 0x0a /* Public */,
      56,    1,  384,    2, 0x0a /* Public */,
      57,    1,  387,    2, 0x0a /* Public */,
      58,    1,  390,    2, 0x0a /* Public */,
      59,    1,  393,    2, 0x0a /* Public */,
      60,    1,  396,    2, 0x0a /* Public */,
      44,    2,  399,    2, 0x0a /* Public */,
      45,    2,  404,    2, 0x0a /* Public */,
      46,    2,  409,    2, 0x0a /* Public */,
      47,    2,  414,    2, 0x0a /* Public */,
      48,    2,  419,    2, 0x0a /* Public */,
      49,    2,  424,    2, 0x0a /* Public */,
      62,    1,  429,    2, 0x0a /* Public */,
      63,    1,  432,    2, 0x0a /* Public */,
      64,    1,  435,    2, 0x0a /* Public */,
      65,    1,  438,    2, 0x0a /* Public */,
      66,    1,  441,    2, 0x0a /* Public */,
      67,    1,  444,    2, 0x0a /* Public */,
      68,    1,  447,    2, 0x0a /* Public */,
      69,    0,  450,    2, 0x08 /* Private */,
      70,    0,  451,    2, 0x08 /* Private */,
      71,    0,  452,    2, 0x08 /* Private */,
      72,    0,  453,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 5,    8,
    QMetaType::Void, 0x80000000 | 5,   10,
    QMetaType::Void, 0x80000000 | 5,   12,
    QMetaType::Void, 0x80000000 | 5,   14,
    QMetaType::Void, 0x80000000 | 5,   16,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, 0x80000000 | 18,   21,
    QMetaType::Void, QMetaType::Int,   23,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, QMetaType::Int,   29,
    QMetaType::Void, QMetaType::Int,   31,
    QMetaType::Void, QMetaType::Int,   33,
    QMetaType::Void, QMetaType::Int,   35,
    QMetaType::Void, QMetaType::Bool,   37,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Bool, 0x80000000 | 40, 0x80000000 | 18, 0x80000000 | 40,   41,   42,   43,
    QMetaType::Bool, 0x80000000 | 5,    6,
    QMetaType::Bool, 0x80000000 | 5,    8,
    QMetaType::Bool, 0x80000000 | 5,   10,
    QMetaType::Bool, 0x80000000 | 5,   12,
    QMetaType::Bool, 0x80000000 | 5,   14,
    QMetaType::Bool, 0x80000000 | 5,   16,
    QMetaType::Bool, 0x80000000 | 18,   19,
    QMetaType::Bool, 0x80000000 | 18,   21,
    QMetaType::Bool, 0x80000000 | 52,   19,
    QMetaType::Bool, 0x80000000 | 52,   21,
    QMetaType::Void, QMetaType::Int,   23,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, QMetaType::Int,   29,
    QMetaType::Void, QMetaType::Int,   31,
    QMetaType::Void, QMetaType::Int,   33,
    QMetaType::Void, QMetaType::Int,   35,
    QMetaType::Void, QMetaType::Bool,   37,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 40,   61,   43,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 40,   61,   43,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 40,   61,   43,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 40,   61,   43,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 40,   61,   43,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 40,   61,   43,
    QMetaType::Void, QMetaType::Int,   61,
    QMetaType::Void, QMetaType::Int,   61,
    QMetaType::Void, QMetaType::Int,   61,
    QMetaType::Void, QMetaType::Int,   61,
    QMetaType::Void, QMetaType::Int,   61,
    QMetaType::Void, QMetaType::Int,   61,
    QMetaType::Void, QMetaType::QPoint,   61,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      42, 0x80000000 | 18, 0x00095409,
       3, QMetaType::Bool, 0x00495103,
      73, 0x80000000 | 74, 0x00095009,
       6, 0x80000000 | 5, 0x0049510b,
       8, 0x80000000 | 5, 0x0049510b,
      10, 0x80000000 | 5, 0x0049510b,
      12, 0x80000000 | 5, 0x0049510b,
      14, 0x80000000 | 5, 0x0049510b,
      16, 0x80000000 | 5, 0x0049510b,
      19, 0x80000000 | 18, 0x0049510b,
      21, 0x80000000 | 18, 0x0049510b,
      23, QMetaType::Int, 0x00495103,
      25, QMetaType::Int, 0x00495103,
      27, QMetaType::Int, 0x00495103,
      29, QMetaType::Int, 0x00495103,
      31, QMetaType::Int, 0x00495103,
      33, QMetaType::Int, 0x00495103,
      35, QMetaType::Int, 0x00495103,
      37, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       0,
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
      11,
      12,
      13,
      14,
      15,
      16,

       0        // eod
};

void Dtk::Widget::DAnchorsBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DAnchorsBase *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->enabledChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->topChanged((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1]))); break;
        case 2: _t->bottomChanged((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1]))); break;
        case 3: _t->leftChanged((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1]))); break;
        case 4: _t->rightChanged((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1]))); break;
        case 5: _t->horizontalCenterChanged((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1]))); break;
        case 6: _t->verticalCenterChanged((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1]))); break;
        case 7: _t->fillChanged((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 8: _t->centerInChanged((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 9: _t->marginsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->topMarginChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->bottomMarginChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->leftMarginChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->rightMarginChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->horizontalCenterOffsetChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->verticalCenterOffsetChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->alignWhenCenteredChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->setEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: { bool _r = _t->setAnchor((*reinterpret_cast< const Qt::AnchorPoint(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2])),(*reinterpret_cast< const Qt::AnchorPoint(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->setTop((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->setBottom((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->setLeft((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->setRight((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->setHorizontalCenter((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->setVerticalCenter((*reinterpret_cast< const DAnchorInfo*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->setFill((*reinterpret_cast< QWidget*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->setCenterIn((*reinterpret_cast< QWidget*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->setFill((*reinterpret_cast< DAnchorsBase*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->setCenterIn((*reinterpret_cast< DAnchorsBase*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->setMargins((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 30: _t->setTopMargin((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: _t->setBottomMargin((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 32: _t->setLeftMargin((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 33: _t->setRightMargin((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 34: _t->setHorizontalCenterOffset((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 35: _t->setVerticalCenterOffset((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 36: _t->setAlignWhenCentered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 37: _t->setTop((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::AnchorPoint(*)>(_a[2]))); break;
        case 38: _t->setBottom((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::AnchorPoint(*)>(_a[2]))); break;
        case 39: _t->setLeft((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::AnchorPoint(*)>(_a[2]))); break;
        case 40: _t->setRight((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::AnchorPoint(*)>(_a[2]))); break;
        case 41: _t->setHorizontalCenter((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::AnchorPoint(*)>(_a[2]))); break;
        case 42: _t->setVerticalCenter((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::AnchorPoint(*)>(_a[2]))); break;
        case 43: _t->moveTop((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 44: _t->moveBottom((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 45: _t->moveLeft((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 46: _t->moveRight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 47: _t->moveHorizontalCenter((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 48: _t->moveVerticalCenter((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 49: _t->moveCenter((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 50: _t->updateVertical(); break;
        case 51: _t->updateHorizontal(); break;
        case 52: _t->updateFill(); break;
        case 53: _t->updateCenterIn(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DAnchorsBase* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DAnchorsBase* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DAnchorsBase::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::enabledChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(const DAnchorInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::topChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(const DAnchorInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::bottomChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(const DAnchorInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::leftChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(const DAnchorInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::rightChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(const DAnchorInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::horizontalCenterChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(const DAnchorInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::verticalCenterChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(QWidget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::fillChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(QWidget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::centerInChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::marginsChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::topMarginChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::bottomMarginChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::leftMarginChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::rightMarginChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::horizontalCenterOffsetChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::verticalCenterOffsetChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (DAnchorsBase::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAnchorsBase::alignWhenCenteredChanged)) {
                *result = 16;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
        case 9:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DAnchorsBase *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QWidget**>(_v) = _t->target(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->enabled(); break;
        case 2: *reinterpret_cast< const DAnchorsBase**>(_v) = _t->anchors(); break;
        case 3: *reinterpret_cast< const DAnchorInfo**>(_v) = _t->top(); break;
        case 4: *reinterpret_cast< const DAnchorInfo**>(_v) = _t->bottom(); break;
        case 5: *reinterpret_cast< const DAnchorInfo**>(_v) = _t->left(); break;
        case 6: *reinterpret_cast< const DAnchorInfo**>(_v) = _t->right(); break;
        case 7: *reinterpret_cast< const DAnchorInfo**>(_v) = _t->horizontalCenter(); break;
        case 8: *reinterpret_cast< const DAnchorInfo**>(_v) = _t->verticalCenter(); break;
        case 9: *reinterpret_cast< QWidget**>(_v) = _t->fill(); break;
        case 10: *reinterpret_cast< QWidget**>(_v) = _t->centerIn(); break;
        case 11: *reinterpret_cast< int*>(_v) = _t->margins(); break;
        case 12: *reinterpret_cast< int*>(_v) = _t->topMargin(); break;
        case 13: *reinterpret_cast< int*>(_v) = _t->bottomMargin(); break;
        case 14: *reinterpret_cast< int*>(_v) = _t->leftMargin(); break;
        case 15: *reinterpret_cast< int*>(_v) = _t->rightMargin(); break;
        case 16: *reinterpret_cast< int*>(_v) = _t->horizontalCenterOffset(); break;
        case 17: *reinterpret_cast< int*>(_v) = _t->verticalCenterOffset(); break;
        case 18: *reinterpret_cast< bool*>(_v) = _t->alignWhenCentered(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DAnchorsBase *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setTop(*reinterpret_cast< const DAnchorInfo**>(_v)); break;
        case 4: _t->setBottom(*reinterpret_cast< const DAnchorInfo**>(_v)); break;
        case 5: _t->setLeft(*reinterpret_cast< const DAnchorInfo**>(_v)); break;
        case 6: _t->setRight(*reinterpret_cast< const DAnchorInfo**>(_v)); break;
        case 7: _t->setHorizontalCenter(*reinterpret_cast< const DAnchorInfo**>(_v)); break;
        case 8: _t->setVerticalCenter(*reinterpret_cast< const DAnchorInfo**>(_v)); break;
        case 9: _t->setFill(*reinterpret_cast< QWidget**>(_v)); break;
        case 10: _t->setCenterIn(*reinterpret_cast< QWidget**>(_v)); break;
        case 11: _t->setMargins(*reinterpret_cast< int*>(_v)); break;
        case 12: _t->setTopMargin(*reinterpret_cast< int*>(_v)); break;
        case 13: _t->setBottomMargin(*reinterpret_cast< int*>(_v)); break;
        case 14: _t->setLeftMargin(*reinterpret_cast< int*>(_v)); break;
        case 15: _t->setRightMargin(*reinterpret_cast< int*>(_v)); break;
        case 16: _t->setHorizontalCenterOffset(*reinterpret_cast< int*>(_v)); break;
        case 17: _t->setVerticalCenterOffset(*reinterpret_cast< int*>(_v)); break;
        case 18: _t->setAlignWhenCentered(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DAnchorsBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DAnchorsBase.data,
    qt_meta_data_Dtk__Widget__DAnchorsBase,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DAnchorsBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DAnchorsBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DAnchorsBase.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Widget::DAnchorsBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 19;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DAnchorsBase::enabledChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Widget::DAnchorsBase::topChanged(const DAnchorInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Widget::DAnchorsBase::bottomChanged(const DAnchorInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Widget::DAnchorsBase::leftChanged(const DAnchorInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Dtk::Widget::DAnchorsBase::rightChanged(const DAnchorInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Dtk::Widget::DAnchorsBase::horizontalCenterChanged(const DAnchorInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Dtk::Widget::DAnchorsBase::verticalCenterChanged(const DAnchorInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Dtk::Widget::DAnchorsBase::fillChanged(QWidget * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Dtk::Widget::DAnchorsBase::centerInChanged(QWidget * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Dtk::Widget::DAnchorsBase::marginsChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Dtk::Widget::DAnchorsBase::topMarginChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Dtk::Widget::DAnchorsBase::bottomMarginChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Dtk::Widget::DAnchorsBase::leftMarginChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Dtk::Widget::DAnchorsBase::rightMarginChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Dtk::Widget::DAnchorsBase::horizontalCenterOffsetChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Dtk::Widget::DAnchorsBase::verticalCenterOffsetChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Dtk::Widget::DAnchorsBase::alignWhenCenteredChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
