/****************************************************************************
** Meta object code from reading C++ file 'dbusmpris.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/widgets/private/mpris/dbusmpris.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusmpris.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DBusMPRISE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusMPRIS::qt_create_metaobjectdata<qt_meta_tag_ZN9DBusMPRISE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusMPRIS",
        "Seeked",
        "",
        "Position",
        "CanControlChanged",
        "value",
        "CanShowInUIChanged",
        "CanGoNextChanged",
        "CanGoPreviousChanged",
        "CanPauseChanged",
        "CanPlayChanged",
        "CanSeekChanged",
        "LoopStatusChanged",
        "MaximumRateChanged",
        "MetadataChanged",
        "QVariantMap",
        "MinimumRateChanged",
        "PlaybackStatusChanged",
        "PositionChanged",
        "RateChanged",
        "ShuffleChanged",
        "VolumeChanged",
        "__propertyChanged__",
        "QDBusMessage",
        "msg",
        "Next",
        "QDBusPendingReply<>",
        "OpenUri",
        "Uri",
        "Pause",
        "Play",
        "PlayPause",
        "Previous",
        "Seek",
        "Offset",
        "SetPosition",
        "QDBusObjectPath",
        "TrackId",
        "Stop",
        "CanControl",
        "CanShowInUI",
        "CanGoNext",
        "CanGoPrevious",
        "CanPause",
        "CanPlay",
        "CanSeek",
        "LoopStatus",
        "MaximumRate",
        "Metadata",
        "MinimumRate",
        "PlaybackStatus",
        "Rate",
        "Shuffle",
        "Volume"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Seeked'
        QtMocHelpers::SignalData<void(qlonglong)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Signal 'CanControlChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'CanShowInUIChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'CanGoNextChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'CanGoPreviousChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'CanPauseChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'CanPlayChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'CanSeekChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'LoopStatusChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'MaximumRateChanged'
        QtMocHelpers::SignalData<void(double)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 5 },
        }}),
        // Signal 'MetadataChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 5 },
        }}),
        // Signal 'MinimumRateChanged'
        QtMocHelpers::SignalData<void(double)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 5 },
        }}),
        // Signal 'PlaybackStatusChanged'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'PositionChanged'
        QtMocHelpers::SignalData<void(qlonglong)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 5 },
        }}),
        // Signal 'RateChanged'
        QtMocHelpers::SignalData<void(double)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 5 },
        }}),
        // Signal 'ShuffleChanged'
        QtMocHelpers::SignalData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'VolumeChanged'
        QtMocHelpers::SignalData<void(double)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 5 },
        }}),
        // Slot '__propertyChanged__'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'Next'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(25, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'OpenUri'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'Pause'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(29, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'Play'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(30, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'PlayPause'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(31, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'Previous'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(32, 2, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'Seek'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong)>(33, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::LongLong, 34 },
        }}),
        // Slot 'SetPosition'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, qlonglong)>(35, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { 0x80000000 | 36, 37 }, { QMetaType::LongLong, 3 },
        }}),
        // Slot 'Stop'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(38, 2, QMC::AccessPublic, 0x80000000 | 26),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CanControl'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'CanShowInUI'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'CanGoNext'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'CanGoPrevious'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'CanPause'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'CanPlay'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'CanSeek'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'LoopStatus'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'MaximumRate'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags, 9),
        // property 'Metadata'
        QtMocHelpers::PropertyData<QVariantMap>(48, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'MinimumRate'
        QtMocHelpers::PropertyData<double>(49, QMetaType::Double, QMC::DefaultPropertyFlags, 11),
        // property 'PlaybackStatus'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'Position'
        QtMocHelpers::PropertyData<qlonglong>(3, QMetaType::LongLong, QMC::DefaultPropertyFlags, 13),
        // property 'Rate'
        QtMocHelpers::PropertyData<double>(51, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'Shuffle'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'Volume'
        QtMocHelpers::PropertyData<double>(53, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusMPRIS, qt_meta_tag_ZN9DBusMPRISE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusMPRIS::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DBusMPRISE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DBusMPRISE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DBusMPRISE_t>.metaTypes,
    nullptr
} };

void DBusMPRIS::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusMPRIS *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Seeked((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 1: _t->CanControlChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->CanShowInUIChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->CanGoNextChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->CanGoPreviousChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->CanPauseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->CanPlayChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->CanSeekChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->LoopStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->MaximumRateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->MetadataChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 11: _t->MinimumRateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 12: _t->PlaybackStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->PositionChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 14: _t->RateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->ShuffleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->VolumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->__propertyChanged__((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 18: { QDBusPendingReply<> _r = _t->Next();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->OpenUri((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->Pause();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->Play();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->PlayPause();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->Previous();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->Seek((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->SetPosition((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->Stop();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(qlonglong )>(_a, &DBusMPRIS::Seeked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(bool )>(_a, &DBusMPRIS::CanControlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(bool )>(_a, &DBusMPRIS::CanShowInUIChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(bool )>(_a, &DBusMPRIS::CanGoNextChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(bool )>(_a, &DBusMPRIS::CanGoPreviousChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(bool )>(_a, &DBusMPRIS::CanPauseChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(bool )>(_a, &DBusMPRIS::CanPlayChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(bool )>(_a, &DBusMPRIS::CanSeekChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(const QString & )>(_a, &DBusMPRIS::LoopStatusChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(double )>(_a, &DBusMPRIS::MaximumRateChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(const QVariantMap & )>(_a, &DBusMPRIS::MetadataChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(double )>(_a, &DBusMPRIS::MinimumRateChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(const QString & )>(_a, &DBusMPRIS::PlaybackStatusChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(qlonglong )>(_a, &DBusMPRIS::PositionChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(double )>(_a, &DBusMPRIS::RateChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(bool )>(_a, &DBusMPRIS::ShuffleChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMPRIS::*)(double )>(_a, &DBusMPRIS::VolumeChanged, 16))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canControl(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canShowInUI(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canGoNext(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canGoPrevious(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->canPause(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canPlay(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->canSeek(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->loopStatus(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->maximumRate(); break;
        case 9: *reinterpret_cast<QVariantMap*>(_v) = _t->metadata(); break;
        case 10: *reinterpret_cast<double*>(_v) = _t->minimumRate(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->playbackStatus(); break;
        case 12: *reinterpret_cast<qlonglong*>(_v) = _t->position(); break;
        case 13: *reinterpret_cast<double*>(_v) = _t->rate(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->shuffle(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 7: _t->setLoopStatus(*reinterpret_cast<QString*>(_v)); break;
        case 13: _t->setRate(*reinterpret_cast<double*>(_v)); break;
        case 14: _t->setShuffle(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setVolume(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DBusMPRIS::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusMPRIS::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DBusMPRISE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusMPRIS::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void DBusMPRIS::Seeked(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DBusMPRIS::CanControlChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DBusMPRIS::CanShowInUIChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DBusMPRIS::CanGoNextChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DBusMPRIS::CanGoPreviousChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DBusMPRIS::CanPauseChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DBusMPRIS::CanPlayChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DBusMPRIS::CanSeekChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DBusMPRIS::LoopStatusChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DBusMPRIS::MaximumRateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DBusMPRIS::MetadataChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DBusMPRIS::MinimumRateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DBusMPRIS::PlaybackStatusChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DBusMPRIS::PositionChanged(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DBusMPRIS::RateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DBusMPRIS::ShuffleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DBusMPRIS::VolumeChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}
QT_WARNING_POP
