/****************************************************************************
** Meta object code from reading C++ file 'dtitlebar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dtitlebar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dtitlebar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DTitlebar_t {
    QByteArrayData data[36];
    char stringdata0[565];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DTitlebar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DTitlebar_t qt_meta_stringdata_Dtk__Widget__DTitlebar = {
    {
QT_MOC_LITERAL(0, 0, 22), // "Dtk::Widget::DTitlebar"
QT_MOC_LITERAL(1, 23, 13), // "optionClicked"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 13), // "doubleClicked"
QT_MOC_LITERAL(4, 52, 12), // "mousePressed"
QT_MOC_LITERAL(5, 65, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(6, 82, 7), // "buttons"
QT_MOC_LITERAL(7, 90, 11), // "mouseMoving"
QT_MOC_LITERAL(8, 102, 15), // "Qt::MouseButton"
QT_MOC_LITERAL(9, 118, 6), // "button"
QT_MOC_LITERAL(10, 125, 14), // "setFixedHeight"
QT_MOC_LITERAL(11, 140, 1), // "h"
QT_MOC_LITERAL(12, 142, 24), // "setBackgroundTransparent"
QT_MOC_LITERAL(13, 167, 11), // "transparent"
QT_MOC_LITERAL(14, 179, 19), // "setSeparatorVisible"
QT_MOC_LITERAL(15, 199, 7), // "visible"
QT_MOC_LITERAL(16, 207, 8), // "setTitle"
QT_MOC_LITERAL(17, 216, 5), // "title"
QT_MOC_LITERAL(18, 222, 7), // "setIcon"
QT_MOC_LITERAL(19, 230, 4), // "icon"
QT_MOC_LITERAL(20, 235, 17), // "toggleWindowState"
QT_MOC_LITERAL(21, 253, 17), // "setBlurBackground"
QT_MOC_LITERAL(22, 271, 14), // "blurBackground"
QT_MOC_LITERAL(23, 286, 8), // "showMenu"
QT_MOC_LITERAL(24, 295, 20), // "_q_toggleWindowState"
QT_MOC_LITERAL(25, 316, 16), // "_q_showMinimized"
QT_MOC_LITERAL(26, 333, 31), // "_q_onTopWindowMotifHintsChanged"
QT_MOC_LITERAL(27, 365, 14), // "_q_closeWindow"
QT_MOC_LITERAL(28, 380, 22), // "_q_addDefaultMenuItems"
QT_MOC_LITERAL(29, 403, 22), // "_q_helpActionTriggered"
QT_MOC_LITERAL(30, 426, 26), // "_q_feedbackActionTriggered"
QT_MOC_LITERAL(31, 453, 23), // "_q_aboutActionTriggered"
QT_MOC_LITERAL(32, 477, 22), // "_q_quitActionTriggered"
QT_MOC_LITERAL(33, 500, 29), // "_q_switchThemeActionTriggered"
QT_MOC_LITERAL(34, 530, 8), // "QAction*"
QT_MOC_LITERAL(35, 539, 25) // "_q_toolBarActionTriggered"

    },
    "Dtk::Widget::DTitlebar\0optionClicked\0"
    "\0doubleClicked\0mousePressed\0"
    "Qt::MouseButtons\0buttons\0mouseMoving\0"
    "Qt::MouseButton\0button\0setFixedHeight\0"
    "h\0setBackgroundTransparent\0transparent\0"
    "setSeparatorVisible\0visible\0setTitle\0"
    "title\0setIcon\0icon\0toggleWindowState\0"
    "setBlurBackground\0blurBackground\0"
    "showMenu\0_q_toggleWindowState\0"
    "_q_showMinimized\0_q_onTopWindowMotifHintsChanged\0"
    "_q_closeWindow\0_q_addDefaultMenuItems\0"
    "_q_helpActionTriggered\0"
    "_q_feedbackActionTriggered\0"
    "_q_aboutActionTriggered\0_q_quitActionTriggered\0"
    "_q_switchThemeActionTriggered\0QAction*\0"
    "_q_toolBarActionTriggered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DTitlebar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      23,   14, // methods
       1,  172, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  129,    2, 0x06 /* Public */,
       3,    0,  130,    2, 0x06 /* Public */,
       4,    1,  131,    2, 0x06 /* Public */,
       7,    1,  134,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,  137,    2, 0x0a /* Public */,
      12,    1,  140,    2, 0x0a /* Public */,
      14,    1,  143,    2, 0x0a /* Public */,
      16,    1,  146,    2, 0x0a /* Public */,
      18,    1,  149,    2, 0x0a /* Public */,
      20,    0,  152,    2, 0x0a /* Public */,
      21,    1,  153,    2, 0x0a /* Public */,
      23,    0,  156,    2, 0x08 /* Private */,
      24,    0,  157,    2, 0x08 /* Private */,
      25,    0,  158,    2, 0x08 /* Private */,
      26,    1,  159,    2, 0x08 /* Private */,
      27,    0,  162,    2, 0x08 /* Private */,
      28,    0,  163,    2, 0x08 /* Private */,
      29,    0,  164,    2, 0x08 /* Private */,
      30,    0,  165,    2, 0x08 /* Private */,
      31,    0,  166,    2, 0x08 /* Private */,
      32,    0,  167,    2, 0x08 /* Private */,
      33,    1,  168,    2, 0x08 /* Private */,
      35,    0,  171,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void, QMetaType::QIcon,   19,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 34,    2,
    QMetaType::Void,

 // properties: name, type, flags
      22, QMetaType::Bool, 0x00095103,

       0        // eod
};

void Dtk::Widget::DTitlebar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DTitlebar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->optionClicked(); break;
        case 1: _t->doubleClicked(); break;
        case 2: _t->mousePressed((*reinterpret_cast< Qt::MouseButtons(*)>(_a[1]))); break;
        case 3: _t->mouseMoving((*reinterpret_cast< Qt::MouseButton(*)>(_a[1]))); break;
        case 4: _t->setFixedHeight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->setBackgroundTransparent((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->setSeparatorVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->setTitle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->setIcon((*reinterpret_cast< const QIcon(*)>(_a[1]))); break;
        case 9: _t->toggleWindowState(); break;
        case 10: _t->setBlurBackground((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->showMenu(); break;
        case 12: _t->d_func()->_q_toggleWindowState(); break;
        case 13: _t->d_func()->_q_showMinimized(); break;
        case 14: _t->d_func()->_q_onTopWindowMotifHintsChanged((*reinterpret_cast< quint32(*)>(_a[1]))); break;
        case 15: _t->d_func()->_q_closeWindow(); break;
        case 16: _t->d_func()->_q_addDefaultMenuItems(); break;
        case 17: _t->d_func()->_q_helpActionTriggered(); break;
        case 18: _t->d_func()->_q_feedbackActionTriggered(); break;
        case 19: _t->d_func()->_q_aboutActionTriggered(); break;
        case 20: _t->d_func()->_q_quitActionTriggered(); break;
        case 21: _t->d_func()->_q_switchThemeActionTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 22: _t->d_func()->_q_toolBarActionTriggered(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DTitlebar::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTitlebar::optionClicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DTitlebar::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTitlebar::doubleClicked)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DTitlebar::*)(Qt::MouseButtons );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTitlebar::mousePressed)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DTitlebar::*)(Qt::MouseButton );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTitlebar::mouseMoving)) {
                *result = 3;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DTitlebar *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->blurBackground(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DTitlebar *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBlurBackground(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DTitlebar::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DTitlebar.data,
    qt_meta_data_Dtk__Widget__DTitlebar,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DTitlebar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DTitlebar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DTitlebar.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QFrame::qt_metacast(_clname);
}

int Dtk::Widget::DTitlebar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DTitlebar::optionClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DTitlebar::doubleClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DTitlebar::mousePressed(Qt::MouseButtons _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Widget::DTitlebar::mouseMoving(Qt::MouseButton _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
