/****************************************************************************
** Meta object code from reading C++ file 'dmainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dmainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dmainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DMainWindow_t {
    QByteArrayData data[56];
    char stringdata0[964];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DMainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DMainWindow_t qt_meta_stringdata_Dtk__Widget__DMainWindow = {
    {
QT_MOC_LITERAL(0, 0, 24), // "Dtk::Widget::DMainWindow"
QT_MOC_LITERAL(1, 25, 19), // "windowRadiusChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 18), // "borderWidthChanged"
QT_MOC_LITERAL(4, 65, 18), // "borderColorChanged"
QT_MOC_LITERAL(5, 84, 19), // "shadowRadiusChanged"
QT_MOC_LITERAL(6, 104, 19), // "shadowOffsetChanged"
QT_MOC_LITERAL(7, 124, 18), // "shadowColorChanged"
QT_MOC_LITERAL(8, 143, 15), // "clipPathChanged"
QT_MOC_LITERAL(9, 159, 16), // "frameMaskChanged"
QT_MOC_LITERAL(10, 176, 19), // "frameMarginsChanged"
QT_MOC_LITERAL(11, 196, 28), // "translucentBackgroundChanged"
QT_MOC_LITERAL(12, 225, 25), // "enableSystemResizeChanged"
QT_MOC_LITERAL(13, 251, 23), // "enableSystemMoveChanged"
QT_MOC_LITERAL(14, 275, 23), // "enableBlurWindowChanged"
QT_MOC_LITERAL(15, 299, 30), // "autoInputMaskByClipPathChanged"
QT_MOC_LITERAL(16, 330, 20), // "sidebarVisbleChanged"
QT_MOC_LITERAL(17, 351, 7), // "visible"
QT_MOC_LITERAL(18, 359, 21), // "sidebarExpanedChanged"
QT_MOC_LITERAL(19, 381, 7), // "expaned"
QT_MOC_LITERAL(20, 389, 15), // "setWindowRadius"
QT_MOC_LITERAL(21, 405, 12), // "windowRadius"
QT_MOC_LITERAL(22, 418, 14), // "setBorderWidth"
QT_MOC_LITERAL(23, 433, 11), // "borderWidth"
QT_MOC_LITERAL(24, 445, 14), // "setBorderColor"
QT_MOC_LITERAL(25, 460, 11), // "borderColor"
QT_MOC_LITERAL(26, 472, 15), // "setShadowRadius"
QT_MOC_LITERAL(27, 488, 12), // "shadowRadius"
QT_MOC_LITERAL(28, 501, 15), // "setShadowOffset"
QT_MOC_LITERAL(29, 517, 12), // "shadowOffset"
QT_MOC_LITERAL(30, 530, 14), // "setShadowColor"
QT_MOC_LITERAL(31, 545, 11), // "shadowColor"
QT_MOC_LITERAL(32, 557, 11), // "setClipPath"
QT_MOC_LITERAL(33, 569, 12), // "QPainterPath"
QT_MOC_LITERAL(34, 582, 8), // "clipPath"
QT_MOC_LITERAL(35, 591, 12), // "setFrameMask"
QT_MOC_LITERAL(36, 604, 9), // "frameMask"
QT_MOC_LITERAL(37, 614, 24), // "setTranslucentBackground"
QT_MOC_LITERAL(38, 639, 21), // "translucentBackground"
QT_MOC_LITERAL(39, 661, 21), // "setEnableSystemResize"
QT_MOC_LITERAL(40, 683, 18), // "enableSystemResize"
QT_MOC_LITERAL(41, 702, 19), // "setEnableSystemMove"
QT_MOC_LITERAL(42, 722, 16), // "enableSystemMove"
QT_MOC_LITERAL(43, 739, 19), // "setEnableBlurWindow"
QT_MOC_LITERAL(44, 759, 16), // "enableBlurWindow"
QT_MOC_LITERAL(45, 776, 26), // "setAutoInputMaskByClipPath"
QT_MOC_LITERAL(46, 803, 23), // "autoInputMaskByClipPath"
QT_MOC_LITERAL(47, 827, 11), // "sendMessage"
QT_MOC_LITERAL(48, 839, 4), // "icon"
QT_MOC_LITERAL(49, 844, 7), // "message"
QT_MOC_LITERAL(50, 852, 17), // "DFloatingMessage*"
QT_MOC_LITERAL(51, 870, 24), // "setTitlebarShadowEnabled"
QT_MOC_LITERAL(52, 895, 21), // "titlebarShadowEnabled"
QT_MOC_LITERAL(53, 917, 24), // "_q_autoShowFeatureDialog"
QT_MOC_LITERAL(54, 942, 12), // "frameMargins"
QT_MOC_LITERAL(55, 955, 8) // "QMargins"

    },
    "Dtk::Widget::DMainWindow\0windowRadiusChanged\0"
    "\0borderWidthChanged\0borderColorChanged\0"
    "shadowRadiusChanged\0shadowOffsetChanged\0"
    "shadowColorChanged\0clipPathChanged\0"
    "frameMaskChanged\0frameMarginsChanged\0"
    "translucentBackgroundChanged\0"
    "enableSystemResizeChanged\0"
    "enableSystemMoveChanged\0enableBlurWindowChanged\0"
    "autoInputMaskByClipPathChanged\0"
    "sidebarVisbleChanged\0visible\0"
    "sidebarExpanedChanged\0expaned\0"
    "setWindowRadius\0windowRadius\0"
    "setBorderWidth\0borderWidth\0setBorderColor\0"
    "borderColor\0setShadowRadius\0shadowRadius\0"
    "setShadowOffset\0shadowOffset\0"
    "setShadowColor\0shadowColor\0setClipPath\0"
    "QPainterPath\0clipPath\0setFrameMask\0"
    "frameMask\0setTranslucentBackground\0"
    "translucentBackground\0setEnableSystemResize\0"
    "enableSystemResize\0setEnableSystemMove\0"
    "enableSystemMove\0setEnableBlurWindow\0"
    "enableBlurWindow\0setAutoInputMaskByClipPath\0"
    "autoInputMaskByClipPath\0sendMessage\0"
    "icon\0message\0DFloatingMessage*\0"
    "setTitlebarShadowEnabled\0titlebarShadowEnabled\0"
    "_q_autoShowFeatureDialog\0frameMargins\0"
    "QMargins"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DMainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      33,   14, // methods
      15,  250, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      16,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  179,    2, 0x06 /* Public */,
       3,    0,  180,    2, 0x06 /* Public */,
       4,    0,  181,    2, 0x06 /* Public */,
       5,    0,  182,    2, 0x06 /* Public */,
       6,    0,  183,    2, 0x06 /* Public */,
       7,    0,  184,    2, 0x06 /* Public */,
       8,    0,  185,    2, 0x06 /* Public */,
       9,    0,  186,    2, 0x06 /* Public */,
      10,    0,  187,    2, 0x06 /* Public */,
      11,    0,  188,    2, 0x06 /* Public */,
      12,    0,  189,    2, 0x06 /* Public */,
      13,    0,  190,    2, 0x06 /* Public */,
      14,    0,  191,    2, 0x06 /* Public */,
      15,    0,  192,    2, 0x06 /* Public */,
      16,    1,  193,    2, 0x06 /* Public */,
      18,    1,  196,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      20,    1,  199,    2, 0x0a /* Public */,
      22,    1,  202,    2, 0x0a /* Public */,
      24,    1,  205,    2, 0x0a /* Public */,
      26,    1,  208,    2, 0x0a /* Public */,
      28,    1,  211,    2, 0x0a /* Public */,
      30,    1,  214,    2, 0x0a /* Public */,
      32,    1,  217,    2, 0x0a /* Public */,
      35,    1,  220,    2, 0x0a /* Public */,
      37,    1,  223,    2, 0x0a /* Public */,
      39,    1,  226,    2, 0x0a /* Public */,
      41,    1,  229,    2, 0x0a /* Public */,
      43,    1,  232,    2, 0x0a /* Public */,
      45,    1,  235,    2, 0x0a /* Public */,
      47,    2,  238,    2, 0x0a /* Public */,
      47,    1,  243,    2, 0x0a /* Public */,
      51,    1,  246,    2, 0x0a /* Public */,
      53,    0,  249,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::Bool,   19,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, QMetaType::Int,   23,
    QMetaType::Void, QMetaType::QColor,   25,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, QMetaType::QPoint,   29,
    QMetaType::Void, QMetaType::QColor,   31,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void, QMetaType::QRegion,   36,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Void, QMetaType::Bool,   40,
    QMetaType::Void, QMetaType::Bool,   42,
    QMetaType::Void, QMetaType::Bool,   44,
    QMetaType::Void, QMetaType::Bool,   46,
    QMetaType::Void, QMetaType::QIcon, QMetaType::QString,   48,   49,
    QMetaType::Void, 0x80000000 | 50,   49,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void,

 // properties: name, type, flags
      21, QMetaType::Int, 0x00495103,
      23, QMetaType::Int, 0x00495103,
      25, QMetaType::QColor, 0x00495103,
      27, QMetaType::Int, 0x00495103,
      29, QMetaType::QPoint, 0x00495103,
      31, QMetaType::QColor, 0x00495103,
      34, 0x80000000 | 33, 0x0049510b,
      36, QMetaType::QRegion, 0x00495103,
      54, 0x80000000 | 55, 0x00495009,
      38, QMetaType::Bool, 0x00495103,
      40, QMetaType::Bool, 0x00495103,
      42, QMetaType::Bool, 0x00495103,
      44, QMetaType::Bool, 0x00495103,
      46, QMetaType::Bool, 0x00495103,
      52, QMetaType::Bool, 0x00095103,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
      11,
      12,
      13,
       0,

       0        // eod
};

void Dtk::Widget::DMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DMainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->windowRadiusChanged(); break;
        case 1: _t->borderWidthChanged(); break;
        case 2: _t->borderColorChanged(); break;
        case 3: _t->shadowRadiusChanged(); break;
        case 4: _t->shadowOffsetChanged(); break;
        case 5: _t->shadowColorChanged(); break;
        case 6: _t->clipPathChanged(); break;
        case 7: _t->frameMaskChanged(); break;
        case 8: _t->frameMarginsChanged(); break;
        case 9: _t->translucentBackgroundChanged(); break;
        case 10: _t->enableSystemResizeChanged(); break;
        case 11: _t->enableSystemMoveChanged(); break;
        case 12: _t->enableBlurWindowChanged(); break;
        case 13: _t->autoInputMaskByClipPathChanged(); break;
        case 14: _t->sidebarVisbleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->sidebarExpanedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->setWindowRadius((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->setBorderWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->setBorderColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 19: _t->setShadowRadius((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->setShadowOffset((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 21: _t->setShadowColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 22: _t->setClipPath((*reinterpret_cast< const QPainterPath(*)>(_a[1]))); break;
        case 23: _t->setFrameMask((*reinterpret_cast< const QRegion(*)>(_a[1]))); break;
        case 24: _t->setTranslucentBackground((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->setEnableSystemResize((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->setEnableSystemMove((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: _t->setEnableBlurWindow((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->setAutoInputMaskByClipPath((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->sendMessage((*reinterpret_cast< const QIcon(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 30: _t->sendMessage((*reinterpret_cast< DFloatingMessage*(*)>(_a[1]))); break;
        case 31: _t->setTitlebarShadowEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->d_func()->_q_autoShowFeatureDialog(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DFloatingMessage* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::windowRadiusChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::borderWidthChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::borderColorChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::shadowRadiusChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::shadowOffsetChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::shadowColorChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::clipPathChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::frameMaskChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::frameMarginsChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::translucentBackgroundChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::enableSystemResizeChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::enableSystemMoveChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::enableBlurWindowChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::autoInputMaskByClipPathChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::sidebarVisbleChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (DMainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DMainWindow::sidebarExpanedChanged)) {
                *result = 15;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DMainWindow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->windowRadius(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->borderWidth(); break;
        case 2: *reinterpret_cast< QColor*>(_v) = _t->borderColor(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->shadowRadius(); break;
        case 4: *reinterpret_cast< QPoint*>(_v) = _t->shadowOffset(); break;
        case 5: *reinterpret_cast< QColor*>(_v) = _t->shadowColor(); break;
        case 6: *reinterpret_cast< QPainterPath*>(_v) = _t->clipPath(); break;
        case 7: *reinterpret_cast< QRegion*>(_v) = _t->frameMask(); break;
        case 8: *reinterpret_cast< QMargins*>(_v) = _t->frameMargins(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->translucentBackground(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->enableSystemResize(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->enableSystemMove(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->enableBlurWindow(); break;
        case 13: *reinterpret_cast< bool*>(_v) = _t->autoInputMaskByClipPath(); break;
        case 14: *reinterpret_cast< bool*>(_v) = _t->titlebarShadowIsEnabled(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DMainWindow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWindowRadius(*reinterpret_cast< int*>(_v)); break;
        case 1: _t->setBorderWidth(*reinterpret_cast< int*>(_v)); break;
        case 2: _t->setBorderColor(*reinterpret_cast< QColor*>(_v)); break;
        case 3: _t->setShadowRadius(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setShadowOffset(*reinterpret_cast< QPoint*>(_v)); break;
        case 5: _t->setShadowColor(*reinterpret_cast< QColor*>(_v)); break;
        case 6: _t->setClipPath(*reinterpret_cast< QPainterPath*>(_v)); break;
        case 7: _t->setFrameMask(*reinterpret_cast< QRegion*>(_v)); break;
        case 9: _t->setTranslucentBackground(*reinterpret_cast< bool*>(_v)); break;
        case 10: _t->setEnableSystemResize(*reinterpret_cast< bool*>(_v)); break;
        case 11: _t->setEnableSystemMove(*reinterpret_cast< bool*>(_v)); break;
        case 12: _t->setEnableBlurWindow(*reinterpret_cast< bool*>(_v)); break;
        case 13: _t->setAutoInputMaskByClipPath(*reinterpret_cast< bool*>(_v)); break;
        case 14: _t->setTitlebarShadowEnabled(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DMainWindow.data,
    qt_meta_data_Dtk__Widget__DMainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DMainWindow.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int Dtk::Widget::DMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 15;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DMainWindow::windowRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DMainWindow::borderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DMainWindow::borderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Widget::DMainWindow::shadowRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Widget::DMainWindow::shadowOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Widget::DMainWindow::shadowColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Widget::DMainWindow::clipPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Widget::DMainWindow::frameMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Widget::DMainWindow::frameMarginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Widget::DMainWindow::translucentBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Dtk::Widget::DMainWindow::enableSystemResizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Dtk::Widget::DMainWindow::enableSystemMoveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Dtk::Widget::DMainWindow::enableBlurWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Dtk::Widget::DMainWindow::autoInputMaskByClipPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Dtk::Widget::DMainWindow::sidebarVisbleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Dtk::Widget::DMainWindow::sidebarExpanedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
