/****************************************************************************
** Meta object code from reading C++ file 'daboutdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/daboutdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'daboutdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DAboutDialog_t {
    QByteArrayData data[30];
    char stringdata0[426];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DAboutDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DAboutDialog_t qt_meta_stringdata_Dtk__Widget__DAboutDialog = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Dtk::Widget::DAboutDialog"
QT_MOC_LITERAL(1, 26, 16), // "featureActivated"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 16), // "licenseActivated"
QT_MOC_LITERAL(4, 61, 14), // "setWindowTitle"
QT_MOC_LITERAL(5, 76, 11), // "windowTitle"
QT_MOC_LITERAL(6, 88, 14), // "setProductIcon"
QT_MOC_LITERAL(7, 103, 4), // "icon"
QT_MOC_LITERAL(8, 108, 14), // "setProductName"
QT_MOC_LITERAL(9, 123, 11), // "productName"
QT_MOC_LITERAL(10, 135, 10), // "setVersion"
QT_MOC_LITERAL(11, 146, 7), // "version"
QT_MOC_LITERAL(12, 154, 14), // "setDescription"
QT_MOC_LITERAL(13, 169, 11), // "description"
QT_MOC_LITERAL(14, 181, 14), // "setCompanyLogo"
QT_MOC_LITERAL(15, 196, 11), // "companyLogo"
QT_MOC_LITERAL(16, 208, 14), // "setWebsiteName"
QT_MOC_LITERAL(17, 223, 11), // "websiteName"
QT_MOC_LITERAL(18, 235, 14), // "setWebsiteLink"
QT_MOC_LITERAL(19, 250, 11), // "websiteLink"
QT_MOC_LITERAL(20, 262, 22), // "setAcknowledgementLink"
QT_MOC_LITERAL(21, 285, 19), // "acknowledgementLink"
QT_MOC_LITERAL(22, 305, 25), // "setAcknowledgementVisible"
QT_MOC_LITERAL(23, 331, 7), // "visible"
QT_MOC_LITERAL(24, 339, 10), // "setLicense"
QT_MOC_LITERAL(25, 350, 7), // "license"
QT_MOC_LITERAL(26, 358, 18), // "_q_onLinkActivated"
QT_MOC_LITERAL(27, 377, 4), // "link"
QT_MOC_LITERAL(28, 382, 21), // "_q_onFeatureActivated"
QT_MOC_LITERAL(29, 404, 21) // "_q_onLicenseActivated"

    },
    "Dtk::Widget::DAboutDialog\0featureActivated\0"
    "\0licenseActivated\0setWindowTitle\0"
    "windowTitle\0setProductIcon\0icon\0"
    "setProductName\0productName\0setVersion\0"
    "version\0setDescription\0description\0"
    "setCompanyLogo\0companyLogo\0setWebsiteName\0"
    "websiteName\0setWebsiteLink\0websiteLink\0"
    "setAcknowledgementLink\0acknowledgementLink\0"
    "setAcknowledgementVisible\0visible\0"
    "setLicense\0license\0_q_onLinkActivated\0"
    "link\0_q_onFeatureActivated\0"
    "_q_onLicenseActivated"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DAboutDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       8,  138, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x06 /* Public */,
       3,    0,   95,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   96,    2, 0x0a /* Public */,
       6,    1,   99,    2, 0x0a /* Public */,
       8,    1,  102,    2, 0x0a /* Public */,
      10,    1,  105,    2, 0x0a /* Public */,
      12,    1,  108,    2, 0x0a /* Public */,
      14,    1,  111,    2, 0x0a /* Public */,
      16,    1,  114,    2, 0x0a /* Public */,
      18,    1,  117,    2, 0x0a /* Public */,
      20,    1,  120,    2, 0x0a /* Public */,
      22,    1,  123,    2, 0x0a /* Public */,
      24,    1,  126,    2, 0x0a /* Public */,
      26,    1,  129,    2, 0x08 /* Private */,
      28,    1,  132,    2, 0x08 /* Private */,
      29,    1,  135,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QIcon,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void, QMetaType::QPixmap,   15,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void, QMetaType::QString,   19,
    QMetaType::Void, QMetaType::QString,   21,
    QMetaType::Void, QMetaType::Bool,   23,
    QMetaType::Void, QMetaType::QString,   25,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::QString,   27,

 // properties: name, type, flags
       5, QMetaType::QString, 0x00095103,
       9, QMetaType::QString, 0x00095103,
      11, QMetaType::QString, 0x00095103,
      13, QMetaType::QString, 0x00095103,
      25, QMetaType::QString, 0x00095103,
      17, QMetaType::QString, 0x00095103,
      19, QMetaType::QString, 0x00095103,
      21, QMetaType::QString, 0x00095103,

       0        // eod
};

void Dtk::Widget::DAboutDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DAboutDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->featureActivated(); break;
        case 1: _t->licenseActivated(); break;
        case 2: _t->setWindowTitle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->setProductIcon((*reinterpret_cast< const QIcon(*)>(_a[1]))); break;
        case 4: _t->setProductName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->setVersion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->setDescription((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->setCompanyLogo((*reinterpret_cast< const QPixmap(*)>(_a[1]))); break;
        case 8: _t->setWebsiteName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->setWebsiteLink((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->setAcknowledgementLink((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->setAcknowledgementVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->setLicense((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->d_func()->_q_onLinkActivated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->d_func()->_q_onFeatureActivated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->d_func()->_q_onLicenseActivated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DAboutDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAboutDialog::featureActivated)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DAboutDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DAboutDialog::licenseActivated)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DAboutDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->windowTitle(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->productName(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->version(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->description(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->license(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->websiteName(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->websiteLink(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->acknowledgementLink(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DAboutDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWindowTitle(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setProductName(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setVersion(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setDescription(*reinterpret_cast< QString*>(_v)); break;
        case 4: _t->setLicense(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setWebsiteName(*reinterpret_cast< QString*>(_v)); break;
        case 6: _t->setWebsiteLink(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setAcknowledgementLink(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DAboutDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<DDialog::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DAboutDialog.data,
    qt_meta_data_Dtk__Widget__DAboutDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DAboutDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DAboutDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DAboutDialog.stringdata0))
        return static_cast<void*>(this);
    return DDialog::qt_metacast(_clname);
}

int Dtk::Widget::DAboutDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DAboutDialog::featureActivated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DAboutDialog::licenseActivated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
