// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "dprintpreviewsettinginfo.h"

DWIDGET_BEGIN_NAMESPACE

DPrintPreviewSettingInfo::DPrintPreviewSettingInfo(SettingType type)
    : t(type)
{

}

Dtk::Widget::DPrintPreviewSettingInfo::~DPrintPreviewSettingInfo()
{

}

DWIDGET_END_NAMESPACE
