/****************************************************************************
** Meta object code from reading C++ file 'dblureffectwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dblureffectwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dblureffectwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DBlurEffectWidget_t {
    QByteArrayData data[45];
    char stringdata0[590];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DBlurEffectWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DBlurEffectWidget_t qt_meta_stringdata_Dtk__Widget__DBlurEffectWidget = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Dtk::Widget::DBlurEffectWidget"
QT_MOC_LITERAL(1, 31, 13), // "radiusChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 6), // "radius"
QT_MOC_LITERAL(4, 53, 11), // "modeChanged"
QT_MOC_LITERAL(5, 65, 8), // "BlurMode"
QT_MOC_LITERAL(6, 74, 4), // "mode"
QT_MOC_LITERAL(7, 79, 16), // "blendModeChanged"
QT_MOC_LITERAL(8, 96, 9), // "BlendMode"
QT_MOC_LITERAL(9, 106, 9), // "blendMode"
QT_MOC_LITERAL(10, 116, 22), // "blurRectXRadiusChanged"
QT_MOC_LITERAL(11, 139, 15), // "blurRectXRadius"
QT_MOC_LITERAL(12, 155, 22), // "blurRectYRadiusChanged"
QT_MOC_LITERAL(13, 178, 15), // "blurRectYRadius"
QT_MOC_LITERAL(14, 194, 16), // "maskAlphaChanged"
QT_MOC_LITERAL(15, 211, 5), // "alpha"
QT_MOC_LITERAL(16, 217, 16), // "maskColorChanged"
QT_MOC_LITERAL(17, 234, 9), // "maskColor"
QT_MOC_LITERAL(18, 244, 11), // "fullChanged"
QT_MOC_LITERAL(19, 256, 4), // "full"
QT_MOC_LITERAL(20, 261, 18), // "blurEnabledChanged"
QT_MOC_LITERAL(21, 280, 11), // "blurEnabled"
QT_MOC_LITERAL(22, 292, 22), // "blurSourceImageDirtied"
QT_MOC_LITERAL(23, 315, 9), // "setRadius"
QT_MOC_LITERAL(24, 325, 7), // "setMode"
QT_MOC_LITERAL(25, 333, 12), // "setBlendMode"
QT_MOC_LITERAL(26, 346, 18), // "setBlurRectXRadius"
QT_MOC_LITERAL(27, 365, 18), // "setBlurRectYRadius"
QT_MOC_LITERAL(28, 384, 12), // "setMaskAlpha"
QT_MOC_LITERAL(29, 397, 12), // "setMaskColor"
QT_MOC_LITERAL(30, 410, 13), // "MaskColorType"
QT_MOC_LITERAL(31, 424, 4), // "type"
QT_MOC_LITERAL(32, 429, 7), // "setFull"
QT_MOC_LITERAL(33, 437, 14), // "setBlurEnabled"
QT_MOC_LITERAL(34, 452, 21), // "updateBlurSourceImage"
QT_MOC_LITERAL(35, 474, 3), // "ren"
QT_MOC_LITERAL(36, 478, 9), // "maskAlpha"
QT_MOC_LITERAL(37, 488, 12), // "GaussianBlur"
QT_MOC_LITERAL(38, 501, 13), // "InWindowBlend"
QT_MOC_LITERAL(39, 515, 17), // "BehindWindowBlend"
QT_MOC_LITERAL(40, 533, 13), // "InWidgetBlend"
QT_MOC_LITERAL(41, 547, 9), // "DarkColor"
QT_MOC_LITERAL(42, 557, 10), // "LightColor"
QT_MOC_LITERAL(43, 568, 9), // "AutoColor"
QT_MOC_LITERAL(44, 578, 11) // "CustomColor"

    },
    "Dtk::Widget::DBlurEffectWidget\0"
    "radiusChanged\0\0radius\0modeChanged\0"
    "BlurMode\0mode\0blendModeChanged\0BlendMode\0"
    "blendMode\0blurRectXRadiusChanged\0"
    "blurRectXRadius\0blurRectYRadiusChanged\0"
    "blurRectYRadius\0maskAlphaChanged\0alpha\0"
    "maskColorChanged\0maskColor\0fullChanged\0"
    "full\0blurEnabledChanged\0blurEnabled\0"
    "blurSourceImageDirtied\0setRadius\0"
    "setMode\0setBlendMode\0setBlurRectXRadius\0"
    "setBlurRectYRadius\0setMaskAlpha\0"
    "setMaskColor\0MaskColorType\0type\0setFull\0"
    "setBlurEnabled\0updateBlurSourceImage\0"
    "ren\0maskAlpha\0GaussianBlur\0InWindowBlend\0"
    "BehindWindowBlend\0InWidgetBlend\0"
    "DarkColor\0LightColor\0AutoColor\0"
    "CustomColor"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DBlurEffectWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       9,  180, // properties
       3,  216, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  119,    2, 0x06 /* Public */,
       4,    1,  122,    2, 0x06 /* Public */,
       7,    1,  125,    2, 0x06 /* Public */,
      10,    1,  128,    2, 0x06 /* Public */,
      12,    1,  131,    2, 0x06 /* Public */,
      14,    1,  134,    2, 0x06 /* Public */,
      16,    1,  137,    2, 0x06 /* Public */,
      18,    1,  140,    2, 0x06 /* Public */,
      20,    1,  143,    2, 0x06 /* Public */,
      22,    0,  146,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      23,    1,  147,    2, 0x0a /* Public */,
      24,    1,  150,    2, 0x0a /* Public */,
      25,    1,  153,    2, 0x0a /* Public */,
      26,    1,  156,    2, 0x0a /* Public */,
      27,    1,  159,    2, 0x0a /* Public */,
      28,    1,  162,    2, 0x0a /* Public */,
      29,    1,  165,    2, 0x0a /* Public */,
      29,    1,  168,    2, 0x0a /* Public */,
      32,    1,  171,    2, 0x0a /* Public */,
      33,    1,  174,    2, 0x0a /* Public */,
      34,    1,  177,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::UChar,   15,
    QMetaType::Void, QMetaType::QColor,   17,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::UChar,   15,
    QMetaType::Void, QMetaType::QColor,   17,
    QMetaType::Void, 0x80000000 | 30,   31,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void, QMetaType::QRegion,   35,

 // properties: name, type, flags
       3, QMetaType::Int, 0x00495103,
       6, 0x80000000 | 5, 0x0049510b,
       9, 0x80000000 | 8, 0x0049510b,
      11, QMetaType::Int, 0x00495103,
      13, QMetaType::Int, 0x00495103,
      17, QMetaType::QColor, 0x00495103,
      36, QMetaType::UChar, 0x00495103,
      19, QMetaType::Bool, 0x00495103,
      21, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       6,
       5,
       7,
       8,

 // enums: name, alias, flags, count, data
       5,    5, 0x0,    1,  231,
       8,    8, 0x0,    3,  233,
      30,   30, 0x0,    4,  239,

 // enum data: key, value
      37, uint(Dtk::Widget::DBlurEffectWidget::GaussianBlur),
      38, uint(Dtk::Widget::DBlurEffectWidget::InWindowBlend),
      39, uint(Dtk::Widget::DBlurEffectWidget::BehindWindowBlend),
      40, uint(Dtk::Widget::DBlurEffectWidget::InWidgetBlend),
      41, uint(Dtk::Widget::DBlurEffectWidget::DarkColor),
      42, uint(Dtk::Widget::DBlurEffectWidget::LightColor),
      43, uint(Dtk::Widget::DBlurEffectWidget::AutoColor),
      44, uint(Dtk::Widget::DBlurEffectWidget::CustomColor),

       0        // eod
};

void Dtk::Widget::DBlurEffectWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DBlurEffectWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->radiusChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->modeChanged((*reinterpret_cast< BlurMode(*)>(_a[1]))); break;
        case 2: _t->blendModeChanged((*reinterpret_cast< BlendMode(*)>(_a[1]))); break;
        case 3: _t->blurRectXRadiusChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->blurRectYRadiusChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->maskAlphaChanged((*reinterpret_cast< quint8(*)>(_a[1]))); break;
        case 6: _t->maskColorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 7: _t->fullChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->blurEnabledChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->blurSourceImageDirtied(); break;
        case 10: _t->setRadius((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->setMode((*reinterpret_cast< BlurMode(*)>(_a[1]))); break;
        case 12: _t->setBlendMode((*reinterpret_cast< BlendMode(*)>(_a[1]))); break;
        case 13: _t->setBlurRectXRadius((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->setBlurRectYRadius((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->setMaskAlpha((*reinterpret_cast< quint8(*)>(_a[1]))); break;
        case 16: _t->setMaskColor((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 17: _t->setMaskColor((*reinterpret_cast< MaskColorType(*)>(_a[1]))); break;
        case 18: _t->setFull((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->setBlurEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->updateBlurSourceImage((*reinterpret_cast< const QRegion(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DBlurEffectWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::radiusChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DBlurEffectWidget::*)(BlurMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::modeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DBlurEffectWidget::*)(BlendMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::blendModeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DBlurEffectWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::blurRectXRadiusChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DBlurEffectWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::blurRectYRadiusChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DBlurEffectWidget::*)(quint8 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::maskAlphaChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DBlurEffectWidget::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::maskColorChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DBlurEffectWidget::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::fullChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DBlurEffectWidget::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::blurEnabledChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DBlurEffectWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBlurEffectWidget::blurSourceImageDirtied)) {
                *result = 9;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DBlurEffectWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->radius(); break;
        case 1: *reinterpret_cast< BlurMode*>(_v) = _t->mode(); break;
        case 2: *reinterpret_cast< BlendMode*>(_v) = _t->blendMode(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->blurRectXRadius(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->blurRectYRadius(); break;
        case 5: *reinterpret_cast< QColor*>(_v) = _t->maskColor(); break;
        case 6: *reinterpret_cast< quint8*>(_v) = _t->maskAlpha(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->isFull(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->blurEnabled(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DBlurEffectWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRadius(*reinterpret_cast< int*>(_v)); break;
        case 1: _t->setMode(*reinterpret_cast< BlurMode*>(_v)); break;
        case 2: _t->setBlendMode(*reinterpret_cast< BlendMode*>(_v)); break;
        case 3: _t->setBlurRectXRadius(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setBlurRectYRadius(*reinterpret_cast< int*>(_v)); break;
        case 5: _t->setMaskColor(*reinterpret_cast< QColor*>(_v)); break;
        case 6: _t->setMaskAlpha(*reinterpret_cast< quint8*>(_v)); break;
        case 7: _t->setFull(*reinterpret_cast< bool*>(_v)); break;
        case 8: _t->setBlurEnabled(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DBlurEffectWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DBlurEffectWidget.data,
    qt_meta_data_Dtk__Widget__DBlurEffectWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DBlurEffectWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DBlurEffectWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DBlurEffectWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::DBlurEffectWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DBlurEffectWidget::radiusChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Widget::DBlurEffectWidget::modeChanged(BlurMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Widget::DBlurEffectWidget::blendModeChanged(BlendMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Widget::DBlurEffectWidget::blurRectXRadiusChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Dtk::Widget::DBlurEffectWidget::blurRectYRadiusChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Dtk::Widget::DBlurEffectWidget::maskAlphaChanged(quint8 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Dtk::Widget::DBlurEffectWidget::maskColorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Dtk::Widget::DBlurEffectWidget::fullChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Dtk::Widget::DBlurEffectWidget::blurEnabledChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Dtk::Widget::DBlurEffectWidget::blurSourceImageDirtied()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
