/****************************************************************************
** Meta object code from reading C++ file 'dtabbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dtabbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dtabbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DTabBar_t {
    QByteArrayData data[50];
    char stringdata0[650];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DTabBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DTabBar_t qt_meta_stringdata_Dtk__Widget__DTabBar = {
    {
QT_MOC_LITERAL(0, 0, 20), // "Dtk::Widget::DTabBar"
QT_MOC_LITERAL(1, 21, 14), // "currentChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 5), // "index"
QT_MOC_LITERAL(4, 43, 17), // "tabCloseRequested"
QT_MOC_LITERAL(5, 61, 8), // "tabMoved"
QT_MOC_LITERAL(6, 70, 4), // "from"
QT_MOC_LITERAL(7, 75, 2), // "to"
QT_MOC_LITERAL(8, 78, 13), // "tabIsInserted"
QT_MOC_LITERAL(9, 92, 12), // "tabIsRemoved"
QT_MOC_LITERAL(10, 105, 13), // "tabBarClicked"
QT_MOC_LITERAL(11, 119, 19), // "tabBarDoubleClicked"
QT_MOC_LITERAL(12, 139, 15), // "tabAddRequested"
QT_MOC_LITERAL(13, 155, 19), // "tabReleaseRequested"
QT_MOC_LITERAL(14, 175, 9), // "tabDroped"
QT_MOC_LITERAL(15, 185, 14), // "Qt::DropAction"
QT_MOC_LITERAL(16, 200, 6), // "action"
QT_MOC_LITERAL(17, 207, 6), // "target"
QT_MOC_LITERAL(18, 214, 17), // "dragActionChanged"
QT_MOC_LITERAL(19, 232, 11), // "dragStarted"
QT_MOC_LITERAL(20, 244, 7), // "dragEnd"
QT_MOC_LITERAL(21, 252, 15), // "setCurrentIndex"
QT_MOC_LITERAL(22, 268, 19), // "setVisibleAddButton"
QT_MOC_LITERAL(23, 288, 16), // "visibleAddButton"
QT_MOC_LITERAL(24, 305, 20), // "setStartDragDistance"
QT_MOC_LITERAL(25, 326, 17), // "startDragDistance"
QT_MOC_LITERAL(26, 344, 12), // "setMaskColor"
QT_MOC_LITERAL(27, 357, 9), // "maskColor"
QT_MOC_LITERAL(28, 367, 13), // "setFlashColor"
QT_MOC_LITERAL(29, 381, 10), // "flashColor"
QT_MOC_LITERAL(30, 392, 9), // "startDrag"
QT_MOC_LITERAL(31, 402, 8), // "stopDrag"
QT_MOC_LITERAL(32, 411, 5), // "shape"
QT_MOC_LITERAL(33, 417, 14), // "QTabBar::Shape"
QT_MOC_LITERAL(34, 432, 12), // "currentIndex"
QT_MOC_LITERAL(35, 445, 5), // "count"
QT_MOC_LITERAL(36, 451, 8), // "drawBase"
QT_MOC_LITERAL(37, 460, 8), // "iconSize"
QT_MOC_LITERAL(38, 469, 9), // "elideMode"
QT_MOC_LITERAL(39, 479, 17), // "Qt::TextElideMode"
QT_MOC_LITERAL(40, 497, 17), // "usesScrollButtons"
QT_MOC_LITERAL(41, 515, 12), // "tabsClosable"
QT_MOC_LITERAL(42, 528, 25), // "selectionBehaviorOnRemove"
QT_MOC_LITERAL(43, 554, 26), // "QTabBar::SelectionBehavior"
QT_MOC_LITERAL(44, 581, 9), // "expanding"
QT_MOC_LITERAL(45, 591, 7), // "movable"
QT_MOC_LITERAL(46, 599, 8), // "dragable"
QT_MOC_LITERAL(47, 608, 12), // "documentMode"
QT_MOC_LITERAL(48, 621, 8), // "autoHide"
QT_MOC_LITERAL(49, 630, 19) // "changeCurrentOnDrag"

    },
    "Dtk::Widget::DTabBar\0currentChanged\0"
    "\0index\0tabCloseRequested\0tabMoved\0"
    "from\0to\0tabIsInserted\0tabIsRemoved\0"
    "tabBarClicked\0tabBarDoubleClicked\0"
    "tabAddRequested\0tabReleaseRequested\0"
    "tabDroped\0Qt::DropAction\0action\0target\0"
    "dragActionChanged\0dragStarted\0dragEnd\0"
    "setCurrentIndex\0setVisibleAddButton\0"
    "visibleAddButton\0setStartDragDistance\0"
    "startDragDistance\0setMaskColor\0maskColor\0"
    "setFlashColor\0flashColor\0startDrag\0"
    "stopDrag\0shape\0QTabBar::Shape\0"
    "currentIndex\0count\0drawBase\0iconSize\0"
    "elideMode\0Qt::TextElideMode\0"
    "usesScrollButtons\0tabsClosable\0"
    "selectionBehaviorOnRemove\0"
    "QTabBar::SelectionBehavior\0expanding\0"
    "movable\0dragable\0documentMode\0autoHide\0"
    "changeCurrentOnDrag"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DTabBar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
      19,  176, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      13,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  114,    2, 0x06 /* Public */,
       4,    1,  117,    2, 0x06 /* Public */,
       5,    2,  120,    2, 0x06 /* Public */,
       8,    1,  125,    2, 0x06 /* Public */,
       9,    1,  128,    2, 0x06 /* Public */,
      10,    1,  131,    2, 0x06 /* Public */,
      11,    1,  134,    2, 0x06 /* Public */,
      12,    0,  137,    2, 0x06 /* Public */,
      13,    1,  138,    2, 0x06 /* Public */,
      14,    3,  141,    2, 0x06 /* Public */,
      18,    1,  148,    2, 0x06 /* Public */,
      19,    0,  151,    2, 0x06 /* Public */,
      20,    1,  152,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      21,    1,  155,    2, 0x0a /* Public */,
      22,    1,  158,    2, 0x0a /* Public */,
      24,    1,  161,    2, 0x0a /* Public */,
      26,    1,  164,    2, 0x0a /* Public */,
      28,    1,  167,    2, 0x0a /* Public */,
      30,    1,  170,    2, 0x0a /* Public */,
      31,    1,  173,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    6,    7,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 15, QMetaType::QObjectStar,    3,   16,   17,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,   16,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Bool,   23,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::QColor,   27,
    QMetaType::Void, QMetaType::QColor,   29,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, 0x80000000 | 15,   16,

 // properties: name, type, flags
      23, QMetaType::Bool, 0x00095103,
      32, 0x80000000 | 33, 0x0009510b,
      34, QMetaType::Int, 0x00495103,
      35, QMetaType::Int, 0x00095001,
      36, QMetaType::Bool, 0x00095103,
      37, QMetaType::QSize, 0x00095103,
      38, 0x80000000 | 39, 0x0009510b,
      40, QMetaType::Bool, 0x00095103,
      41, QMetaType::Bool, 0x00095103,
      42, 0x80000000 | 43, 0x0009510b,
      44, QMetaType::Bool, 0x00095103,
      45, QMetaType::Bool, 0x00095103,
      46, QMetaType::Bool, 0x00095103,
      47, QMetaType::Bool, 0x00095103,
      48, QMetaType::Bool, 0x00095103,
      49, QMetaType::Bool, 0x00095103,
      25, QMetaType::Int, 0x00095103,
      27, QMetaType::QColor, 0x00095103,
      29, QMetaType::QColor, 0x00095103,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

       0        // eod
};

void Dtk::Widget::DTabBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DTabBar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->currentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->tabCloseRequested((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->tabMoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->tabIsInserted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->tabIsRemoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->tabBarClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->tabBarDoubleClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->tabAddRequested(); break;
        case 8: _t->tabReleaseRequested((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->tabDroped((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::DropAction(*)>(_a[2])),(*reinterpret_cast< QObject*(*)>(_a[3]))); break;
        case 10: _t->dragActionChanged((*reinterpret_cast< Qt::DropAction(*)>(_a[1]))); break;
        case 11: _t->dragStarted(); break;
        case 12: _t->dragEnd((*reinterpret_cast< Qt::DropAction(*)>(_a[1]))); break;
        case 13: _t->setCurrentIndex((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->setVisibleAddButton((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->setStartDragDistance((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->setMaskColor((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 17: _t->setFlashColor((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 18: _t->startDrag((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->stopDrag((*reinterpret_cast< Qt::DropAction(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DTabBar::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::currentChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::tabCloseRequested)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::tabMoved)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::tabIsInserted)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::tabIsRemoved)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::tabBarClicked)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::tabBarDoubleClicked)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::tabAddRequested)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::tabReleaseRequested)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(int , Qt::DropAction , QObject * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::tabDroped)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(Qt::DropAction );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::dragActionChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::dragStarted)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DTabBar::*)(Qt::DropAction );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTabBar::dragEnd)) {
                *result = 12;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DTabBar *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->visibleAddButton(); break;
        case 1: *reinterpret_cast< QTabBar::Shape*>(_v) = _t->shape(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->currentIndex(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->count(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->drawBase(); break;
        case 5: *reinterpret_cast< QSize*>(_v) = _t->iconSize(); break;
        case 6: *reinterpret_cast< Qt::TextElideMode*>(_v) = _t->elideMode(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->usesScrollButtons(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->tabsClosable(); break;
        case 9: *reinterpret_cast< QTabBar::SelectionBehavior*>(_v) = _t->selectionBehaviorOnRemove(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->expanding(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->isMovable(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->isDragable(); break;
        case 13: *reinterpret_cast< bool*>(_v) = _t->documentMode(); break;
        case 14: *reinterpret_cast< bool*>(_v) = _t->autoHide(); break;
        case 15: *reinterpret_cast< bool*>(_v) = _t->changeCurrentOnDrag(); break;
        case 16: *reinterpret_cast< int*>(_v) = _t->startDragDistance(); break;
        case 17: *reinterpret_cast< QColor*>(_v) = _t->maskColor(); break;
        case 18: *reinterpret_cast< QColor*>(_v) = _t->flashColor(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DTabBar *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisibleAddButton(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setShape(*reinterpret_cast< QTabBar::Shape*>(_v)); break;
        case 2: _t->setCurrentIndex(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setDrawBase(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setIconSize(*reinterpret_cast< QSize*>(_v)); break;
        case 6: _t->setElideMode(*reinterpret_cast< Qt::TextElideMode*>(_v)); break;
        case 7: _t->setUsesScrollButtons(*reinterpret_cast< bool*>(_v)); break;
        case 8: _t->setTabsClosable(*reinterpret_cast< bool*>(_v)); break;
        case 9: _t->setSelectionBehaviorOnRemove(*reinterpret_cast< QTabBar::SelectionBehavior*>(_v)); break;
        case 10: _t->setExpanding(*reinterpret_cast< bool*>(_v)); break;
        case 11: _t->setMovable(*reinterpret_cast< bool*>(_v)); break;
        case 12: _t->setDragable(*reinterpret_cast< bool*>(_v)); break;
        case 13: _t->setDocumentMode(*reinterpret_cast< bool*>(_v)); break;
        case 14: _t->setAutoHide(*reinterpret_cast< bool*>(_v)); break;
        case 15: _t->setChangeCurrentOnDrag(*reinterpret_cast< bool*>(_v)); break;
        case 16: _t->setStartDragDistance(*reinterpret_cast< int*>(_v)); break;
        case 17: _t->setMaskColor(*reinterpret_cast< QColor*>(_v)); break;
        case 18: _t->setFlashColor(*reinterpret_cast< QColor*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Widget__DTabBar[] = {
    QMetaObject::SuperData::link<QTabBar::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DTabBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DTabBar.data,
    qt_meta_data_Dtk__Widget__DTabBar,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Widget__DTabBar,
    nullptr
} };


const QMetaObject *Dtk::Widget::DTabBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DTabBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DTabBar.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DObject"))
        return static_cast< DObject*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::DTabBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 20;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 19;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DTabBar::currentChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Widget::DTabBar::tabCloseRequested(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Widget::DTabBar::tabMoved(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Widget::DTabBar::tabIsInserted(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Dtk::Widget::DTabBar::tabIsRemoved(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Dtk::Widget::DTabBar::tabBarClicked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Dtk::Widget::DTabBar::tabBarDoubleClicked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Dtk::Widget::DTabBar::tabAddRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Widget::DTabBar::tabReleaseRequested(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Dtk::Widget::DTabBar::tabDroped(int _t1, Qt::DropAction _t2, QObject * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Dtk::Widget::DTabBar::dragActionChanged(Qt::DropAction _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Dtk::Widget::DTabBar::dragStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Dtk::Widget::DTabBar::dragEnd(Qt::DropAction _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
