// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef DCONSTANTS_H
#define DCONSTANTS_H

#include <dtkwidget_global.h>

DWIDGET_BEGIN_NAMESPACE
	//basis width and height
	const int BUTTON_HEIGHT = 22;
	const int EXPAND_HEADER_HEIGHT = 30;
	const int CONTENT_HEADER_HEIGHT = 38;
	const int RADIO_ITEM_HEIGHT = 30;
    const int MENU_ITEM_HEIGHT = 24;
    const int MENU_ITEM_LEFT_MARGIN = 24;   //NOT include the tick
	const int HEADER_LEFT_MARGIN = 14;
	const int HEADER_RIGHT_MARGIN = 14;
	const int TEXT_LEFT_MARGIN = 6;
	const int TEXT_RIGHT_MARGIN = 6;
	const int BUTTON_MARGIN = 8;
	const int TEXT_BUTTON_MIN_WIDTH = 70;
    const int IMAGE_BUTTON_WIDTH = 24;
	const int FONT_SIZE = 12;
	const int NORMAL_RADIUS = 3;
DWIDGET_END_NAMESPACE

#endif //DCONSTANTS_H
