/****************************************************************************
** Meta object code from reading C++ file 'darrowrectangle.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/darrowrectangle.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'darrowrectangle.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget15DArrowRectangleE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DArrowRectangle::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget15DArrowRectangleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DArrowRectangle",
        "windowDeactivate",
        "",
        "backgroundColor",
        "QColor",
        "borderColor",
        "borderWidth",
        "radius",
        "arrowWidth",
        "arrowHeight",
        "arrowX",
        "arrowY",
        "margin",
        "arrowDirection",
        "ArrowDirection",
        "shadowXOffset",
        "shadowYOffset",
        "shadowBlurRadius"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'windowDeactivate'
        QtMocHelpers::SignalData<void() const>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'borderColor'
        QtMocHelpers::PropertyData<QColor>(5, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'borderWidth'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'radius'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'arrowWidth'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'arrowHeight'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'arrowX'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'arrowY'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'margin'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'arrowDirection'
        QtMocHelpers::PropertyData<enum ArrowDirection>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'shadowXOffset'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'shadowYOffset'
        QtMocHelpers::PropertyData<qreal>(16, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'shadowBlurRadius'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DArrowRectangle, qt_meta_tag_ZN3Dtk6Widget15DArrowRectangleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DArrowRectangle::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DArrowRectangleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DArrowRectangleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget15DArrowRectangleE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DArrowRectangle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DArrowRectangle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->windowDeactivate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DArrowRectangle::*)() const>(_a, &DArrowRectangle::windowDeactivate, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->borderColor(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->borderWidth(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->radius(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->arrowWidth(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->arrowHeight(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->arrowX(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->arrowY(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->margin(); break;
        case 9: *reinterpret_cast<enum ArrowDirection*>(_v) = _t->arrowDirection(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->shadowXOffset(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->shadowYOffset(); break;
        case 12: *reinterpret_cast<qreal*>(_v) = _t->shadowBlurRadius(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 1: _t->setBorderColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setBorderWidth(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setRadius(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setArrowWidth(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setArrowHeight(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setArrowX(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setArrowY(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setMargin(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setArrowDirection(*reinterpret_cast<enum ArrowDirection*>(_v)); break;
        case 10: _t->setShadowXOffset(*reinterpret_cast<qreal*>(_v)); break;
        case 11: _t->setShadowYOffset(*reinterpret_cast<qreal*>(_v)); break;
        case 12: _t->setShadowBlurRadius(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DArrowRectangle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DArrowRectangle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DArrowRectangleE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::DArrowRectangle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DArrowRectangle::windowDeactivate()const
{
    QMetaObject::activate(const_cast< Dtk::Widget::DArrowRectangle *>(this), &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
