/****************************************************************************
** Meta object code from reading C++ file 'dtitlebareditpanel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/widgets/private/dtitlebareditpanel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dtitlebareditpanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget16PlaceHoderWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::PlaceHoderWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget16PlaceHoderWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::PlaceHoderWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlaceHoderWidget, qt_meta_tag_ZN3Dtk6Widget16PlaceHoderWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::PlaceHoderWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget16PlaceHoderWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget16PlaceHoderWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget16PlaceHoderWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::PlaceHoderWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlaceHoderWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Widget::PlaceHoderWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::PlaceHoderWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget16PlaceHoderWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::PlaceHoderWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget14DragDropWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DragDropWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget14DragDropWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DragDropWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DragDropWidget, qt_meta_tag_ZN3Dtk6Widget14DragDropWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DragDropWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DIconButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget14DragDropWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget14DragDropWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget14DragDropWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DragDropWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DragDropWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Widget::DragDropWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DragDropWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget14DragDropWidgetE_t>.strings))
        return static_cast<void*>(this);
    return DIconButton::qt_metacast(_clname);
}

int Dtk::Widget::DragDropWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DIconButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget14IconTextWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::IconTextWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget14IconTextWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::IconTextWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IconTextWidget, qt_meta_tag_ZN3Dtk6Widget14IconTextWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::IconTextWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget14IconTextWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget14IconTextWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget14IconTextWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::IconTextWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IconTextWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Widget::IconTextWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::IconTextWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget14IconTextWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::IconTextWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget15DCollapseWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DCollapseWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget15DCollapseWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DCollapseWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DCollapseWidget, qt_meta_tag_ZN3Dtk6Widget15DCollapseWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DCollapseWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DCollapseWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DCollapseWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget15DCollapseWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DCollapseWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DCollapseWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Widget::DCollapseWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DCollapseWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DCollapseWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::DCollapseWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget21DTitlebarCustomWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DTitlebarCustomWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget21DTitlebarCustomWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DTitlebarCustomWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DTitlebarCustomWidget, qt_meta_tag_ZN3Dtk6Widget21DTitlebarCustomWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DTitlebarCustomWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DCollapseWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget21DTitlebarCustomWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget21DTitlebarCustomWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget21DTitlebarCustomWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DTitlebarCustomWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DTitlebarCustomWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Widget::DTitlebarCustomWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DTitlebarCustomWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget21DTitlebarCustomWidgetE_t>.strings))
        return static_cast<void*>(this);
    return DCollapseWidget::qt_metacast(_clname);
}

int Dtk::Widget::DTitlebarCustomWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DCollapseWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget18DTitlebarEditPanelE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DTitlebarEditPanel::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget18DTitlebarEditPanelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DTitlebarEditPanel",
        "addingToolView",
        "",
        "key",
        "pos",
        "removedToolView",
        "movedToolView",
        "resetToolView",
        "startScreenShot"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addingToolView'
        QtMocHelpers::SignalData<void(const QString &, const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'removedToolView'
        QtMocHelpers::SignalData<void(const QString &, const int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'movedToolView'
        QtMocHelpers::SignalData<void(const QString &, const int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'resetToolView'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startScreenShot'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DTitlebarEditPanel, qt_meta_tag_ZN3Dtk6Widget18DTitlebarEditPanelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DTitlebarEditPanel::staticMetaObject = { {
    QMetaObject::SuperData::link<DCollapseWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget18DTitlebarEditPanelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget18DTitlebarEditPanelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget18DTitlebarEditPanelE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DTitlebarEditPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DTitlebarEditPanel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addingToolView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->removedToolView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->movedToolView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->resetToolView(); break;
        case 4: _t->startScreenShot(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DTitlebarEditPanel::*)(const QString & , const int )>(_a, &DTitlebarEditPanel::addingToolView, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTitlebarEditPanel::*)(const QString & , const int )>(_a, &DTitlebarEditPanel::removedToolView, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTitlebarEditPanel::*)(const QString & , const int )>(_a, &DTitlebarEditPanel::movedToolView, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTitlebarEditPanel::*)()>(_a, &DTitlebarEditPanel::resetToolView, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTitlebarEditPanel::*)()>(_a, &DTitlebarEditPanel::startScreenShot, 4))
            return;
    }
}

const QMetaObject *Dtk::Widget::DTitlebarEditPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DTitlebarEditPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget18DTitlebarEditPanelE_t>.strings))
        return static_cast<void*>(this);
    return DCollapseWidget::qt_metacast(_clname);
}

int Dtk::Widget::DTitlebarEditPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DCollapseWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DTitlebarEditPanel::addingToolView(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Dtk::Widget::DTitlebarEditPanel::removedToolView(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Dtk::Widget::DTitlebarEditPanel::movedToolView(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Dtk::Widget::DTitlebarEditPanel::resetToolView()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Widget::DTitlebarEditPanel::startScreenShot()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget17DToolbarEditPanelE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DToolbarEditPanel::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget17DToolbarEditPanelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DToolbarEditPanel",
        "confirmBtnClicked",
        "",
        "onConfirmBtnClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'confirmBtnClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onConfirmBtnClicked'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DToolbarEditPanel, qt_meta_tag_ZN3Dtk6Widget17DToolbarEditPanelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DToolbarEditPanel::staticMetaObject = { {
    QMetaObject::SuperData::link<DBlurEffectWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget17DToolbarEditPanelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget17DToolbarEditPanelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget17DToolbarEditPanelE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DToolbarEditPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DToolbarEditPanel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->confirmBtnClicked(); break;
        case 1: _t->onConfirmBtnClicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DToolbarEditPanel::*)()>(_a, &DToolbarEditPanel::confirmBtnClicked, 0))
            return;
    }
}

const QMetaObject *Dtk::Widget::DToolbarEditPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DToolbarEditPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget17DToolbarEditPanelE_t>.strings))
        return static_cast<void*>(this);
    return DBlurEffectWidget::qt_metacast(_clname);
}

int Dtk::Widget::DToolbarEditPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DBlurEffectWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DToolbarEditPanel::confirmBtnClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
