/****************************************************************************
** Meta object code from reading C++ file 'dstackwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dstackwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dstackwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget27DSlideStackWidgetTransitionE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DSlideStackWidgetTransition::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget27DSlideStackWidgetTransitionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DSlideStackWidgetTransition",
        "updateVariant",
        "",
        "QVariant",
        "variant"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updateVariant'
        QtMocHelpers::SlotData<void(const QVariant &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DSlideStackWidgetTransition, qt_meta_tag_ZN3Dtk6Widget27DSlideStackWidgetTransitionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DSlideStackWidgetTransition::staticMetaObject = { {
    QMetaObject::SuperData::link<DAbstractStackWidgetTransition::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget27DSlideStackWidgetTransitionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget27DSlideStackWidgetTransitionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget27DSlideStackWidgetTransitionE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DSlideStackWidgetTransition::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DSlideStackWidgetTransition *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateVariant((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Dtk::Widget::DSlideStackWidgetTransition::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DSlideStackWidgetTransition::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget27DSlideStackWidgetTransitionE_t>.strings))
        return static_cast<void*>(this);
    return DAbstractStackWidgetTransition::qt_metacast(_clname);
}

int Dtk::Widget::DSlideStackWidgetTransition::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DAbstractStackWidgetTransition::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget12DStackWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DStackWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget12DStackWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DStackWidget",
        "busyChanged",
        "",
        "busy",
        "depthChanged",
        "depth",
        "currentIndexChanged",
        "currentIndex",
        "currentWidgetChanged",
        "QWidget*",
        "currentWidget",
        "widgetDepthChanged",
        "widget",
        "switchWidgetFinished",
        "pushWidget",
        "enableTransition",
        "insertWidget",
        "index",
        "popWidget",
        "isDelete",
        "count",
        "clear",
        "indexOf",
        "getWidgetByIndex",
        "setTransition",
        "DAbstractStackWidgetTransition*",
        "transition",
        "setAnimationDuration",
        "animationDuration",
        "setAnimationType",
        "QEasingCurve::Type",
        "animationType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'depthChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'currentIndexChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'currentWidgetChanged'
        QtMocHelpers::SignalData<void(QWidget *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'widgetDepthChanged'
        QtMocHelpers::SignalData<void(QWidget *, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'switchWidgetFinished'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pushWidget'
        QtMocHelpers::SlotData<int(QWidget *, bool)>(14, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 9, 12 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'pushWidget'
        QtMocHelpers::SlotData<int(QWidget *)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'insertWidget'
        QtMocHelpers::SlotData<void(int, QWidget *, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 9, 12 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'insertWidget'
        QtMocHelpers::SlotData<void(int, QWidget *)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 9, 12 },
        }}),
        // Slot 'popWidget'
        QtMocHelpers::SlotData<void(QWidget *, bool, int, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 }, { QMetaType::Bool, 19 }, { QMetaType::Int, 20 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'popWidget'
        QtMocHelpers::SlotData<void(QWidget *, bool, int)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 12 }, { QMetaType::Bool, 19 }, { QMetaType::Int, 20 },
        }}),
        // Slot 'popWidget'
        QtMocHelpers::SlotData<void(QWidget *, bool)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 12 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'popWidget'
        QtMocHelpers::SlotData<void(QWidget *)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'popWidget'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'indexOf'
        QtMocHelpers::SlotData<int(QWidget *) const>(22, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Slot 'getWidgetByIndex'
        QtMocHelpers::SlotData<QWidget *(int) const>(23, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setTransition'
        QtMocHelpers::SlotData<void(DAbstractStackWidgetTransition *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'setAnimationDuration'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setAnimationType'
        QtMocHelpers::SlotData<void(QEasingCurve::Type)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'busy'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'depth'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'currentIndex'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'currentWidget'
        QtMocHelpers::PropertyData<QWidget*>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'transition'
        QtMocHelpers::PropertyData<DAbstractStackWidgetTransition*>(26, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'animationDuration'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'animationType'
        QtMocHelpers::PropertyData<QEasingCurve::Type>(31, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DStackWidget, qt_meta_tag_ZN3Dtk6Widget12DStackWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk6Widget12DStackWidgetE[] = {
    QMetaObject::SuperData::link<QEasingCurve::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Widget::DStackWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DStackWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DStackWidgetE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk6Widget12DStackWidgetE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget12DStackWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DStackWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DStackWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->busyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->depthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->currentWidgetChanged((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 4: _t->widgetDepthChanged((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->switchWidgetFinished(); break;
        case 6: { int _r = _t->pushWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->pushWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->insertWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 9: _t->insertWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 10: _t->popWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 11: _t->popWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 12: _t->popWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->popWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 14: _t->popWidget(); break;
        case 15: _t->clear(); break;
        case 16: { int _r = _t->indexOf((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: { QWidget* _r = _t->getWidgetByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QWidget**>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setTransition((*reinterpret_cast<std::add_pointer_t<DAbstractStackWidgetTransition*>>(_a[1]))); break;
        case 19: _t->setAnimationDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setAnimationType((*reinterpret_cast<std::add_pointer_t<QEasingCurve::Type>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DStackWidget::*)(bool )>(_a, &DStackWidget::busyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DStackWidget::*)(int )>(_a, &DStackWidget::depthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DStackWidget::*)(int )>(_a, &DStackWidget::currentIndexChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DStackWidget::*)(QWidget * )>(_a, &DStackWidget::currentWidgetChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DStackWidget::*)(QWidget * , int )>(_a, &DStackWidget::widgetDepthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DStackWidget::*)()>(_a, &DStackWidget::switchWidgetFinished, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->busy(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->depth(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->currentIndex(); break;
        case 3: *reinterpret_cast<QWidget**>(_v) = _t->currentWidget(); break;
        case 4: *reinterpret_cast<DAbstractStackWidgetTransition**>(_v) = _t->transition(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->animationDuration(); break;
        case 6: *reinterpret_cast<QEasingCurve::Type*>(_v) = _t->animationType(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setTransition(*reinterpret_cast<DAbstractStackWidgetTransition**>(_v)); break;
        case 5: _t->setAnimationDuration(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setAnimationType(*reinterpret_cast<QEasingCurve::Type*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DStackWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DStackWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DStackWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::DStackWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DStackWidget::busyChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DStackWidget::depthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Dtk::Widget::DStackWidget::currentIndexChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Dtk::Widget::DStackWidget::currentWidgetChanged(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Dtk::Widget::DStackWidget::widgetDepthChanged(QWidget * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Dtk::Widget::DStackWidget::switchWidgetFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
