/****************************************************************************
** Meta object code from reading C++ file 'dapplication.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dapplication.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DApplication_t {
    QByteArrayData data[18];
    char stringdata0[380];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DApplication_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DApplication_t qt_meta_stringdata_Dtk__Widget__DApplication = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Dtk::Widget::DApplication"
QT_MOC_LITERAL(1, 26, 18), // "newInstanceStarted"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 16), // "iconThemeChanged"
QT_MOC_LITERAL(4, 63, 29), // "screenDevicePixelRatioChanged"
QT_MOC_LITERAL(5, 93, 8), // "QScreen*"
QT_MOC_LITERAL(6, 102, 6), // "screen"
QT_MOC_LITERAL(7, 109, 23), // "_q_onNewInstanceStarted"
QT_MOC_LITERAL(8, 133, 38), // "_q_panWindowContentsForVirtua..."
QT_MOC_LITERAL(9, 172, 41), // "_q_resizeWindowContentsForVir..."
QT_MOC_LITERAL(10, 214, 18), // "_q_sizeModeChanged"
QT_MOC_LITERAL(11, 233, 23), // "visibleMenuShortcutText"
QT_MOC_LITERAL(12, 257, 25), // "visibleMenuCheckboxWidget"
QT_MOC_LITERAL(13, 283, 15), // "visibleMenuIcon"
QT_MOC_LITERAL(14, 299, 19), // "autoActivateWindows"
QT_MOC_LITERAL(15, 319, 22), // "applicationCreditsFile"
QT_MOC_LITERAL(16, 342, 25), // "applicationCreditsContent"
QT_MOC_LITERAL(17, 368, 11) // "licensePath"

    },
    "Dtk::Widget::DApplication\0newInstanceStarted\0"
    "\0iconThemeChanged\0screenDevicePixelRatioChanged\0"
    "QScreen*\0screen\0_q_onNewInstanceStarted\0"
    "_q_panWindowContentsForVirtualKeyboard\0"
    "_q_resizeWindowContentsForVirtualKeyboard\0"
    "_q_sizeModeChanged\0visibleMenuShortcutText\0"
    "visibleMenuCheckboxWidget\0visibleMenuIcon\0"
    "autoActivateWindows\0applicationCreditsFile\0"
    "applicationCreditsContent\0licensePath"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DApplication[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       7,   58, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,
       3,    0,   50,    2, 0x06 /* Public */,
       4,    1,   51,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   54,    2, 0x08 /* Private */,
       8,    0,   55,    2, 0x08 /* Private */,
       9,    0,   56,    2, 0x08 /* Private */,
      10,    0,   57,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      11, QMetaType::Bool, 0x00095103,
      12, QMetaType::Bool, 0x00095103,
      13, QMetaType::Bool, 0x00095103,
      14, QMetaType::Bool, 0x00095103,
      15, QMetaType::QString, 0x00095103,
      16, QMetaType::QByteArray, 0x00095103,
      17, QMetaType::QString, 0x00095103,

       0        // eod
};

void Dtk::Widget::DApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DApplication *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->newInstanceStarted(); break;
        case 1: _t->iconThemeChanged(); break;
        case 2: _t->screenDevicePixelRatioChanged((*reinterpret_cast< QScreen*(*)>(_a[1]))); break;
        case 3: _t->d_func()->_q_onNewInstanceStarted(); break;
        case 4: _t->d_func()->_q_panWindowContentsForVirtualKeyboard(); break;
        case 5: _t->d_func()->_q_resizeWindowContentsForVirtualKeyboard(); break;
        case 6: _t->d_func()->_q_sizeModeChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DApplication::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DApplication::newInstanceStarted)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DApplication::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DApplication::iconThemeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DApplication::*)(QScreen * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DApplication::screenDevicePixelRatioChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DApplication *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->visibleMenuShortcutText(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->visibleMenuCheckboxWidget(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->visibleMenuIcon(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->autoActivateWindows(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->applicationCreditsFile(); break;
        case 5: *reinterpret_cast< QByteArray*>(_v) = _t->applicationCreditsContent(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->licensePath(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DApplication *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisibleMenuShortcutText(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setVisibleMenuCheckboxWidget(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setVisibleMenuIcon(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setAutoActivateWindows(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setApplicationCreditsFile(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setApplicationCreditsContent(*reinterpret_cast< QByteArray*>(_v)); break;
        case 6: _t->setLicensePath(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<QApplication::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DApplication.data,
    qt_meta_data_Dtk__Widget__DApplication,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DApplication.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QApplication::qt_metacast(_clname);
}

int Dtk::Widget::DApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DApplication::newInstanceStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DApplication::iconThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DApplication::screenDevicePixelRatioChanged(QScreen * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
