/****************************************************************************
** Meta object code from reading C++ file 'dblureffectwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dblureffectwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dblureffectwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget17DBlurEffectWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DBlurEffectWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget17DBlurEffectWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DBlurEffectWidget",
        "radiusChanged",
        "",
        "radius",
        "modeChanged",
        "BlurMode",
        "mode",
        "blendModeChanged",
        "BlendMode",
        "blendMode",
        "blurRectXRadiusChanged",
        "blurRectXRadius",
        "blurRectYRadiusChanged",
        "blurRectYRadius",
        "maskAlphaChanged",
        "alpha",
        "maskColorChanged",
        "QColor",
        "maskColor",
        "fullChanged",
        "full",
        "blurEnabledChanged",
        "blurEnabled",
        "blurSourceImageDirtied",
        "setRadius",
        "setMode",
        "setBlendMode",
        "setBlurRectXRadius",
        "setBlurRectYRadius",
        "setMaskAlpha",
        "setMaskColor",
        "MaskColorType",
        "type",
        "setFull",
        "setBlurEnabled",
        "updateBlurSourceImage",
        "QRegion",
        "ren",
        "maskAlpha",
        "GaussianBlur",
        "InWindowBlend",
        "BehindWindowBlend",
        "InWidgetBlend",
        "DarkColor",
        "LightColor",
        "AutoColor",
        "CustomColor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'radiusChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void(enum BlurMode)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'blendModeChanged'
        QtMocHelpers::SignalData<void(enum BlendMode)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'blurRectXRadiusChanged'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'blurRectYRadiusChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'maskAlphaChanged'
        QtMocHelpers::SignalData<void(quint8)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 15 },
        }}),
        // Signal 'maskColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'fullChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Signal 'blurEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'blurSourceImageDirtied'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setRadius'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setMode'
        QtMocHelpers::SlotData<void(enum BlurMode)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setBlendMode'
        QtMocHelpers::SlotData<void(enum BlendMode)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setBlurRectXRadius'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'setBlurRectYRadius'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'setMaskAlpha'
        QtMocHelpers::SlotData<void(quint8)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 15 },
        }}),
        // Slot 'setMaskColor'
        QtMocHelpers::SlotData<void(QColor)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setMaskColor'
        QtMocHelpers::SlotData<void(enum MaskColorType)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'setFull'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'setBlurEnabled'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'updateBlurSourceImage'
        QtMocHelpers::SlotData<void(const QRegion &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'radius'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'mode'
        QtMocHelpers::PropertyData<enum BlurMode>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'blendMode'
        QtMocHelpers::PropertyData<enum BlendMode>(9, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'blurRectXRadius'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'blurRectYRadius'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'maskColor'
        QtMocHelpers::PropertyData<QColor>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'maskAlpha'
        QtMocHelpers::PropertyData<quint8>(38, QMetaType::UChar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'full'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'blurEnabled'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'BlurMode'
        QtMocHelpers::EnumData<enum BlurMode>(5, 5, QMC::EnumFlags{}).add({
            {   39, BlurMode::GaussianBlur },
        }),
        // enum 'BlendMode'
        QtMocHelpers::EnumData<enum BlendMode>(8, 8, QMC::EnumFlags{}).add({
            {   40, BlendMode::InWindowBlend },
            {   41, BlendMode::BehindWindowBlend },
            {   42, BlendMode::InWidgetBlend },
        }),
        // enum 'MaskColorType'
        QtMocHelpers::EnumData<enum MaskColorType>(31, 31, QMC::EnumFlags{}).add({
            {   43, MaskColorType::DarkColor },
            {   44, MaskColorType::LightColor },
            {   45, MaskColorType::AutoColor },
            {   46, MaskColorType::CustomColor },
        }),
    };
    return QtMocHelpers::metaObjectData<DBlurEffectWidget, qt_meta_tag_ZN3Dtk6Widget17DBlurEffectWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DBlurEffectWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget17DBlurEffectWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget17DBlurEffectWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget17DBlurEffectWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DBlurEffectWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBlurEffectWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->radiusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<enum BlurMode>>(_a[1]))); break;
        case 2: _t->blendModeChanged((*reinterpret_cast<std::add_pointer_t<enum BlendMode>>(_a[1]))); break;
        case 3: _t->blurRectXRadiusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->blurRectYRadiusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->maskAlphaChanged((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1]))); break;
        case 6: _t->maskColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 7: _t->fullChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->blurEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->blurSourceImageDirtied(); break;
        case 10: _t->setRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setMode((*reinterpret_cast<std::add_pointer_t<enum BlurMode>>(_a[1]))); break;
        case 12: _t->setBlendMode((*reinterpret_cast<std::add_pointer_t<enum BlendMode>>(_a[1]))); break;
        case 13: _t->setBlurRectXRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setBlurRectYRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->setMaskAlpha((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1]))); break;
        case 16: _t->setMaskColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 17: _t->setMaskColor((*reinterpret_cast<std::add_pointer_t<enum MaskColorType>>(_a[1]))); break;
        case 18: _t->setFull((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setBlurEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->updateBlurSourceImage((*reinterpret_cast<std::add_pointer_t<QRegion>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)(int )>(_a, &DBlurEffectWidget::radiusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)(BlurMode )>(_a, &DBlurEffectWidget::modeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)(BlendMode )>(_a, &DBlurEffectWidget::blendModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)(int )>(_a, &DBlurEffectWidget::blurRectXRadiusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)(int )>(_a, &DBlurEffectWidget::blurRectYRadiusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)(quint8 )>(_a, &DBlurEffectWidget::maskAlphaChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)(QColor )>(_a, &DBlurEffectWidget::maskColorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)(bool )>(_a, &DBlurEffectWidget::fullChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)(bool )>(_a, &DBlurEffectWidget::blurEnabledChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlurEffectWidget::*)()>(_a, &DBlurEffectWidget::blurSourceImageDirtied, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->radius(); break;
        case 1: *reinterpret_cast<enum BlurMode*>(_v) = _t->mode(); break;
        case 2: *reinterpret_cast<enum BlendMode*>(_v) = _t->blendMode(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->blurRectXRadius(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->blurRectYRadius(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->maskColor(); break;
        case 6: *reinterpret_cast<quint8*>(_v) = _t->maskAlpha(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isFull(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->blurEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRadius(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setMode(*reinterpret_cast<enum BlurMode*>(_v)); break;
        case 2: _t->setBlendMode(*reinterpret_cast<enum BlendMode*>(_v)); break;
        case 3: _t->setBlurRectXRadius(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setBlurRectYRadius(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setMaskColor(*reinterpret_cast<QColor*>(_v)); break;
        case 6: _t->setMaskAlpha(*reinterpret_cast<quint8*>(_v)); break;
        case 7: _t->setFull(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setBlurEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DBlurEffectWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DBlurEffectWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget17DBlurEffectWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::DBlurEffectWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DBlurEffectWidget::radiusChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DBlurEffectWidget::modeChanged(BlurMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Dtk::Widget::DBlurEffectWidget::blendModeChanged(BlendMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Dtk::Widget::DBlurEffectWidget::blurRectXRadiusChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Dtk::Widget::DBlurEffectWidget::blurRectYRadiusChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Dtk::Widget::DBlurEffectWidget::maskAlphaChanged(quint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Dtk::Widget::DBlurEffectWidget::maskColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Dtk::Widget::DBlurEffectWidget::fullChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Dtk::Widget::DBlurEffectWidget::blurEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Dtk::Widget::DBlurEffectWidget::blurSourceImageDirtied()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
