/****************************************************************************
** Meta object code from reading C++ file 'dlistview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dlistview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dlistview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DListView_t {
    QByteArrayData data[45];
    char stringdata0[561];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DListView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DListView_t qt_meta_stringdata_Dtk__Widget__DListView = {
    {
QT_MOC_LITERAL(0, 0, 22), // "Dtk::Widget::DListView"
QT_MOC_LITERAL(1, 23, 15), // "rowCountChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 18), // "orientationChanged"
QT_MOC_LITERAL(4, 59, 15), // "Qt::Orientation"
QT_MOC_LITERAL(5, 75, 11), // "orientation"
QT_MOC_LITERAL(6, 87, 14), // "currentChanged"
QT_MOC_LITERAL(7, 102, 11), // "QModelIndex"
QT_MOC_LITERAL(8, 114, 8), // "previous"
QT_MOC_LITERAL(9, 123, 11), // "triggerEdit"
QT_MOC_LITERAL(10, 135, 5), // "index"
QT_MOC_LITERAL(11, 141, 7), // "addItem"
QT_MOC_LITERAL(12, 149, 4), // "data"
QT_MOC_LITERAL(13, 154, 8), // "addItems"
QT_MOC_LITERAL(14, 163, 5), // "datas"
QT_MOC_LITERAL(15, 169, 10), // "insertItem"
QT_MOC_LITERAL(16, 180, 11), // "insertItems"
QT_MOC_LITERAL(17, 192, 10), // "removeItem"
QT_MOC_LITERAL(18, 203, 11), // "removeItems"
QT_MOC_LITERAL(19, 215, 5), // "count"
QT_MOC_LITERAL(20, 221, 15), // "addHeaderWidget"
QT_MOC_LITERAL(21, 237, 8), // "QWidget*"
QT_MOC_LITERAL(22, 246, 6), // "widget"
QT_MOC_LITERAL(23, 253, 18), // "removeHeaderWidget"
QT_MOC_LITERAL(24, 272, 16), // "takeHeaderWidget"
QT_MOC_LITERAL(25, 289, 15), // "addFooterWidget"
QT_MOC_LITERAL(26, 305, 18), // "removeFooterWidget"
QT_MOC_LITERAL(27, 324, 16), // "takeFooterWidget"
QT_MOC_LITERAL(28, 341, 14), // "setOrientation"
QT_MOC_LITERAL(29, 356, 15), // "QListView::Flow"
QT_MOC_LITERAL(30, 372, 4), // "flow"
QT_MOC_LITERAL(31, 377, 8), // "wrapping"
QT_MOC_LITERAL(32, 386, 4), // "edit"
QT_MOC_LITERAL(33, 391, 17), // "setBackgroundType"
QT_MOC_LITERAL(34, 409, 35), // "DStyledItemDelegate::Backgrou..."
QT_MOC_LITERAL(35, 445, 14), // "backgroundType"
QT_MOC_LITERAL(36, 460, 14), // "setItemMargins"
QT_MOC_LITERAL(37, 475, 8), // "QMargins"
QT_MOC_LITERAL(38, 484, 11), // "itemMargins"
QT_MOC_LITERAL(39, 496, 11), // "setItemSize"
QT_MOC_LITERAL(40, 508, 8), // "itemSize"
QT_MOC_LITERAL(41, 517, 14), // "setItemSpacing"
QT_MOC_LITERAL(42, 532, 7), // "spacing"
QT_MOC_LITERAL(43, 540, 13), // "setItemRadius"
QT_MOC_LITERAL(44, 554, 6) // "radius"

    },
    "Dtk::Widget::DListView\0rowCountChanged\0"
    "\0orientationChanged\0Qt::Orientation\0"
    "orientation\0currentChanged\0QModelIndex\0"
    "previous\0triggerEdit\0index\0addItem\0"
    "data\0addItems\0datas\0insertItem\0"
    "insertItems\0removeItem\0removeItems\0"
    "count\0addHeaderWidget\0QWidget*\0widget\0"
    "removeHeaderWidget\0takeHeaderWidget\0"
    "addFooterWidget\0removeFooterWidget\0"
    "takeFooterWidget\0setOrientation\0"
    "QListView::Flow\0flow\0wrapping\0edit\0"
    "setBackgroundType\0DStyledItemDelegate::BackgroundType\0"
    "backgroundType\0setItemMargins\0QMargins\0"
    "itemMargins\0setItemSize\0itemSize\0"
    "setItemSpacing\0spacing\0setItemRadius\0"
    "radius"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DListView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      23,   14, // methods
       5,  204, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  129,    2, 0x06 /* Public */,
       3,    1,  130,    2, 0x06 /* Public */,
       6,    1,  133,    2, 0x06 /* Public */,
       9,    1,  136,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    1,  139,    2, 0x0a /* Public */,
      13,    1,  142,    2, 0x0a /* Public */,
      15,    2,  145,    2, 0x0a /* Public */,
      16,    2,  150,    2, 0x0a /* Public */,
      17,    1,  155,    2, 0x0a /* Public */,
      18,    2,  158,    2, 0x0a /* Public */,
      20,    1,  163,    2, 0x0a /* Public */,
      23,    1,  166,    2, 0x0a /* Public */,
      24,    1,  169,    2, 0x0a /* Public */,
      25,    1,  172,    2, 0x0a /* Public */,
      26,    1,  175,    2, 0x0a /* Public */,
      27,    1,  178,    2, 0x0a /* Public */,
      28,    2,  181,    2, 0x0a /* Public */,
      32,    1,  186,    2, 0x0a /* Public */,
      33,    1,  189,    2, 0x0a /* Public */,
      36,    1,  192,    2, 0x0a /* Public */,
      39,    1,  195,    2, 0x0a /* Public */,
      41,    1,  198,    2, 0x0a /* Public */,
      43,    1,  201,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,   10,

 // slots: parameters
    QMetaType::Bool, QMetaType::QVariant,   12,
    QMetaType::Bool, QMetaType::QVariantList,   14,
    QMetaType::Bool, QMetaType::Int, QMetaType::QVariant,   10,   12,
    QMetaType::Bool, QMetaType::Int, QMetaType::QVariantList,   10,   14,
    QMetaType::Bool, QMetaType::Int,   10,
    QMetaType::Bool, QMetaType::Int, QMetaType::Int,   10,   19,
    QMetaType::Int, 0x80000000 | 21,   22,
    QMetaType::Void, QMetaType::Int,   10,
    0x80000000 | 21, QMetaType::Int,   10,
    QMetaType::Int, 0x80000000 | 21,   22,
    QMetaType::Void, QMetaType::Int,   10,
    0x80000000 | 21, QMetaType::Int,   10,
    QMetaType::Void, 0x80000000 | 29, QMetaType::Bool,   30,   31,
    QMetaType::Void, 0x80000000 | 7,   10,
    QMetaType::Void, 0x80000000 | 34,   35,
    QMetaType::Void, 0x80000000 | 37,   38,
    QMetaType::Void, QMetaType::QSize,   40,
    QMetaType::Void, QMetaType::Int,   42,
    QMetaType::Void, QMetaType::Int,   44,

 // properties: name, type, flags
      19, QMetaType::Int, 0x00495001,
       5, 0x80000000 | 4, 0x00495009,
      35, 0x80000000 | 34, 0x0009510b,
      38, 0x80000000 | 37, 0x0009510b,
      40, QMetaType::QSize, 0x00095103,

 // properties: notify_signal_id
       0,
       1,
       0,
       0,
       0,

       0        // eod
};

void Dtk::Widget::DListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DListView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->rowCountChanged(); break;
        case 1: _t->orientationChanged((*reinterpret_cast< Qt::Orientation(*)>(_a[1]))); break;
        case 2: _t->currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 3: _t->triggerEdit((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 4: { bool _r = _t->addItem((*reinterpret_cast< const QVariant(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->addItems((*reinterpret_cast< const QVariantList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->insertItem((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->insertItems((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QVariantList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->removeItem((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->removeItems((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->addHeaderWidget((*reinterpret_cast< QWidget*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->removeHeaderWidget((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: { QWidget* _r = _t->takeHeaderWidget((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->addFooterWidget((*reinterpret_cast< QWidget*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->removeFooterWidget((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: { QWidget* _r = _t->takeFooterWidget((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWidget**>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setOrientation((*reinterpret_cast< QListView::Flow(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 17: _t->edit((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 18: _t->setBackgroundType((*reinterpret_cast< DStyledItemDelegate::BackgroundType(*)>(_a[1]))); break;
        case 19: _t->setItemMargins((*reinterpret_cast< const QMargins(*)>(_a[1]))); break;
        case 20: _t->setItemSize((*reinterpret_cast< QSize(*)>(_a[1]))); break;
        case 21: _t->setItemSpacing((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->setItemRadius((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DListView::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DListView::rowCountChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DListView::*)(Qt::Orientation );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DListView::orientationChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DListView::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DListView::currentChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DListView::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DListView::triggerEdit)) {
                *result = 3;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DListView *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->count(); break;
        case 1: *reinterpret_cast< Qt::Orientation*>(_v) = _t->orientation(); break;
        case 2: *reinterpret_cast< DStyledItemDelegate::BackgroundType*>(_v) = _t->backgroundType(); break;
        case 3: *reinterpret_cast< QMargins*>(_v) = _t->itemMargins(); break;
        case 4: *reinterpret_cast< QSize*>(_v) = _t->itemSize(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DListView *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setBackgroundType(*reinterpret_cast< DStyledItemDelegate::BackgroundType*>(_v)); break;
        case 3: _t->setItemMargins(*reinterpret_cast< QMargins*>(_v)); break;
        case 4: _t->setItemSize(*reinterpret_cast< QSize*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Widget__DListView[] = {
    QMetaObject::SuperData::link<Dtk::Widget::DStyledItemDelegate::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DListView::staticMetaObject = { {
    QMetaObject::SuperData::link<QListView::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DListView.data,
    qt_meta_data_Dtk__Widget__DListView,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Widget__DListView,
    nullptr
} };


const QMetaObject *Dtk::Widget::DListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DListView.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QListView::qt_metacast(_clname);
}

int Dtk::Widget::DListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DListView::rowCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DListView::orientationChanged(Qt::Orientation _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Widget::DListView::currentChanged(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Widget::DListView::triggerEdit(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
