/****************************************************************************
** Meta object code from reading C++ file 'dsplitscreen_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/widgets/private/dsplitscreen_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dsplitscreen_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DSplitScreenPlaceholder_t {
    QByteArrayData data[7];
    char stringdata0[81];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DSplitScreenPlaceholder_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DSplitScreenPlaceholder_t qt_meta_stringdata_Dtk__Widget__DSplitScreenPlaceholder = {
    {
QT_MOC_LITERAL(0, 0, 36), // "Dtk::Widget::DSplitScreenPlac..."
QT_MOC_LITERAL(1, 37, 8), // "Position"
QT_MOC_LITERAL(2, 46, 12), // "PositionFlag"
QT_MOC_LITERAL(3, 59, 4), // "Left"
QT_MOC_LITERAL(4, 64, 5), // "Right"
QT_MOC_LITERAL(5, 70, 3), // "Top"
QT_MOC_LITERAL(6, 74, 6) // "Bottom"

    },
    "Dtk::Widget::DSplitScreenPlaceholder\0"
    "Position\0PositionFlag\0Left\0Right\0Top\0"
    "Bottom"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DSplitScreenPlaceholder[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       1,   14, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // enums: name, alias, flags, count, data
       1,    2, 0x1,    4,   19,

 // enum data: key, value
       3, uint(Dtk::Widget::DSplitScreenPlaceholder::Left),
       4, uint(Dtk::Widget::DSplitScreenPlaceholder::Right),
       5, uint(Dtk::Widget::DSplitScreenPlaceholder::Top),
       6, uint(Dtk::Widget::DSplitScreenPlaceholder::Bottom),

       0        // eod
};

void Dtk::Widget::DSplitScreenPlaceholder::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DSplitScreenPlaceholder::staticMetaObject = { {
    QMetaObject::SuperData::link<DPushButton::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DSplitScreenPlaceholder.data,
    qt_meta_data_Dtk__Widget__DSplitScreenPlaceholder,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DSplitScreenPlaceholder::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DSplitScreenPlaceholder::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DSplitScreenPlaceholder.stringdata0))
        return static_cast<void*>(this);
    return DPushButton::qt_metacast(_clname);
}

int Dtk::Widget::DSplitScreenPlaceholder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DPushButton::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Widget__DSplitScreenCell_t {
    QByteArrayData data[17];
    char stringdata0[240];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DSplitScreenCell_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DSplitScreenCell_t qt_meta_stringdata_Dtk__Widget__DSplitScreenCell = {
    {
QT_MOC_LITERAL(0, 0, 29), // "Dtk::Widget::DSplitScreenCell"
QT_MOC_LITERAL(1, 30, 14), // "screenSelected"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 22), // "DSplitScreenCell::Mode"
QT_MOC_LITERAL(4, 69, 4), // "type"
QT_MOC_LITERAL(5, 74, 33), // "DSplitScreenPlaceholder::Posi..."
QT_MOC_LITERAL(6, 108, 8), // "position"
QT_MOC_LITERAL(7, 117, 27), // "onScreenPlaceholderSelected"
QT_MOC_LITERAL(8, 145, 4), // "Mode"
QT_MOC_LITERAL(9, 150, 8), // "ModeFlag"
QT_MOC_LITERAL(10, 159, 8), // "TwoSplit"
QT_MOC_LITERAL(11, 168, 10), // "ThreeSplit"
QT_MOC_LITERAL(12, 179, 9), // "FourSplit"
QT_MOC_LITERAL(13, 189, 15), // "SupportTwoSplit"
QT_MOC_LITERAL(14, 205, 16), // "SupportFourSplit"
QT_MOC_LITERAL(15, 222, 12), // "PositionType"
QT_MOC_LITERAL(16, 235, 4) // "Left"

    },
    "Dtk::Widget::DSplitScreenCell\0"
    "screenSelected\0\0DSplitScreenCell::Mode\0"
    "type\0DSplitScreenPlaceholder::Position\0"
    "position\0onScreenPlaceholderSelected\0"
    "Mode\0ModeFlag\0TwoSplit\0ThreeSplit\0"
    "FourSplit\0SupportTwoSplit\0SupportFourSplit\0"
    "PositionType\0Left"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DSplitScreenCell[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       1,   30, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   29,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,

 // slots: parameters
    QMetaType::Void,

 // enums: name, alias, flags, count, data
       8,    9, 0x1,    7,   35,

 // enum data: key, value
      10, uint(Dtk::Widget::DSplitScreenCell::TwoSplit),
      11, uint(Dtk::Widget::DSplitScreenCell::ThreeSplit),
      12, uint(Dtk::Widget::DSplitScreenCell::FourSplit),
      13, uint(Dtk::Widget::DSplitScreenCell::SupportTwoSplit),
      14, uint(Dtk::Widget::DSplitScreenCell::SupportFourSplit),
      15, uint(Dtk::Widget::DSplitScreenCell::PositionType),
      16, uint(Dtk::Widget::DSplitScreenCell::Left),

       0        // eod
};

void Dtk::Widget::DSplitScreenCell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DSplitScreenCell *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->screenSelected((*reinterpret_cast< DSplitScreenCell::Mode(*)>(_a[1])),(*reinterpret_cast< DSplitScreenPlaceholder::Position(*)>(_a[2]))); break;
        case 1: _t->onScreenPlaceholderSelected(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DSplitScreenCell::*)(DSplitScreenCell::Mode , DSplitScreenPlaceholder::Position );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DSplitScreenCell::screenSelected)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DSplitScreenCell::staticMetaObject = { {
    QMetaObject::SuperData::link<DFrame::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DSplitScreenCell.data,
    qt_meta_data_Dtk__Widget__DSplitScreenCell,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DSplitScreenCell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DSplitScreenCell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DSplitScreenCell.stringdata0))
        return static_cast<void*>(this);
    return DFrame::qt_metacast(_clname);
}

int Dtk::Widget::DSplitScreenCell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DSplitScreenCell::screenSelected(DSplitScreenCell::Mode _t1, DSplitScreenPlaceholder::Position _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_Dtk__Widget__DSplitScreenWidget_t {
    QByteArrayData data[10];
    char stringdata0[181];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DSplitScreenWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DSplitScreenWidget_t qt_meta_stringdata_Dtk__Widget__DSplitScreenWidget = {
    {
QT_MOC_LITERAL(0, 0, 31), // "Dtk::Widget::DSplitScreenWidget"
QT_MOC_LITERAL(1, 32, 18), // "onThemeTypeChanged"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 37), // "Gui::DGuiApplicationHelper::C..."
QT_MOC_LITERAL(4, 90, 2), // "ct"
QT_MOC_LITERAL(5, 93, 16), // "onScreenSelected"
QT_MOC_LITERAL(6, 110, 22), // "DSplitScreenCell::Mode"
QT_MOC_LITERAL(7, 133, 4), // "type"
QT_MOC_LITERAL(8, 138, 33), // "DSplitScreenPlaceholder::Posi..."
QT_MOC_LITERAL(9, 172, 8) // "position"

    },
    "Dtk::Widget::DSplitScreenWidget\0"
    "onThemeTypeChanged\0\0"
    "Gui::DGuiApplicationHelper::ColorType\0"
    "ct\0onScreenSelected\0DSplitScreenCell::Mode\0"
    "type\0DSplitScreenPlaceholder::Position\0"
    "position"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DSplitScreenWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x08 /* Private */,
       5,    2,   27,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 8,    7,    9,

       0        // eod
};

void Dtk::Widget::DSplitScreenWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DSplitScreenWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->onThemeTypeChanged((*reinterpret_cast< Gui::DGuiApplicationHelper::ColorType(*)>(_a[1]))); break;
        case 1: _t->onScreenSelected((*reinterpret_cast< DSplitScreenCell::Mode(*)>(_a[1])),(*reinterpret_cast< DSplitScreenPlaceholder::Position(*)>(_a[2]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DSplitScreenWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DBlurEffectWidget::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DSplitScreenWidget.data,
    qt_meta_data_Dtk__Widget__DSplitScreenWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DSplitScreenWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DSplitScreenWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DSplitScreenWidget.stringdata0))
        return static_cast<void*>(this);
    return DBlurEffectWidget::qt_metacast(_clname);
}

int Dtk::Widget::DSplitScreenWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DBlurEffectWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
