/****************************************************************************
** Meta object code from reading C++ file 'dprintpreviewdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dprintpreviewdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dprintpreviewdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DPrintPreviewDialog_t {
    QByteArrayData data[25];
    char stringdata0[510];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DPrintPreviewDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DPrintPreviewDialog_t qt_meta_stringdata_Dtk__Widget__DPrintPreviewDialog = {
    {
QT_MOC_LITERAL(0, 0, 32), // "Dtk::Widget::DPrintPreviewDialog"
QT_MOC_LITERAL(1, 33, 14), // "paintRequested"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 9), // "DPrinter*"
QT_MOC_LITERAL(4, 59, 7), // "printer"
QT_MOC_LITERAL(5, 67, 12), // "QVector<int>"
QT_MOC_LITERAL(6, 80, 9), // "pageRange"
QT_MOC_LITERAL(7, 90, 17), // "_q_printerChanged"
QT_MOC_LITERAL(8, 108, 19), // "_q_pageRangeChanged"
QT_MOC_LITERAL(9, 128, 20), // "_q_pageMarginChanged"
QT_MOC_LITERAL(10, 149, 18), // "_q_ColorModeChange"
QT_MOC_LITERAL(11, 168, 13), // "_q_startPrint"
QT_MOC_LITERAL(12, 182, 21), // "_q_orientationChanged"
QT_MOC_LITERAL(13, 204, 22), // "_q_customPagesFinished"
QT_MOC_LITERAL(14, 227, 20), // "_q_marginspinChanged"
QT_MOC_LITERAL(15, 248, 21), // "_q_marginEditFinished"
QT_MOC_LITERAL(16, 270, 25), // "_q_currentPageSpinChanged"
QT_MOC_LITERAL(17, 296, 20), // "_q_checkStateChanged"
QT_MOC_LITERAL(18, 317, 27), // "_q_textWaterMarkModeChanged"
QT_MOC_LITERAL(19, 345, 30), // "_q_customTextWatermarkFinished"
QT_MOC_LITERAL(20, 376, 20), // "_q_colorButtonCliked"
QT_MOC_LITERAL(21, 397, 20), // "_q_selectColorButton"
QT_MOC_LITERAL(22, 418, 32), // "_q_pagePersheetComboIndexChanged"
QT_MOC_LITERAL(23, 451, 30), // "_q_printOrderComboIndexChanged"
QT_MOC_LITERAL(24, 482, 27) // "_q_spinboxValueEmptyChecked"

    },
    "Dtk::Widget::DPrintPreviewDialog\0"
    "paintRequested\0\0DPrinter*\0printer\0"
    "QVector<int>\0pageRange\0_q_printerChanged\0"
    "_q_pageRangeChanged\0_q_pageMarginChanged\0"
    "_q_ColorModeChange\0_q_startPrint\0"
    "_q_orientationChanged\0_q_customPagesFinished\0"
    "_q_marginspinChanged\0_q_marginEditFinished\0"
    "_q_currentPageSpinChanged\0"
    "_q_checkStateChanged\0_q_textWaterMarkModeChanged\0"
    "_q_customTextWatermarkFinished\0"
    "_q_colorButtonCliked\0_q_selectColorButton\0"
    "_q_pagePersheetComboIndexChanged\0"
    "_q_printOrderComboIndexChanged\0"
    "_q_spinboxValueEmptyChecked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DPrintPreviewDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  114,    2, 0x06 /* Public */,
       1,    2,  117,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,  122,    2, 0x08 /* Private */,
       8,    1,  125,    2, 0x08 /* Private */,
       9,    1,  128,    2, 0x08 /* Private */,
      10,    1,  131,    2, 0x08 /* Private */,
      11,    1,  134,    2, 0x08 /* Private */,
      12,    1,  137,    2, 0x08 /* Private */,
      13,    0,  140,    2, 0x08 /* Private */,
      14,    1,  141,    2, 0x08 /* Private */,
      15,    0,  144,    2, 0x08 /* Private */,
      16,    1,  145,    2, 0x08 /* Private */,
      17,    1,  148,    2, 0x08 /* Private */,
      18,    1,  151,    2, 0x08 /* Private */,
      19,    0,  154,    2, 0x08 /* Private */,
      20,    1,  155,    2, 0x08 /* Private */,
      21,    1,  158,    2, 0x08 /* Private */,
      22,    1,  161,    2, 0x08 /* Private */,
      23,    1,  164,    2, 0x08 /* Private */,
      24,    1,  167,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QColor,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void Dtk::Widget::DPrintPreviewDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DPrintPreviewDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->paintRequested((*reinterpret_cast< DPrinter*(*)>(_a[1]))); break;
        case 1: _t->paintRequested((*reinterpret_cast< DPrinter*(*)>(_a[1])),(*reinterpret_cast< const QVector<int>(*)>(_a[2]))); break;
        case 2: _t->d_func()->_q_printerChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->d_func()->_q_pageRangeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->d_func()->_q_pageMarginChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->d_func()->_q_ColorModeChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->d_func()->_q_startPrint((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->d_func()->_q_orientationChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->d_func()->_q_customPagesFinished(); break;
        case 9: _t->d_func()->_q_marginspinChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 10: _t->d_func()->_q_marginEditFinished(); break;
        case 11: _t->d_func()->_q_currentPageSpinChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->d_func()->_q_checkStateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->d_func()->_q_textWaterMarkModeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->d_func()->_q_customTextWatermarkFinished(); break;
        case 15: _t->d_func()->_q_colorButtonCliked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->d_func()->_q_selectColorButton((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 17: _t->d_func()->_q_pagePersheetComboIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->d_func()->_q_printOrderComboIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->d_func()->_q_spinboxValueEmptyChecked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<int> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DPrintPreviewDialog::*)(DPrinter * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPrintPreviewDialog::paintRequested)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DPrintPreviewDialog::*)(DPrinter * , const QVector<int> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DPrintPreviewDialog::paintRequested)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DPrintPreviewDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<DDialog::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DPrintPreviewDialog.data,
    qt_meta_data_Dtk__Widget__DPrintPreviewDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DPrintPreviewDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DPrintPreviewDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DPrintPreviewDialog.stringdata0))
        return static_cast<void*>(this);
    return DDialog::qt_metacast(_clname);
}

int Dtk::Widget::DPrintPreviewDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DPrintPreviewDialog::paintRequested(DPrinter * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Widget::DPrintPreviewDialog::paintRequested(DPrinter * _t1, const QVector<int> & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
