/****************************************************************************
** Meta object code from reading C++ file 'dtabbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dtabbar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dtabbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget7DTabBarE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DTabBar::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget7DTabBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DTabBar",
        "currentChanged",
        "",
        "index",
        "tabCloseRequested",
        "tabMoved",
        "from",
        "to",
        "tabIsInserted",
        "tabIsRemoved",
        "tabBarClicked",
        "tabBarDoubleClicked",
        "tabAddRequested",
        "tabReleaseRequested",
        "tabDroped",
        "Qt::DropAction",
        "action",
        "target",
        "dragActionChanged",
        "dragStarted",
        "dragEnd",
        "setCurrentIndex",
        "setVisibleAddButton",
        "visibleAddButton",
        "setStartDragDistance",
        "startDragDistance",
        "setMaskColor",
        "QColor",
        "maskColor",
        "setFlashColor",
        "flashColor",
        "startDrag",
        "stopDrag",
        "shape",
        "QTabBar::Shape",
        "currentIndex",
        "count",
        "drawBase",
        "iconSize",
        "QSize",
        "elideMode",
        "Qt::TextElideMode",
        "usesScrollButtons",
        "tabsClosable",
        "selectionBehaviorOnRemove",
        "QTabBar::SelectionBehavior",
        "expanding",
        "movable",
        "dragable",
        "documentMode",
        "autoHide",
        "changeCurrentOnDrag"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'tabCloseRequested'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'tabMoved'
        QtMocHelpers::SignalData<void(int, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'tabIsInserted'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'tabIsRemoved'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'tabBarClicked'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'tabBarDoubleClicked'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'tabAddRequested'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabReleaseRequested'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'tabDroped'
        QtMocHelpers::SignalData<void(int, Qt::DropAction, QObject *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 15, 16 }, { QMetaType::QObjectStar, 17 },
        }}),
        // Signal 'dragActionChanged'
        QtMocHelpers::SignalData<void(Qt::DropAction)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'dragStarted'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragEnd'
        QtMocHelpers::SignalData<void(Qt::DropAction)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setCurrentIndex'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setVisibleAddButton'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setStartDragDistance'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Slot 'setMaskColor'
        QtMocHelpers::SlotData<void(QColor)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'setFlashColor'
        QtMocHelpers::SlotData<void(QColor)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 30 },
        }}),
        // Slot 'startDrag'
        QtMocHelpers::SlotData<void(int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'stopDrag'
        QtMocHelpers::SlotData<void(Qt::DropAction)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'visibleAddButton'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'shape'
        QtMocHelpers::PropertyData<QTabBar::Shape>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'currentIndex'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'count'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'drawBase'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'iconSize'
        QtMocHelpers::PropertyData<QSize>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'elideMode'
        QtMocHelpers::PropertyData<Qt::TextElideMode>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'usesScrollButtons'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'tabsClosable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'selectionBehaviorOnRemove'
        QtMocHelpers::PropertyData<QTabBar::SelectionBehavior>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'expanding'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'movable'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'dragable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'documentMode'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'autoHide'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'changeCurrentOnDrag'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'startDragDistance'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'maskColor'
        QtMocHelpers::PropertyData<QColor>(28, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'flashColor'
        QtMocHelpers::PropertyData<QColor>(30, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DTabBar, qt_meta_tag_ZN3Dtk6Widget7DTabBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk6Widget7DTabBarE[] = {
    QMetaObject::SuperData::link<QTabBar::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Widget::DTabBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget7DTabBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget7DTabBarE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk6Widget7DTabBarE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget7DTabBarE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DTabBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DTabBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->tabCloseRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->tabMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->tabIsInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->tabIsRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->tabBarClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->tabBarDoubleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->tabAddRequested(); break;
        case 8: _t->tabReleaseRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->tabDroped((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::DropAction>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[3]))); break;
        case 10: _t->dragActionChanged((*reinterpret_cast<std::add_pointer_t<Qt::DropAction>>(_a[1]))); break;
        case 11: _t->dragStarted(); break;
        case 12: _t->dragEnd((*reinterpret_cast<std::add_pointer_t<Qt::DropAction>>(_a[1]))); break;
        case 13: _t->setCurrentIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setVisibleAddButton((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->setStartDragDistance((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->setMaskColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 17: _t->setFlashColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 18: _t->startDrag((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->stopDrag((*reinterpret_cast<std::add_pointer_t<Qt::DropAction>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(int )>(_a, &DTabBar::currentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(int )>(_a, &DTabBar::tabCloseRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(int , int )>(_a, &DTabBar::tabMoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(int )>(_a, &DTabBar::tabIsInserted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(int )>(_a, &DTabBar::tabIsRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(int )>(_a, &DTabBar::tabBarClicked, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(int )>(_a, &DTabBar::tabBarDoubleClicked, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)()>(_a, &DTabBar::tabAddRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(int )>(_a, &DTabBar::tabReleaseRequested, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(int , Qt::DropAction , QObject * )>(_a, &DTabBar::tabDroped, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(Qt::DropAction )>(_a, &DTabBar::dragActionChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)()>(_a, &DTabBar::dragStarted, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DTabBar::*)(Qt::DropAction )>(_a, &DTabBar::dragEnd, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->visibleAddButton(); break;
        case 1: *reinterpret_cast<QTabBar::Shape*>(_v) = _t->shape(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->currentIndex(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->drawBase(); break;
        case 5: *reinterpret_cast<QSize*>(_v) = _t->iconSize(); break;
        case 6: *reinterpret_cast<Qt::TextElideMode*>(_v) = _t->elideMode(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->usesScrollButtons(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->tabsClosable(); break;
        case 9: *reinterpret_cast<QTabBar::SelectionBehavior*>(_v) = _t->selectionBehaviorOnRemove(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->expanding(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isMovable(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isDragable(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->documentMode(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->autoHide(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->changeCurrentOnDrag(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->startDragDistance(); break;
        case 17: *reinterpret_cast<QColor*>(_v) = _t->maskColor(); break;
        case 18: *reinterpret_cast<QColor*>(_v) = _t->flashColor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisibleAddButton(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setShape(*reinterpret_cast<QTabBar::Shape*>(_v)); break;
        case 2: _t->setCurrentIndex(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setDrawBase(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setIconSize(*reinterpret_cast<QSize*>(_v)); break;
        case 6: _t->setElideMode(*reinterpret_cast<Qt::TextElideMode*>(_v)); break;
        case 7: _t->setUsesScrollButtons(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setTabsClosable(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setSelectionBehaviorOnRemove(*reinterpret_cast<QTabBar::SelectionBehavior*>(_v)); break;
        case 10: _t->setExpanding(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setMovable(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setDragable(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setDocumentMode(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setAutoHide(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setChangeCurrentOnDrag(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setStartDragDistance(*reinterpret_cast<int*>(_v)); break;
        case 17: _t->setMaskColor(*reinterpret_cast<QColor*>(_v)); break;
        case 18: _t->setFlashColor(*reinterpret_cast<QColor*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DTabBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DTabBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget7DTabBarE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DObject"))
        return static_cast< DObject*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::DTabBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DTabBar::currentChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DTabBar::tabCloseRequested(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Dtk::Widget::DTabBar::tabMoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Dtk::Widget::DTabBar::tabIsInserted(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Dtk::Widget::DTabBar::tabIsRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Dtk::Widget::DTabBar::tabBarClicked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Dtk::Widget::DTabBar::tabBarDoubleClicked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Dtk::Widget::DTabBar::tabAddRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Widget::DTabBar::tabReleaseRequested(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Dtk::Widget::DTabBar::tabDroped(int _t1, Qt::DropAction _t2, QObject * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3);
}

// SIGNAL 10
void Dtk::Widget::DTabBar::dragActionChanged(Qt::DropAction _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Dtk::Widget::DTabBar::dragStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Dtk::Widget::DTabBar::dragEnd(Qt::DropAction _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
