/****************************************************************************
** Meta object code from reading C++ file 'dinputdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dinputdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dinputdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DInputDialog_t {
    QByteArrayData data[61];
    char stringdata0[840];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DInputDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DInputDialog_t qt_meta_stringdata_Dtk__Widget__DInputDialog = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Dtk::Widget::DInputDialog"
QT_MOC_LITERAL(1, 26, 16), // "textValueChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 4), // "text"
QT_MOC_LITERAL(4, 49, 17), // "textValueSelected"
QT_MOC_LITERAL(5, 67, 15), // "intValueChanged"
QT_MOC_LITERAL(6, 83, 5), // "value"
QT_MOC_LITERAL(7, 89, 16), // "intValueSelected"
QT_MOC_LITERAL(8, 106, 18), // "doubleValueChanged"
QT_MOC_LITERAL(9, 125, 19), // "doubleValueSelected"
QT_MOC_LITERAL(10, 145, 19), // "cancelButtonClicked"
QT_MOC_LITERAL(11, 165, 15), // "okButtonClicked"
QT_MOC_LITERAL(12, 181, 27), // "comboBoxCurrentIndexChanged"
QT_MOC_LITERAL(13, 209, 20), // "comboBoxCurrentIndex"
QT_MOC_LITERAL(14, 230, 16), // "textAlertChanged"
QT_MOC_LITERAL(15, 247, 9), // "textAlert"
QT_MOC_LITERAL(16, 257, 12), // "setInputMode"
QT_MOC_LITERAL(17, 270, 9), // "InputMode"
QT_MOC_LITERAL(18, 280, 4), // "mode"
QT_MOC_LITERAL(19, 285, 12), // "setTextValue"
QT_MOC_LITERAL(20, 298, 15), // "setTextEchoMode"
QT_MOC_LITERAL(21, 314, 19), // "QLineEdit::EchoMode"
QT_MOC_LITERAL(22, 334, 19), // "setComboBoxEditable"
QT_MOC_LITERAL(23, 354, 8), // "editable"
QT_MOC_LITERAL(24, 363, 16), // "setComboBoxItems"
QT_MOC_LITERAL(25, 380, 5), // "items"
QT_MOC_LITERAL(26, 386, 23), // "setComboBoxCurrentIndex"
QT_MOC_LITERAL(27, 410, 11), // "setIntValue"
QT_MOC_LITERAL(28, 422, 13), // "setIntMinimum"
QT_MOC_LITERAL(29, 436, 3), // "min"
QT_MOC_LITERAL(30, 440, 13), // "setIntMaximum"
QT_MOC_LITERAL(31, 454, 3), // "max"
QT_MOC_LITERAL(32, 458, 11), // "setIntRange"
QT_MOC_LITERAL(33, 470, 10), // "setIntStep"
QT_MOC_LITERAL(34, 481, 4), // "step"
QT_MOC_LITERAL(35, 486, 14), // "setDoubleValue"
QT_MOC_LITERAL(36, 501, 16), // "setDoubleMinimum"
QT_MOC_LITERAL(37, 518, 16), // "setDoubleMaximum"
QT_MOC_LITERAL(38, 535, 14), // "setDoubleRange"
QT_MOC_LITERAL(39, 550, 17), // "setDoubleDecimals"
QT_MOC_LITERAL(40, 568, 8), // "decimals"
QT_MOC_LITERAL(41, 577, 15), // "setOkButtonText"
QT_MOC_LITERAL(42, 593, 18), // "setOkButtonEnabled"
QT_MOC_LITERAL(43, 612, 6), // "enable"
QT_MOC_LITERAL(44, 619, 19), // "setCancelButtonText"
QT_MOC_LITERAL(45, 639, 12), // "setTextAlert"
QT_MOC_LITERAL(46, 652, 9), // "inputMode"
QT_MOC_LITERAL(47, 662, 9), // "textValue"
QT_MOC_LITERAL(48, 672, 8), // "intValue"
QT_MOC_LITERAL(49, 681, 11), // "doubleValue"
QT_MOC_LITERAL(50, 693, 12), // "textEchoMode"
QT_MOC_LITERAL(51, 706, 16), // "comboBoxEditable"
QT_MOC_LITERAL(52, 723, 13), // "comboBoxItems"
QT_MOC_LITERAL(53, 737, 10), // "intMinimum"
QT_MOC_LITERAL(54, 748, 10), // "intMaximum"
QT_MOC_LITERAL(55, 759, 7), // "intStep"
QT_MOC_LITERAL(56, 767, 13), // "doubleMinimum"
QT_MOC_LITERAL(57, 781, 13), // "doubleMaximum"
QT_MOC_LITERAL(58, 795, 14), // "doubleDecimals"
QT_MOC_LITERAL(59, 810, 12), // "okButtonText"
QT_MOC_LITERAL(60, 823, 16) // "cancelButtonText"

    },
    "Dtk::Widget::DInputDialog\0textValueChanged\0"
    "\0text\0textValueSelected\0intValueChanged\0"
    "value\0intValueSelected\0doubleValueChanged\0"
    "doubleValueSelected\0cancelButtonClicked\0"
    "okButtonClicked\0comboBoxCurrentIndexChanged\0"
    "comboBoxCurrentIndex\0textAlertChanged\0"
    "textAlert\0setInputMode\0InputMode\0mode\0"
    "setTextValue\0setTextEchoMode\0"
    "QLineEdit::EchoMode\0setComboBoxEditable\0"
    "editable\0setComboBoxItems\0items\0"
    "setComboBoxCurrentIndex\0setIntValue\0"
    "setIntMinimum\0min\0setIntMaximum\0max\0"
    "setIntRange\0setIntStep\0step\0setDoubleValue\0"
    "setDoubleMinimum\0setDoubleMaximum\0"
    "setDoubleRange\0setDoubleDecimals\0"
    "decimals\0setOkButtonText\0setOkButtonEnabled\0"
    "enable\0setCancelButtonText\0setTextAlert\0"
    "inputMode\0textValue\0intValue\0doubleValue\0"
    "textEchoMode\0comboBoxEditable\0"
    "comboBoxItems\0intMinimum\0intMaximum\0"
    "intStep\0doubleMinimum\0doubleMaximum\0"
    "doubleDecimals\0okButtonText\0"
    "cancelButtonText"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DInputDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
      17,  254, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  164,    2, 0x06 /* Public */,
       4,    1,  167,    2, 0x06 /* Public */,
       5,    1,  170,    2, 0x06 /* Public */,
       7,    1,  173,    2, 0x06 /* Public */,
       8,    1,  176,    2, 0x06 /* Public */,
       9,    1,  179,    2, 0x06 /* Public */,
      10,    0,  182,    2, 0x06 /* Public */,
      11,    0,  183,    2, 0x06 /* Public */,
      12,    1,  184,    2, 0x06 /* Public */,
      14,    1,  187,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    1,  190,    2, 0x0a /* Public */,
      19,    1,  193,    2, 0x0a /* Public */,
      20,    1,  196,    2, 0x0a /* Public */,
      22,    1,  199,    2, 0x0a /* Public */,
      24,    1,  202,    2, 0x0a /* Public */,
      26,    1,  205,    2, 0x0a /* Public */,
      27,    1,  208,    2, 0x0a /* Public */,
      28,    1,  211,    2, 0x0a /* Public */,
      30,    1,  214,    2, 0x0a /* Public */,
      32,    2,  217,    2, 0x0a /* Public */,
      33,    1,  222,    2, 0x0a /* Public */,
      35,    1,  225,    2, 0x0a /* Public */,
      36,    1,  228,    2, 0x0a /* Public */,
      37,    1,  231,    2, 0x0a /* Public */,
      38,    2,  234,    2, 0x0a /* Public */,
      39,    1,  239,    2, 0x0a /* Public */,
      41,    1,  242,    2, 0x0a /* Public */,
      42,    1,  245,    2, 0x0a /* Public */,
      44,    1,  248,    2, 0x0a /* Public */,
      45,    1,  251,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Double,    6,
    QMetaType::Void, QMetaType::Double,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Bool,   15,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 21,   18,
    QMetaType::Void, QMetaType::Bool,   23,
    QMetaType::Void, QMetaType::QStringList,   25,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,   29,
    QMetaType::Void, QMetaType::Int,   31,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   29,   31,
    QMetaType::Void, QMetaType::Int,   34,
    QMetaType::Void, QMetaType::Double,    6,
    QMetaType::Void, QMetaType::Double,   29,
    QMetaType::Void, QMetaType::Double,   31,
    QMetaType::Void, QMetaType::Double, QMetaType::Double,   29,   31,
    QMetaType::Void, QMetaType::Int,   40,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Bool,   43,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Bool,   15,

 // properties: name, type, flags
      46, 0x80000000 | 17, 0x0009510b,
      47, QMetaType::QString, 0x00495103,
      48, QMetaType::Int, 0x00495103,
      49, QMetaType::Int, 0x00495103,
      50, 0x80000000 | 21, 0x0009510b,
      51, QMetaType::Bool, 0x00095103,
      52, QMetaType::QStringList, 0x00095103,
      13, QMetaType::Int, 0x00495103,
      53, QMetaType::Int, 0x00095103,
      54, QMetaType::Int, 0x00095103,
      55, QMetaType::Int, 0x00095103,
      56, QMetaType::Double, 0x00095103,
      57, QMetaType::Double, 0x00095103,
      58, QMetaType::Int, 0x00095103,
      59, QMetaType::QString, 0x00095103,
      60, QMetaType::QString, 0x00095103,
      15, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       0,
       2,
       4,
       0,
       0,
       0,
       8,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       9,

       0        // eod
};

void Dtk::Widget::DInputDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DInputDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->textValueChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->textValueSelected((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->intValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->intValueSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->doubleValueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 5: _t->doubleValueSelected((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 6: _t->cancelButtonClicked(); break;
        case 7: _t->okButtonClicked(); break;
        case 8: _t->comboBoxCurrentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->textAlertChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->setInputMode((*reinterpret_cast< InputMode(*)>(_a[1]))); break;
        case 11: _t->setTextValue((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->setTextEchoMode((*reinterpret_cast< QLineEdit::EchoMode(*)>(_a[1]))); break;
        case 13: _t->setComboBoxEditable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->setComboBoxItems((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 15: _t->setComboBoxCurrentIndex((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->setIntValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->setIntMinimum((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->setIntMaximum((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->setIntRange((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 20: _t->setIntStep((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->setDoubleValue((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 22: _t->setDoubleMinimum((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 23: _t->setDoubleMaximum((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 24: _t->setDoubleRange((*reinterpret_cast< double(*)>(_a[1])),(*reinterpret_cast< double(*)>(_a[2]))); break;
        case 25: _t->setDoubleDecimals((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 26: _t->setOkButtonText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->setOkButtonEnabled((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 28: _t->setCancelButtonText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 29: _t->setTextAlert((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DInputDialog::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::textValueChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DInputDialog::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::textValueSelected)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DInputDialog::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::intValueChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DInputDialog::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::intValueSelected)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DInputDialog::*)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::doubleValueChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DInputDialog::*)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::doubleValueSelected)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DInputDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::cancelButtonClicked)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DInputDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::okButtonClicked)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DInputDialog::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::comboBoxCurrentIndexChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DInputDialog::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DInputDialog::textAlertChanged)) {
                *result = 9;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DInputDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< InputMode*>(_v) = _t->inputMode(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->textValue(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->intValue(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->doubleValue(); break;
        case 4: *reinterpret_cast< QLineEdit::EchoMode*>(_v) = _t->textEchoMode(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isComboBoxEditable(); break;
        case 6: *reinterpret_cast< QStringList*>(_v) = _t->comboBoxItems(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->comboBoxCurrentIndex(); break;
        case 8: *reinterpret_cast< int*>(_v) = _t->intMinimum(); break;
        case 9: *reinterpret_cast< int*>(_v) = _t->intMaximum(); break;
        case 10: *reinterpret_cast< int*>(_v) = _t->intStep(); break;
        case 11: *reinterpret_cast< double*>(_v) = _t->doubleMinimum(); break;
        case 12: *reinterpret_cast< double*>(_v) = _t->doubleMaximum(); break;
        case 13: *reinterpret_cast< int*>(_v) = _t->doubleDecimals(); break;
        case 14: *reinterpret_cast< QString*>(_v) = _t->okButtonText(); break;
        case 15: *reinterpret_cast< QString*>(_v) = _t->cancelButtonText(); break;
        case 16: *reinterpret_cast< bool*>(_v) = _t->isTextAlert(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DInputDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInputMode(*reinterpret_cast< InputMode*>(_v)); break;
        case 1: _t->setTextValue(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setIntValue(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setDoubleValue(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setTextEchoMode(*reinterpret_cast< QLineEdit::EchoMode*>(_v)); break;
        case 5: _t->setComboBoxEditable(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setComboBoxItems(*reinterpret_cast< QStringList*>(_v)); break;
        case 7: _t->setComboBoxCurrentIndex(*reinterpret_cast< int*>(_v)); break;
        case 8: _t->setIntMinimum(*reinterpret_cast< int*>(_v)); break;
        case 9: _t->setIntMaximum(*reinterpret_cast< int*>(_v)); break;
        case 10: _t->setIntStep(*reinterpret_cast< int*>(_v)); break;
        case 11: _t->setDoubleMinimum(*reinterpret_cast< double*>(_v)); break;
        case 12: _t->setDoubleMaximum(*reinterpret_cast< double*>(_v)); break;
        case 13: _t->setDoubleDecimals(*reinterpret_cast< int*>(_v)); break;
        case 14: _t->setOkButtonText(*reinterpret_cast< QString*>(_v)); break;
        case 15: _t->setCancelButtonText(*reinterpret_cast< QString*>(_v)); break;
        case 16: _t->setTextAlert(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Widget__DInputDialog[] = {
    QMetaObject::SuperData::link<QLineEdit::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DInputDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<DDialog::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DInputDialog.data,
    qt_meta_data_Dtk__Widget__DInputDialog,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Widget__DInputDialog,
    nullptr
} };


const QMetaObject *Dtk::Widget::DInputDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DInputDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DInputDialog.stringdata0))
        return static_cast<void*>(this);
    return DDialog::qt_metacast(_clname);
}

int Dtk::Widget::DInputDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 30;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 17;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DInputDialog::textValueChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Widget::DInputDialog::textValueSelected(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Widget::DInputDialog::intValueChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Widget::DInputDialog::intValueSelected(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Dtk::Widget::DInputDialog::doubleValueChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Dtk::Widget::DInputDialog::doubleValueSelected(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Dtk::Widget::DInputDialog::cancelButtonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Widget::DInputDialog::okButtonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Widget::DInputDialog::comboBoxCurrentIndexChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Dtk::Widget::DInputDialog::textAlertChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
