/****************************************************************************
** Meta object code from reading C++ file 'dmpriscontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dmpriscontrol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dmpriscontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget13DMPRISControlE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DMPRISControl::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget13DMPRISControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DMPRISControl",
        "mprisAcquired",
        "",
        "mprisChanged",
        "mprisLosted",
        "setPictureVisible",
        "visible",
        "setPictureSize",
        "QSize",
        "size",
        "_q_onMetaDataChanged",
        "_q_onPlaybackStatusChanged",
        "_q_onPrevClicked",
        "_q_onPlayClicked",
        "_q_onPauseClicked",
        "_q_onNextClicked",
        "_q_loadMPRISPath",
        "_q_removeMPRISPath",
        "_q_onCanControlChanged",
        "canControl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mprisAcquired'
        QtMocHelpers::SignalData<void() const>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mprisChanged'
        QtMocHelpers::SignalData<void() const>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mprisLosted'
        QtMocHelpers::SignalData<void() const>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPictureVisible'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'setPictureSize'
        QtMocHelpers::SlotData<void(const QSize &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot '_q_onMetaDataChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot '_q_onPlaybackStatusChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot '_q_onPrevClicked'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot '_q_onPlayClicked'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot '_q_onPauseClicked'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot '_q_onNextClicked'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot '_q_loadMPRISPath'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot '_q_removeMPRISPath'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot '_q_onCanControlChanged'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DMPRISControl, qt_meta_tag_ZN3Dtk6Widget13DMPRISControlE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DMPRISControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget13DMPRISControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget13DMPRISControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget13DMPRISControlE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DMPRISControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DMPRISControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mprisAcquired(); break;
        case 1: _t->mprisChanged(); break;
        case 2: _t->mprisLosted(); break;
        case 3: _t->setPictureVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setPictureSize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 5: _t->d_func()->_q_onMetaDataChanged(); break;
        case 6: _t->d_func()->_q_onPlaybackStatusChanged(); break;
        case 7: _t->d_func()->_q_onPrevClicked(); break;
        case 8: _t->d_func()->_q_onPlayClicked(); break;
        case 9: _t->d_func()->_q_onPauseClicked(); break;
        case 10: _t->d_func()->_q_onNextClicked(); break;
        case 11: _t->d_func()->_q_loadMPRISPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->d_func()->_q_removeMPRISPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->d_func()->_q_onCanControlChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DMPRISControl::*)() const>(_a, &DMPRISControl::mprisAcquired, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMPRISControl::*)() const>(_a, &DMPRISControl::mprisChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMPRISControl::*)() const>(_a, &DMPRISControl::mprisLosted, 2))
            return;
    }
}

const QMetaObject *Dtk::Widget::DMPRISControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DMPRISControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget13DMPRISControlE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QFrame::qt_metacast(_clname);
}

int Dtk::Widget::DMPRISControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DMPRISControl::mprisAcquired()const
{
    QMetaObject::activate(const_cast< Dtk::Widget::DMPRISControl *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DMPRISControl::mprisChanged()const
{
    QMetaObject::activate(const_cast< Dtk::Widget::DMPRISControl *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DMPRISControl::mprisLosted()const
{
    QMetaObject::activate(const_cast< Dtk::Widget::DMPRISControl *>(this), &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
