/****************************************************************************
** Meta object code from reading C++ file 'ddialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/ddialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ddialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget7DDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DDialog::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget7DDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DDialog",
        "aboutToClose",
        "",
        "closed",
        "buttonClicked",
        "index",
        "text",
        "titleChanged",
        "title",
        "messageChanged",
        "massage",
        "textFormatChanged",
        "Qt::TextFormat",
        "textFormat",
        "sizeChanged",
        "QSize",
        "size",
        "visibleChanged",
        "visible",
        "addButton",
        "isDefault",
        "ButtonType",
        "type",
        "addButtons",
        "insertButton",
        "QAbstractButton*",
        "button",
        "insertButtons",
        "removeButton",
        "removeButtonByText",
        "clearButtons",
        "setDefaultButton",
        "str",
        "addContent",
        "QWidget*",
        "widget",
        "Qt::Alignment",
        "alignment",
        "insertContent",
        "removeContent",
        "isDelete",
        "clearContents",
        "setSpacing",
        "spacing",
        "addSpacing",
        "insertSpacing",
        "clearSpacing",
        "setButtonText",
        "setButtonIcon",
        "QIcon",
        "icon",
        "setTitle",
        "setWordWrapTitle",
        "wordWrap",
        "setMessage",
        "message",
        "setWordWrapMessage",
        "setIcon",
        "setTextFormat",
        "setOnButtonClickedClose",
        "onButtonClickedClose",
        "setCloseButtonVisible",
        "closeButtonVisible",
        "exec",
        "_q_onButtonClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aboutToClose'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'buttonClicked'
        QtMocHelpers::SignalData<void(int, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(QString)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'messageChanged'
        QtMocHelpers::SignalData<void(QString)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'textFormatChanged'
        QtMocHelpers::SignalData<void(Qt::TextFormat)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void(QSize)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'addButton'
        QtMocHelpers::SlotData<int(const QString &, bool, enum ButtonType)>(19, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 6 }, { QMetaType::Bool, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'addButton'
        QtMocHelpers::SlotData<int(const QString &, bool)>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::QString, 6 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'addButton'
        QtMocHelpers::SlotData<int(const QString &)>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'addButtons'
        QtMocHelpers::SlotData<int(const QStringList &)>(23, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Slot 'insertButton'
        QtMocHelpers::SlotData<void(int, const QString &, bool, enum ButtonType)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 }, { QMetaType::Bool, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'insertButton'
        QtMocHelpers::SlotData<void(int, const QString &, bool)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'insertButton'
        QtMocHelpers::SlotData<void(int, const QString &)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'insertButton'
        QtMocHelpers::SlotData<void(int, QAbstractButton *, bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 25, 26 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'insertButton'
        QtMocHelpers::SlotData<void(int, QAbstractButton *)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'insertButtons'
        QtMocHelpers::SlotData<void(int, const QStringList &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QStringList, 6 },
        }}),
        // Slot 'removeButton'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'removeButton'
        QtMocHelpers::SlotData<void(QAbstractButton *)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'removeButtonByText'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'clearButtons'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDefaultButton'
        QtMocHelpers::SlotData<bool(int)>(31, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setDefaultButton'
        QtMocHelpers::SlotData<bool(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'setDefaultButton'
        QtMocHelpers::SlotData<void(QAbstractButton *)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'addContent'
        QtMocHelpers::SlotData<void(QWidget *, Qt::Alignment)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { 0x80000000 | 36, 37 },
        }}),
        // Slot 'addContent'
        QtMocHelpers::SlotData<void(QWidget *)>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'insertContent'
        QtMocHelpers::SlotData<void(int, QWidget *, Qt::Alignment)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 34, 35 }, { 0x80000000 | 36, 37 },
        }}),
        // Slot 'insertContent'
        QtMocHelpers::SlotData<void(int, QWidget *)>(38, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 34, 35 },
        }}),
        // Slot 'removeContent'
        QtMocHelpers::SlotData<void(QWidget *, bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'removeContent'
        QtMocHelpers::SlotData<void(QWidget *)>(39, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'clearContents'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'clearContents'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setSpacing'
        QtMocHelpers::SlotData<void(int)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'addSpacing'
        QtMocHelpers::SlotData<void(int)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'insertSpacing'
        QtMocHelpers::SlotData<void(int, int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 43 },
        }}),
        // Slot 'clearSpacing'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setButtonText'
        QtMocHelpers::SlotData<void(int, const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'setButtonIcon'
        QtMocHelpers::SlotData<void(int, const QIcon &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 49, 50 },
        }}),
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void(const QString &)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'setWordWrapTitle'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 53 },
        }}),
        // Slot 'setMessage'
        QtMocHelpers::SlotData<void(const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 55 },
        }}),
        // Slot 'setWordWrapMessage'
        QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 53 },
        }}),
        // Slot 'setIcon'
        QtMocHelpers::SlotData<void(const QIcon &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Slot 'setTextFormat'
        QtMocHelpers::SlotData<void(Qt::TextFormat)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setOnButtonClickedClose'
        QtMocHelpers::SlotData<void(bool)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 60 },
        }}),
        // Slot 'setCloseButtonVisible'
        QtMocHelpers::SlotData<void(bool)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 62 },
        }}),
        // Slot 'exec'
        QtMocHelpers::SlotData<int()>(63, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot '_q_onButtonClicked'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'title'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'message'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'icon'
        QtMocHelpers::PropertyData<QIcon>(50, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'textFormat'
        QtMocHelpers::PropertyData<Qt::TextFormat>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'onButtonClickedClose'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'closeButtonVisible'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DDialog, qt_meta_tag_ZN3Dtk6Widget7DDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<DAbstractDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget7DDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget7DDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget7DDialogE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aboutToClose(); break;
        case 1: _t->closed(); break;
        case 2: _t->buttonClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->messageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->textFormatChanged((*reinterpret_cast<std::add_pointer_t<Qt::TextFormat>>(_a[1]))); break;
        case 6: _t->sizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 7: _t->visibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: { int _r = _t->addButton((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<enum ButtonType>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->addButton((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->addButton((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->addButtons((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->insertButton((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<enum ButtonType>>(_a[4]))); break;
        case 13: _t->insertButton((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 14: _t->insertButton((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->insertButton((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 16: _t->insertButton((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 17: _t->insertButtons((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 18: _t->removeButton((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->removeButton((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1]))); break;
        case 20: _t->removeButtonByText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->clearButtons(); break;
        case 22: { bool _r = _t->setDefaultButton((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->setDefaultButton((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->setDefaultButton((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1]))); break;
        case 25: _t->addContent((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::Alignment>>(_a[2]))); break;
        case 26: _t->addContent((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 27: _t->insertContent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Alignment>>(_a[3]))); break;
        case 28: _t->insertContent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 29: _t->removeContent((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 30: _t->removeContent((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 31: _t->clearContents((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->clearContents(); break;
        case 33: _t->setSpacing((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->addSpacing((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->insertSpacing((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 36: _t->clearSpacing(); break;
        case 37: _t->setButtonText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 38: _t->setButtonIcon((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[2]))); break;
        case 39: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->setWordWrapTitle((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->setMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 42: _t->setWordWrapMessage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->setIcon((*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[1]))); break;
        case 44: _t->setTextFormat((*reinterpret_cast<std::add_pointer_t<Qt::TextFormat>>(_a[1]))); break;
        case 45: _t->setOnButtonClickedClose((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->setCloseButtonVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: { int _r = _t->exec();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->d_func()->_q_onButtonClicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DDialog::*)()>(_a, &DDialog::aboutToClose, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDialog::*)()>(_a, &DDialog::closed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDialog::*)(int , const QString & )>(_a, &DDialog::buttonClicked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDialog::*)(QString )>(_a, &DDialog::titleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDialog::*)(QString )>(_a, &DDialog::messageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDialog::*)(Qt::TextFormat )>(_a, &DDialog::textFormatChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDialog::*)(QSize )>(_a, &DDialog::sizeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DDialog::*)(bool )>(_a, &DDialog::visibleChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->message(); break;
        case 2: *reinterpret_cast<QIcon*>(_v) = _t->icon(); break;
        case 3: *reinterpret_cast<Qt::TextFormat*>(_v) = _t->textFormat(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->onButtonClickedClose(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->closeButtonVisible(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setMessage(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setIcon(*reinterpret_cast<QIcon*>(_v)); break;
        case 3: _t->setTextFormat(*reinterpret_cast<Qt::TextFormat*>(_v)); break;
        case 4: _t->setOnButtonClickedClose(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setCloseButtonVisible(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget7DDialogE_t>.strings))
        return static_cast<void*>(this);
    return DAbstractDialog::qt_metacast(_clname);
}

int Dtk::Widget::DDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DAbstractDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 49)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 49;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 49)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 49;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DDialog::aboutToClose()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DDialog::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DDialog::buttonClicked(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Dtk::Widget::DDialog::titleChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Dtk::Widget::DDialog::messageChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Dtk::Widget::DDialog::textFormatChanged(Qt::TextFormat _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Dtk::Widget::DDialog::sizeChanged(QSize _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Dtk::Widget::DDialog::visibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
