/****************************************************************************
** Meta object code from reading C++ file 'dprintpreviewdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dprintpreviewdialog.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dprintpreviewdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DPrintPreviewDialog::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DPrintPreviewDialog",
        "paintRequested",
        "",
        "DPrinter*",
        "printer",
        "QList<int>",
        "pageRange",
        "_q_printerChanged",
        "_q_pageRangeChanged",
        "_q_pageMarginChanged",
        "_q_ColorModeChange",
        "_q_startPrint",
        "_q_orientationChanged",
        "_q_customPagesFinished",
        "_q_marginspinChanged",
        "_q_marginEditFinished",
        "_q_currentPageSpinChanged",
        "_q_checkStateChanged",
        "_q_textWaterMarkModeChanged",
        "_q_customTextWatermarkFinished",
        "_q_colorButtonCliked",
        "_q_selectColorButton",
        "QColor",
        "_q_pagePersheetComboIndexChanged",
        "_q_printOrderComboIndexChanged",
        "_q_spinboxValueEmptyChecked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'paintRequested'
        QtMocHelpers::SignalData<void(DPrinter *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'paintRequested'
        QtMocHelpers::SignalData<void(DPrinter *, const QVector<int> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot '_q_printerChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_pageRangeChanged'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_pageMarginChanged'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_ColorModeChange'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_startPrint'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot '_q_orientationChanged'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_customPagesFinished'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_marginspinChanged'
        QtMocHelpers::SlotData<void(double)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot '_q_marginEditFinished'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_currentPageSpinChanged'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_checkStateChanged'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_textWaterMarkModeChanged'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_customTextWatermarkFinished'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_colorButtonCliked'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot '_q_selectColorButton'
        QtMocHelpers::SlotData<void(QColor)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Slot '_q_pagePersheetComboIndexChanged'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_printOrderComboIndexChanged'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot '_q_spinboxValueEmptyChecked'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DPrintPreviewDialog, qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DPrintPreviewDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<DDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewDialogE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DPrintPreviewDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DPrintPreviewDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->paintRequested((*reinterpret_cast<std::add_pointer_t<DPrinter*>>(_a[1]))); break;
        case 1: _t->paintRequested((*reinterpret_cast<std::add_pointer_t<DPrinter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 2: _t->d_func()->_q_printerChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->d_func()->_q_pageRangeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->d_func()->_q_pageMarginChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->d_func()->_q_ColorModeChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->d_func()->_q_startPrint((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->d_func()->_q_orientationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->d_func()->_q_customPagesFinished(); break;
        case 9: _t->d_func()->_q_marginspinChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->d_func()->_q_marginEditFinished(); break;
        case 11: _t->d_func()->_q_currentPageSpinChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->d_func()->_q_checkStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->d_func()->_q_textWaterMarkModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->d_func()->_q_customTextWatermarkFinished(); break;
        case 15: _t->d_func()->_q_colorButtonCliked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->d_func()->_q_selectColorButton((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 17: _t->d_func()->_q_pagePersheetComboIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->d_func()->_q_printOrderComboIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->d_func()->_q_spinboxValueEmptyChecked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DPrintPreviewDialog::*)(DPrinter * )>(_a, &DPrintPreviewDialog::paintRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DPrintPreviewDialog::*)(DPrinter * , const QVector<int> & )>(_a, &DPrintPreviewDialog::paintRequested, 1))
            return;
    }
}

const QMetaObject *Dtk::Widget::DPrintPreviewDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DPrintPreviewDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewDialogE_t>.strings))
        return static_cast<void*>(this);
    return DDialog::qt_metacast(_clname);
}

int Dtk::Widget::DPrintPreviewDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DPrintPreviewDialog::paintRequested(DPrinter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DPrintPreviewDialog::paintRequested(DPrinter * _t1, const QVector<int> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
