/****************************************************************************
** Meta object code from reading C++ file 'buttonexample.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../examples/collections/buttonexample.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'buttonexample.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ButtonExampleWindow_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ButtonExampleWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ButtonExampleWindow_t qt_meta_stringdata_ButtonExampleWindow = {
    {
QT_MOC_LITERAL(0, 0, 19) // "ButtonExampleWindow"

    },
    "ButtonExampleWindow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ButtonExampleWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ButtonExampleWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ButtonExampleWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<PageWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_ButtonExampleWindow.data,
    qt_meta_data_ButtonExampleWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ButtonExampleWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ButtonExampleWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ButtonExampleWindow.stringdata0))
        return static_cast<void*>(this);
    return PageWindowInterface::qt_metacast(_clname);
}

int ButtonExampleWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PageWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DPushButtonExample_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DPushButtonExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DPushButtonExample_t qt_meta_stringdata_DPushButtonExample = {
    {
QT_MOC_LITERAL(0, 0, 18) // "DPushButtonExample"

    },
    "DPushButtonExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DPushButtonExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DPushButtonExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DPushButtonExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DPushButtonExample.data,
    qt_meta_data_DPushButtonExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DPushButtonExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DPushButtonExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DPushButtonExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DPushButtonExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DWarningButtonExample_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DWarningButtonExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DWarningButtonExample_t qt_meta_stringdata_DWarningButtonExample = {
    {
QT_MOC_LITERAL(0, 0, 21) // "DWarningButtonExample"

    },
    "DWarningButtonExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DWarningButtonExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DWarningButtonExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DWarningButtonExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DWarningButtonExample.data,
    qt_meta_data_DWarningButtonExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DWarningButtonExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DWarningButtonExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DWarningButtonExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DWarningButtonExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DSuggestButtonExample_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DSuggestButtonExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DSuggestButtonExample_t qt_meta_stringdata_DSuggestButtonExample = {
    {
QT_MOC_LITERAL(0, 0, 21) // "DSuggestButtonExample"

    },
    "DSuggestButtonExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DSuggestButtonExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DSuggestButtonExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DSuggestButtonExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DSuggestButtonExample.data,
    qt_meta_data_DSuggestButtonExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DSuggestButtonExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DSuggestButtonExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DSuggestButtonExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DSuggestButtonExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DToolButtonExample_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DToolButtonExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DToolButtonExample_t qt_meta_stringdata_DToolButtonExample = {
    {
QT_MOC_LITERAL(0, 0, 18) // "DToolButtonExample"

    },
    "DToolButtonExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DToolButtonExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DToolButtonExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DToolButtonExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DToolButtonExample.data,
    qt_meta_data_DToolButtonExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DToolButtonExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DToolButtonExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DToolButtonExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DToolButtonExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DIconButtonExample_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DIconButtonExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DIconButtonExample_t qt_meta_stringdata_DIconButtonExample = {
    {
QT_MOC_LITERAL(0, 0, 18) // "DIconButtonExample"

    },
    "DIconButtonExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DIconButtonExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DIconButtonExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DIconButtonExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DIconButtonExample.data,
    qt_meta_data_DIconButtonExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DIconButtonExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DIconButtonExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DIconButtonExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DIconButtonExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DButtonBoxExample_t {
    QByteArrayData data[1];
    char stringdata0[18];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DButtonBoxExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DButtonBoxExample_t qt_meta_stringdata_DButtonBoxExample = {
    {
QT_MOC_LITERAL(0, 0, 17) // "DButtonBoxExample"

    },
    "DButtonBoxExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DButtonBoxExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DButtonBoxExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DButtonBoxExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DButtonBoxExample.data,
    qt_meta_data_DButtonBoxExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DButtonBoxExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DButtonBoxExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DButtonBoxExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DButtonBoxExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DFloatingButtonExample_t {
    QByteArrayData data[1];
    char stringdata0[23];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DFloatingButtonExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DFloatingButtonExample_t qt_meta_stringdata_DFloatingButtonExample = {
    {
QT_MOC_LITERAL(0, 0, 22) // "DFloatingButtonExample"

    },
    "DFloatingButtonExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DFloatingButtonExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DFloatingButtonExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DFloatingButtonExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DFloatingButtonExample.data,
    qt_meta_data_DFloatingButtonExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DFloatingButtonExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DFloatingButtonExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DFloatingButtonExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DFloatingButtonExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DSwitchButtonExample_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DSwitchButtonExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DSwitchButtonExample_t qt_meta_stringdata_DSwitchButtonExample = {
    {
QT_MOC_LITERAL(0, 0, 20) // "DSwitchButtonExample"

    },
    "DSwitchButtonExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DSwitchButtonExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DSwitchButtonExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DSwitchButtonExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DSwitchButtonExample.data,
    qt_meta_data_DSwitchButtonExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DSwitchButtonExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DSwitchButtonExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DSwitchButtonExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DSwitchButtonExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DRadioButtonExample_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DRadioButtonExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DRadioButtonExample_t qt_meta_stringdata_DRadioButtonExample = {
    {
QT_MOC_LITERAL(0, 0, 19) // "DRadioButtonExample"

    },
    "DRadioButtonExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DRadioButtonExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DRadioButtonExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DRadioButtonExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DRadioButtonExample.data,
    qt_meta_data_DRadioButtonExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DRadioButtonExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DRadioButtonExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DRadioButtonExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DRadioButtonExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DCheckButtonExample_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DCheckButtonExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DCheckButtonExample_t qt_meta_stringdata_DCheckButtonExample = {
    {
QT_MOC_LITERAL(0, 0, 19) // "DCheckButtonExample"

    },
    "DCheckButtonExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DCheckButtonExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DCheckButtonExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DCheckButtonExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DCheckButtonExample.data,
    qt_meta_data_DCheckButtonExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DCheckButtonExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DCheckButtonExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DCheckButtonExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DCheckButtonExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DComboBoxExample_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DComboBoxExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DComboBoxExample_t qt_meta_stringdata_DComboBoxExample = {
    {
QT_MOC_LITERAL(0, 0, 16) // "DComboBoxExample"

    },
    "DComboBoxExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DComboBoxExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DComboBoxExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DComboBoxExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DComboBoxExample.data,
    qt_meta_data_DComboBoxExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DComboBoxExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DComboBoxExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DComboBoxExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DComboBoxExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DFontComboBoxExample_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DFontComboBoxExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DFontComboBoxExample_t qt_meta_stringdata_DFontComboBoxExample = {
    {
QT_MOC_LITERAL(0, 0, 20) // "DFontComboBoxExample"

    },
    "DFontComboBoxExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DFontComboBoxExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DFontComboBoxExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DFontComboBoxExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DFontComboBoxExample.data,
    qt_meta_data_DFontComboBoxExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DFontComboBoxExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DFontComboBoxExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DFontComboBoxExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DFontComboBoxExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DSearchComboBoxExample_t {
    QByteArrayData data[1];
    char stringdata0[23];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DSearchComboBoxExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DSearchComboBoxExample_t qt_meta_stringdata_DSearchComboBoxExample = {
    {
QT_MOC_LITERAL(0, 0, 22) // "DSearchComboBoxExample"

    },
    "DSearchComboBoxExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DSearchComboBoxExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DSearchComboBoxExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DSearchComboBoxExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DSearchComboBoxExample.data,
    qt_meta_data_DSearchComboBoxExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DSearchComboBoxExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DSearchComboBoxExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DSearchComboBoxExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DSearchComboBoxExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
