/****************************************************************************
** Meta object code from reading C++ file 'dabstractdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dabstractdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dabstractdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget15DAbstractDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DAbstractDialog::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget15DAbstractDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DAbstractDialog",
        "sizeChanged",
        "",
        "QSize",
        "size",
        "moveToCenter",
        "moveToTopRight",
        "moveToCenterByRect",
        "QRect",
        "rect",
        "moveToTopRightByRect",
        "setDisplayPosition",
        "DisplayPosition",
        "displayPosition",
        "Center",
        "TopRight",
        "DisplayPostion",
        "DisplayCenter",
        "DisplayTopRight"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void(QSize)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'moveToCenter'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveToTopRight'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveToCenterByRect'
        QtMocHelpers::SlotData<void(const QRect &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'moveToTopRightByRect'
        QtMocHelpers::SlotData<void(const QRect &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setDisplayPosition'
        QtMocHelpers::SlotData<void(enum DisplayPosition)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'displayPosition'
        QtMocHelpers::PropertyData<enum DisplayPosition>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DisplayPosition'
        QtMocHelpers::EnumData<enum DisplayPosition>(12, 12, QMC::EnumFlags{}).add({
            {   14, DisplayPosition::Center },
            {   15, DisplayPosition::TopRight },
        }),
        // enum 'DisplayPostion'
        QtMocHelpers::EnumData<enum DisplayPostion>(16, 16, QMC::EnumFlags{}).add({
            {   17, DisplayPostion::DisplayCenter },
            {   18, DisplayPostion::DisplayTopRight },
        }),
    };
    return QtMocHelpers::metaObjectData<DAbstractDialog, qt_meta_tag_ZN3Dtk6Widget15DAbstractDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DAbstractDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DAbstractDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DAbstractDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget15DAbstractDialogE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DAbstractDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DAbstractDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 1: _t->moveToCenter(); break;
        case 2: _t->moveToTopRight(); break;
        case 3: _t->moveToCenterByRect((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 4: _t->moveToTopRightByRect((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 5: _t->setDisplayPosition((*reinterpret_cast<std::add_pointer_t<enum DisplayPosition>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DAbstractDialog::*)(QSize )>(_a, &DAbstractDialog::sizeChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum DisplayPosition*>(_v) = _t->displayPosition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDisplayPosition(*reinterpret_cast<enum DisplayPosition*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DAbstractDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DAbstractDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget15DAbstractDialogE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QDialog::qt_metacast(_clname);
}

int Dtk::Widget::DAbstractDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DAbstractDialog::sizeChanged(QSize _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
