/****************************************************************************
** Meta object code from reading C++ file 'dimageviewer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dimageviewer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dimageviewer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DImageViewer_t {
    QByteArrayData data[20];
    char stringdata0[262];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DImageViewer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DImageViewer_t qt_meta_stringdata_Dtk__Widget__DImageViewer = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Dtk::Widget::DImageViewer"
QT_MOC_LITERAL(1, 26, 12), // "imageChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 5), // "image"
QT_MOC_LITERAL(4, 46, 15), // "fileNameChanged"
QT_MOC_LITERAL(5, 62, 8), // "fileName"
QT_MOC_LITERAL(6, 71, 18), // "scaleFactorChanged"
QT_MOC_LITERAL(7, 90, 11), // "scaleFactor"
QT_MOC_LITERAL(8, 102, 18), // "rotateAngleChanged"
QT_MOC_LITERAL(9, 121, 5), // "angle"
QT_MOC_LITERAL(10, 127, 16), // "transformChanged"
QT_MOC_LITERAL(11, 144, 20), // "requestPreviousImage"
QT_MOC_LITERAL(12, 165, 16), // "requestNextImage"
QT_MOC_LITERAL(13, 182, 16), // "cropImageChanged"
QT_MOC_LITERAL(14, 199, 4), // "rect"
QT_MOC_LITERAL(15, 204, 12), // "scaleAtPoint"
QT_MOC_LITERAL(16, 217, 3), // "pos"
QT_MOC_LITERAL(17, 221, 6), // "factor"
QT_MOC_LITERAL(18, 228, 21), // "_q_pinchAnimeFinished"
QT_MOC_LITERAL(19, 250, 11) // "rotateAngle"

    },
    "Dtk::Widget::DImageViewer\0imageChanged\0"
    "\0image\0fileNameChanged\0fileName\0"
    "scaleFactorChanged\0scaleFactor\0"
    "rotateAngleChanged\0angle\0transformChanged\0"
    "requestPreviousImage\0requestNextImage\0"
    "cropImageChanged\0rect\0scaleAtPoint\0"
    "pos\0factor\0_q_pinchAnimeFinished\0"
    "rotateAngle"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DImageViewer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       4,   88, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    1,   67,    2, 0x06 /* Public */,
       6,    1,   70,    2, 0x06 /* Public */,
       8,    1,   73,    2, 0x06 /* Public */,
      10,    0,   76,    2, 0x06 /* Public */,
      11,    0,   77,    2, 0x06 /* Public */,
      12,    0,   78,    2, 0x06 /* Public */,
      13,    1,   79,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    2,   82,    2, 0x0a /* Public */,
      18,    0,   87,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QImage,    3,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QReal,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QRect,   14,

 // slots: parameters
    QMetaType::Void, QMetaType::QPoint, QMetaType::QReal,   16,   17,
    QMetaType::Void,

 // properties: name, type, flags
       3, QMetaType::QImage, 0x00495103,
       5, QMetaType::QString, 0x00495103,
       7, QMetaType::QReal, 0x00495103,
      19, QMetaType::Int, 0x00495001,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,

       0        // eod
};

void Dtk::Widget::DImageViewer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DImageViewer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->imageChanged((*reinterpret_cast< const QImage(*)>(_a[1]))); break;
        case 1: _t->fileNameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->scaleFactorChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 3: _t->rotateAngleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->transformChanged(); break;
        case 5: _t->requestPreviousImage(); break;
        case 6: _t->requestNextImage(); break;
        case 7: _t->cropImageChanged((*reinterpret_cast< const QRect(*)>(_a[1]))); break;
        case 8: _t->scaleAtPoint((*reinterpret_cast< QPoint(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 9: _t->d_func()->_q_pinchAnimeFinished(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DImageViewer::*)(const QImage & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DImageViewer::imageChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DImageViewer::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DImageViewer::fileNameChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DImageViewer::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DImageViewer::scaleFactorChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DImageViewer::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DImageViewer::rotateAngleChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DImageViewer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DImageViewer::transformChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DImageViewer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DImageViewer::requestPreviousImage)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DImageViewer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DImageViewer::requestNextImage)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DImageViewer::*)(const QRect & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DImageViewer::cropImageChanged)) {
                *result = 7;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DImageViewer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QImage*>(_v) = _t->image(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->fileName(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->scaleFactor(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->rotateAngle(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DImageViewer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setImage(*reinterpret_cast< QImage*>(_v)); break;
        case 1: _t->setFileName(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setScaleFactor(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DImageViewer::staticMetaObject = { {
    QMetaObject::SuperData::link<DGraphicsView::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DImageViewer.data,
    qt_meta_data_Dtk__Widget__DImageViewer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DImageViewer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DImageViewer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DImageViewer.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Core::DObject"))
        return static_cast< Core::DObject*>(this);
    return DGraphicsView::qt_metacast(_clname);
}

int Dtk::Widget::DImageViewer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DImageViewer::imageChanged(const QImage & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Widget::DImageViewer::fileNameChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Widget::DImageViewer::scaleFactorChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Widget::DImageViewer::rotateAngleChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Dtk::Widget::DImageViewer::transformChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Widget::DImageViewer::requestPreviousImage()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Widget::DImageViewer::requestNextImage()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Widget::DImageViewer::cropImageChanged(const QRect & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
