/****************************************************************************
** Meta object code from reading C++ file 'dprintpreviewwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dprintpreviewwidget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dprintpreviewwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DPrintPreviewWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DPrintPreviewWidget",
        "paintRequested",
        "",
        "DPrinter*",
        "printer",
        "QList<int>",
        "pageRange",
        "previewChanged",
        "currentPageChanged",
        "page",
        "totalPages",
        "pagesCountChanged",
        "pages",
        "updatePreview",
        "turnFront",
        "turnBack",
        "turnBegin",
        "turnEnd",
        "setCurrentPage",
        "print",
        "isSavedPicture",
        "themeTypeChanged",
        "DGuiApplicationHelper::ColorType",
        "themeType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'paintRequested'
        QtMocHelpers::SignalData<void(DPrinter *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'paintRequested'
        QtMocHelpers::SignalData<void(DPrinter *, const QVector<int> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'previewChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentPageChanged'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'totalPages'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'pagesCountChanged'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'updatePreview'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'turnFront'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'turnBack'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'turnBegin'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'turnEnd'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurrentPage'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'print'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'themeTypeChanged'
        QtMocHelpers::SlotData<void(DGuiApplicationHelper::ColorType)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DPrintPreviewWidget, qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DPrintPreviewWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DPrintPreviewWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DPrintPreviewWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->paintRequested((*reinterpret_cast<std::add_pointer_t<DPrinter*>>(_a[1]))); break;
        case 1: _t->paintRequested((*reinterpret_cast<std::add_pointer_t<DPrinter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 2: _t->previewChanged(); break;
        case 3: _t->currentPageChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->totalPages((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->pagesCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->updatePreview(); break;
        case 7: _t->turnFront(); break;
        case 8: _t->turnBack(); break;
        case 9: _t->turnBegin(); break;
        case 10: _t->turnEnd(); break;
        case 11: _t->setCurrentPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->print((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->print(); break;
        case 14: _t->themeTypeChanged((*reinterpret_cast<std::add_pointer_t<DGuiApplicationHelper::ColorType>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DPrintPreviewWidget::*)(DPrinter * )>(_a, &DPrintPreviewWidget::paintRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DPrintPreviewWidget::*)(DPrinter * , const QVector<int> & )>(_a, &DPrintPreviewWidget::paintRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DPrintPreviewWidget::*)()>(_a, &DPrintPreviewWidget::previewChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DPrintPreviewWidget::*)(int )>(_a, &DPrintPreviewWidget::currentPageChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DPrintPreviewWidget::*)(int )>(_a, &DPrintPreviewWidget::totalPages, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DPrintPreviewWidget::*)(int )>(_a, &DPrintPreviewWidget::pagesCountChanged, 5))
            return;
    }
}

const QMetaObject *Dtk::Widget::DPrintPreviewWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DPrintPreviewWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget19DPrintPreviewWidgetE_t>.strings))
        return static_cast<void*>(this);
    return DFrame::qt_metacast(_clname);
}

int Dtk::Widget::DPrintPreviewWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DPrintPreviewWidget::paintRequested(DPrinter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DPrintPreviewWidget::paintRequested(DPrinter * _t1, const QVector<int> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Dtk::Widget::DPrintPreviewWidget::previewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Widget::DPrintPreviewWidget::currentPageChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Dtk::Widget::DPrintPreviewWidget::totalPages(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Dtk::Widget::DPrintPreviewWidget::pagesCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
