/****************************************************************************
** Meta object code from reading C++ file 'dipv4lineedit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dipv4lineedit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dipv4lineedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DIpv4LineEdit_t {
    QByteArrayData data[21];
    char stringdata0[280];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DIpv4LineEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DIpv4LineEdit_t qt_meta_stringdata_Dtk__Widget__DIpv4LineEdit = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Dtk::Widget::DIpv4LineEdit"
QT_MOC_LITERAL(1, 27, 12), // "focusChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 5), // "focus"
QT_MOC_LITERAL(4, 47, 17), // "setCursorPosition"
QT_MOC_LITERAL(5, 65, 14), // "cursorPosition"
QT_MOC_LITERAL(6, 80, 11), // "setReadOnly"
QT_MOC_LITERAL(7, 92, 8), // "readOnly"
QT_MOC_LITERAL(8, 101, 12), // "setSelection"
QT_MOC_LITERAL(9, 114, 5), // "start"
QT_MOC_LITERAL(10, 120, 6), // "length"
QT_MOC_LITERAL(11, 127, 9), // "selectAll"
QT_MOC_LITERAL(12, 137, 21), // "_q_updateLineEditText"
QT_MOC_LITERAL(13, 159, 20), // "_q_setIpLineEditText"
QT_MOC_LITERAL(14, 180, 11), // "displayText"
QT_MOC_LITERAL(15, 192, 9), // "alignment"
QT_MOC_LITERAL(16, 202, 13), // "Qt::Alignment"
QT_MOC_LITERAL(17, 216, 12), // "selectedText"
QT_MOC_LITERAL(18, 229, 15), // "acceptableInput"
QT_MOC_LITERAL(19, 245, 15), // "placeholderText"
QT_MOC_LITERAL(20, 261, 18) // "clearButtonEnabled"

    },
    "Dtk::Widget::DIpv4LineEdit\0focusChanged\0"
    "\0focus\0setCursorPosition\0cursorPosition\0"
    "setReadOnly\0readOnly\0setSelection\0"
    "start\0length\0selectAll\0_q_updateLineEditText\0"
    "_q_setIpLineEditText\0displayText\0"
    "alignment\0Qt::Alignment\0selectedText\0"
    "acceptableInput\0placeholderText\0"
    "clearButtonEnabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DIpv4LineEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       8,   68, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   52,    2, 0x0a /* Public */,
       6,    1,   55,    2, 0x0a /* Public */,
       8,    2,   58,    2, 0x0a /* Public */,
      11,    0,   63,    2, 0x0a /* Public */,
      12,    0,   64,    2, 0x08 /* Private */,
      13,    1,   65,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,

 // properties: name, type, flags
      14, QMetaType::QString, 0x00095001,
       5, QMetaType::Int, 0x00095103,
      15, 0x80000000 | 16, 0x00095009,
      17, QMetaType::QString, 0x00095001,
      18, QMetaType::Bool, 0x00095001,
       7, QMetaType::Bool, 0x00095103,
      19, QMetaType::QString, 0x00095001,
      20, QMetaType::Bool, 0x00095001,

       0        // eod
};

void Dtk::Widget::DIpv4LineEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DIpv4LineEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->focusChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->setCursorPosition((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->setReadOnly((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setSelection((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->selectAll(); break;
        case 5: _t->d_func()->_q_updateLineEditText(); break;
        case 6: _t->d_func()->_q_setIpLineEditText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DIpv4LineEdit::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DIpv4LineEdit::focusChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DIpv4LineEdit *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->displayText(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->cursorPosition(); break;
        case 2: *reinterpret_cast< Qt::Alignment*>(_v) = _t->alignment(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->selectedText(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->hasAcceptableInput(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isReadOnly(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->placeholderText(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->isClearButtonEnabled(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DIpv4LineEdit *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setCursorPosition(*reinterpret_cast< int*>(_v)); break;
        case 5: _t->setReadOnly(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DIpv4LineEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QLineEdit::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DIpv4LineEdit.data,
    qt_meta_data_Dtk__Widget__DIpv4LineEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DIpv4LineEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DIpv4LineEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DIpv4LineEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Core::DObject"))
        return static_cast< Core::DObject*>(this);
    return QLineEdit::qt_metacast(_clname);
}

int Dtk::Widget::DIpv4LineEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DIpv4LineEdit::focusChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
