/****************************************************************************
** Meta object code from reading C++ file 'dsplitscreen_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/widgets/private/dsplitscreen_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dsplitscreen_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget23DSplitScreenPlaceholderE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DSplitScreenPlaceholder::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget23DSplitScreenPlaceholderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DSplitScreenPlaceholder",
        "Position",
        "PositionFlag",
        "Left",
        "Right",
        "Top",
        "Bottom"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'Position'
        QtMocHelpers::EnumData<Position>(1, 2, QMC::EnumIsFlag).add({
            {    3, PositionFlag::Left },
            {    4, PositionFlag::Right },
            {    5, PositionFlag::Top },
            {    6, PositionFlag::Bottom },
        }),
    };
    return QtMocHelpers::metaObjectData<DSplitScreenPlaceholder, qt_meta_tag_ZN3Dtk6Widget23DSplitScreenPlaceholderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DSplitScreenPlaceholder::staticMetaObject = { {
    QMetaObject::SuperData::link<DPushButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget23DSplitScreenPlaceholderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget23DSplitScreenPlaceholderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget23DSplitScreenPlaceholderE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DSplitScreenPlaceholder::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DSplitScreenPlaceholder *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Dtk::Widget::DSplitScreenPlaceholder::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DSplitScreenPlaceholder::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget23DSplitScreenPlaceholderE_t>.strings))
        return static_cast<void*>(this);
    return DPushButton::qt_metacast(_clname);
}

int Dtk::Widget::DSplitScreenPlaceholder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DPushButton::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget16DSplitScreenCellE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DSplitScreenCell::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget16DSplitScreenCellE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DSplitScreenCell",
        "screenSelected",
        "",
        "DSplitScreenCell::Mode",
        "type",
        "DSplitScreenPlaceholder::Position",
        "position",
        "onScreenPlaceholderSelected",
        "Mode",
        "ModeFlag",
        "TwoSplit",
        "ThreeSplit",
        "FourSplit",
        "SupportTwoSplit",
        "SupportFourSplit",
        "PositionType",
        "Left"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'screenSelected'
        QtMocHelpers::SignalData<void(DSplitScreenCell::Mode, DSplitScreenPlaceholder::Position)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'onScreenPlaceholderSelected'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'Mode'
        QtMocHelpers::EnumData<Mode>(8, 9, QMC::EnumIsFlag).add({
            {   10, ModeFlag::TwoSplit },
            {   11, ModeFlag::ThreeSplit },
            {   12, ModeFlag::FourSplit },
            {   13, ModeFlag::SupportTwoSplit },
            {   14, ModeFlag::SupportFourSplit },
            {   15, ModeFlag::PositionType },
            {   16, ModeFlag::Left },
        }),
    };
    return QtMocHelpers::metaObjectData<DSplitScreenCell, qt_meta_tag_ZN3Dtk6Widget16DSplitScreenCellE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DSplitScreenCell::staticMetaObject = { {
    QMetaObject::SuperData::link<DFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget16DSplitScreenCellE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget16DSplitScreenCellE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget16DSplitScreenCellE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DSplitScreenCell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DSplitScreenCell *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->screenSelected((*reinterpret_cast<std::add_pointer_t<DSplitScreenCell::Mode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DSplitScreenPlaceholder::Position>>(_a[2]))); break;
        case 1: _t->onScreenPlaceholderSelected(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DSplitScreenCell::*)(DSplitScreenCell::Mode , DSplitScreenPlaceholder::Position )>(_a, &DSplitScreenCell::screenSelected, 0))
            return;
    }
}

const QMetaObject *Dtk::Widget::DSplitScreenCell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DSplitScreenCell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget16DSplitScreenCellE_t>.strings))
        return static_cast<void*>(this);
    return DFrame::qt_metacast(_clname);
}

int Dtk::Widget::DSplitScreenCell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DSplitScreenCell::screenSelected(DSplitScreenCell::Mode _t1, DSplitScreenPlaceholder::Position _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN3Dtk6Widget18DSplitScreenWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DSplitScreenWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget18DSplitScreenWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DSplitScreenWidget",
        "onThemeTypeChanged",
        "",
        "Gui::DGuiApplicationHelper::ColorType",
        "ct",
        "onScreenSelected",
        "DSplitScreenCell::Mode",
        "type",
        "DSplitScreenPlaceholder::Position",
        "position"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onThemeTypeChanged'
        QtMocHelpers::SlotData<void(Gui::DGuiApplicationHelper::ColorType)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onScreenSelected'
        QtMocHelpers::SlotData<void(DSplitScreenCell::Mode, DSplitScreenPlaceholder::Position)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DSplitScreenWidget, qt_meta_tag_ZN3Dtk6Widget18DSplitScreenWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DSplitScreenWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DBlurEffectWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget18DSplitScreenWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget18DSplitScreenWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget18DSplitScreenWidgetE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DSplitScreenWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DSplitScreenWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onThemeTypeChanged((*reinterpret_cast<std::add_pointer_t<Gui::DGuiApplicationHelper::ColorType>>(_a[1]))); break;
        case 1: _t->onScreenSelected((*reinterpret_cast<std::add_pointer_t<DSplitScreenCell::Mode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DSplitScreenPlaceholder::Position>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *Dtk::Widget::DSplitScreenWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DSplitScreenWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget18DSplitScreenWidgetE_t>.strings))
        return static_cast<void*>(this);
    return DBlurEffectWidget::qt_metacast(_clname);
}

int Dtk::Widget::DSplitScreenWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DBlurEffectWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
