/****************************************************************************
** Meta object code from reading C++ file 'dapplication.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dapplication.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget12DApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DApplication::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget12DApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DApplication",
        "newInstanceStarted",
        "",
        "iconThemeChanged",
        "screenDevicePixelRatioChanged",
        "QScreen*",
        "screen",
        "_q_onNewInstanceStarted",
        "_q_panWindowContentsForVirtualKeyboard",
        "_q_resizeWindowContentsForVirtualKeyboard",
        "_q_sizeModeChanged",
        "visibleMenuShortcutText",
        "visibleMenuCheckboxWidget",
        "visibleMenuIcon",
        "autoActivateWindows",
        "applicationCreditsFile",
        "applicationCreditsContent",
        "licensePath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newInstanceStarted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconThemeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenDevicePixelRatioChanged'
        QtMocHelpers::SignalData<void(QScreen *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot '_q_onNewInstanceStarted'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_panWindowContentsForVirtualKeyboard'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_resizeWindowContentsForVirtualKeyboard'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_sizeModeChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'visibleMenuShortcutText'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'visibleMenuCheckboxWidget'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'visibleMenuIcon'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'autoActivateWindows'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'applicationCreditsFile'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'applicationCreditsContent'
        QtMocHelpers::PropertyData<QByteArray>(16, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'licensePath'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DApplication, qt_meta_tag_ZN3Dtk6Widget12DApplicationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<QApplication::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget12DApplicationE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DApplication *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newInstanceStarted(); break;
        case 1: _t->iconThemeChanged(); break;
        case 2: _t->screenDevicePixelRatioChanged((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 3: _t->d_func()->_q_onNewInstanceStarted(); break;
        case 4: _t->d_func()->_q_panWindowContentsForVirtualKeyboard(); break;
        case 5: _t->d_func()->_q_resizeWindowContentsForVirtualKeyboard(); break;
        case 6: _t->d_func()->_q_sizeModeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DApplication::*)()>(_a, &DApplication::newInstanceStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DApplication::*)()>(_a, &DApplication::iconThemeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DApplication::*)(QScreen * )>(_a, &DApplication::screenDevicePixelRatioChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->visibleMenuShortcutText(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->visibleMenuCheckboxWidget(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->visibleMenuIcon(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->autoActivateWindows(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->applicationCreditsFile(); break;
        case 5: *reinterpret_cast<QByteArray*>(_v) = _t->applicationCreditsContent(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->licensePath(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisibleMenuShortcutText(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setVisibleMenuCheckboxWidget(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setVisibleMenuIcon(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setAutoActivateWindows(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setApplicationCreditsFile(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setApplicationCreditsContent(*reinterpret_cast<QByteArray*>(_v)); break;
        case 6: _t->setLicensePath(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DApplicationE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QApplication::qt_metacast(_clname);
}

int Dtk::Widget::DApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DApplication::newInstanceStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DApplication::iconThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DApplication::screenDevicePixelRatioChanged(QScreen * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
