/****************************************************************************
** Meta object code from reading C++ file 'dbusmpris.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/widgets/private/mpris/dbusmpris.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusmpris.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DBusMPRIS_t {
    QByteArrayData data[53];
    char stringdata0[613];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DBusMPRIS_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DBusMPRIS_t qt_meta_stringdata_DBusMPRIS = {
    {
QT_MOC_LITERAL(0, 0, 9), // "DBusMPRIS"
QT_MOC_LITERAL(1, 10, 6), // "Seeked"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 8), // "Position"
QT_MOC_LITERAL(4, 27, 17), // "CanControlChanged"
QT_MOC_LITERAL(5, 45, 5), // "value"
QT_MOC_LITERAL(6, 51, 18), // "CanShowInUIChanged"
QT_MOC_LITERAL(7, 70, 16), // "CanGoNextChanged"
QT_MOC_LITERAL(8, 87, 20), // "CanGoPreviousChanged"
QT_MOC_LITERAL(9, 108, 15), // "CanPauseChanged"
QT_MOC_LITERAL(10, 124, 14), // "CanPlayChanged"
QT_MOC_LITERAL(11, 139, 14), // "CanSeekChanged"
QT_MOC_LITERAL(12, 154, 17), // "LoopStatusChanged"
QT_MOC_LITERAL(13, 172, 18), // "MaximumRateChanged"
QT_MOC_LITERAL(14, 191, 15), // "MetadataChanged"
QT_MOC_LITERAL(15, 207, 18), // "MinimumRateChanged"
QT_MOC_LITERAL(16, 226, 21), // "PlaybackStatusChanged"
QT_MOC_LITERAL(17, 248, 15), // "PositionChanged"
QT_MOC_LITERAL(18, 264, 11), // "RateChanged"
QT_MOC_LITERAL(19, 276, 14), // "ShuffleChanged"
QT_MOC_LITERAL(20, 291, 13), // "VolumeChanged"
QT_MOC_LITERAL(21, 305, 19), // "__propertyChanged__"
QT_MOC_LITERAL(22, 325, 12), // "QDBusMessage"
QT_MOC_LITERAL(23, 338, 3), // "msg"
QT_MOC_LITERAL(24, 342, 4), // "Next"
QT_MOC_LITERAL(25, 347, 19), // "QDBusPendingReply<>"
QT_MOC_LITERAL(26, 367, 7), // "OpenUri"
QT_MOC_LITERAL(27, 375, 3), // "Uri"
QT_MOC_LITERAL(28, 379, 5), // "Pause"
QT_MOC_LITERAL(29, 385, 4), // "Play"
QT_MOC_LITERAL(30, 390, 9), // "PlayPause"
QT_MOC_LITERAL(31, 400, 8), // "Previous"
QT_MOC_LITERAL(32, 409, 4), // "Seek"
QT_MOC_LITERAL(33, 414, 6), // "Offset"
QT_MOC_LITERAL(34, 421, 11), // "SetPosition"
QT_MOC_LITERAL(35, 433, 15), // "QDBusObjectPath"
QT_MOC_LITERAL(36, 449, 7), // "TrackId"
QT_MOC_LITERAL(37, 457, 4), // "Stop"
QT_MOC_LITERAL(38, 462, 10), // "CanControl"
QT_MOC_LITERAL(39, 473, 11), // "CanShowInUI"
QT_MOC_LITERAL(40, 485, 9), // "CanGoNext"
QT_MOC_LITERAL(41, 495, 13), // "CanGoPrevious"
QT_MOC_LITERAL(42, 509, 8), // "CanPause"
QT_MOC_LITERAL(43, 518, 7), // "CanPlay"
QT_MOC_LITERAL(44, 526, 7), // "CanSeek"
QT_MOC_LITERAL(45, 534, 10), // "LoopStatus"
QT_MOC_LITERAL(46, 545, 11), // "MaximumRate"
QT_MOC_LITERAL(47, 557, 8), // "Metadata"
QT_MOC_LITERAL(48, 566, 11), // "MinimumRate"
QT_MOC_LITERAL(49, 578, 14), // "PlaybackStatus"
QT_MOC_LITERAL(50, 593, 4), // "Rate"
QT_MOC_LITERAL(51, 598, 7), // "Shuffle"
QT_MOC_LITERAL(52, 606, 6) // "Volume"

    },
    "DBusMPRIS\0Seeked\0\0Position\0CanControlChanged\0"
    "value\0CanShowInUIChanged\0CanGoNextChanged\0"
    "CanGoPreviousChanged\0CanPauseChanged\0"
    "CanPlayChanged\0CanSeekChanged\0"
    "LoopStatusChanged\0MaximumRateChanged\0"
    "MetadataChanged\0MinimumRateChanged\0"
    "PlaybackStatusChanged\0PositionChanged\0"
    "RateChanged\0ShuffleChanged\0VolumeChanged\0"
    "__propertyChanged__\0QDBusMessage\0msg\0"
    "Next\0QDBusPendingReply<>\0OpenUri\0Uri\0"
    "Pause\0Play\0PlayPause\0Previous\0Seek\0"
    "Offset\0SetPosition\0QDBusObjectPath\0"
    "TrackId\0Stop\0CanControl\0CanShowInUI\0"
    "CanGoNext\0CanGoPrevious\0CanPause\0"
    "CanPlay\0CanSeek\0LoopStatus\0MaximumRate\0"
    "Metadata\0MinimumRate\0PlaybackStatus\0"
    "Rate\0Shuffle\0Volume"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DBusMPRIS[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      27,   14, // methods
      16,  220, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      17,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  149,    2, 0x06 /* Public */,
       4,    1,  152,    2, 0x06 /* Public */,
       6,    1,  155,    2, 0x06 /* Public */,
       7,    1,  158,    2, 0x06 /* Public */,
       8,    1,  161,    2, 0x06 /* Public */,
       9,    1,  164,    2, 0x06 /* Public */,
      10,    1,  167,    2, 0x06 /* Public */,
      11,    1,  170,    2, 0x06 /* Public */,
      12,    1,  173,    2, 0x06 /* Public */,
      13,    1,  176,    2, 0x06 /* Public */,
      14,    1,  179,    2, 0x06 /* Public */,
      15,    1,  182,    2, 0x06 /* Public */,
      16,    1,  185,    2, 0x06 /* Public */,
      17,    1,  188,    2, 0x06 /* Public */,
      18,    1,  191,    2, 0x06 /* Public */,
      19,    1,  194,    2, 0x06 /* Public */,
      20,    1,  197,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      21,    1,  200,    2, 0x08 /* Private */,
      24,    0,  203,    2, 0x0a /* Public */,
      26,    1,  204,    2, 0x0a /* Public */,
      28,    0,  207,    2, 0x0a /* Public */,
      29,    0,  208,    2, 0x0a /* Public */,
      30,    0,  209,    2, 0x0a /* Public */,
      31,    0,  210,    2, 0x0a /* Public */,
      32,    1,  211,    2, 0x0a /* Public */,
      34,    2,  214,    2, 0x0a /* Public */,
      37,    0,  219,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::LongLong,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::Double,    5,
    QMetaType::Void, QMetaType::QVariantMap,    5,
    QMetaType::Void, QMetaType::Double,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::LongLong,    5,
    QMetaType::Void, QMetaType::Double,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Double,    5,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 22,   23,
    0x80000000 | 25,
    0x80000000 | 25, QMetaType::QString,   27,
    0x80000000 | 25,
    0x80000000 | 25,
    0x80000000 | 25,
    0x80000000 | 25,
    0x80000000 | 25, QMetaType::LongLong,   33,
    0x80000000 | 25, 0x80000000 | 35, QMetaType::LongLong,   36,    3,
    0x80000000 | 25,

 // properties: name, type, flags
      38, QMetaType::Bool, 0x00495001,
      39, QMetaType::Bool, 0x00495001,
      40, QMetaType::Bool, 0x00495001,
      41, QMetaType::Bool, 0x00495001,
      42, QMetaType::Bool, 0x00495001,
      43, QMetaType::Bool, 0x00495001,
      44, QMetaType::Bool, 0x00495001,
      45, QMetaType::QString, 0x00495103,
      46, QMetaType::Double, 0x00495001,
      47, QMetaType::QVariantMap, 0x00495001,
      48, QMetaType::Double, 0x00495001,
      49, QMetaType::QString, 0x00495001,
       3, QMetaType::LongLong, 0x00495001,
      50, QMetaType::Double, 0x00495103,
      51, QMetaType::Bool, 0x00495103,
      52, QMetaType::Double, 0x00495103,

 // properties: notify_signal_id
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
      11,
      12,
      13,
      14,
      15,
      16,

       0        // eod
};

void DBusMPRIS::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DBusMPRIS *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->Seeked((*reinterpret_cast< qlonglong(*)>(_a[1]))); break;
        case 1: _t->CanControlChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->CanShowInUIChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->CanGoNextChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->CanGoPreviousChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->CanPauseChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->CanPlayChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->CanSeekChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->LoopStatusChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->MaximumRateChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 10: _t->MetadataChanged((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 11: _t->MinimumRateChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 12: _t->PlaybackStatusChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->PositionChanged((*reinterpret_cast< qlonglong(*)>(_a[1]))); break;
        case 14: _t->RateChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 15: _t->ShuffleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->VolumeChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 17: _t->__propertyChanged__((*reinterpret_cast< const QDBusMessage(*)>(_a[1]))); break;
        case 18: { QDBusPendingReply<> _r = _t->Next();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->OpenUri((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->Pause();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->Play();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->PlayPause();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->Previous();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->Seek((*reinterpret_cast< qlonglong(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->SetPosition((*reinterpret_cast< const QDBusObjectPath(*)>(_a[1])),(*reinterpret_cast< qlonglong(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->Stop();
            if (_a[0]) *reinterpret_cast< QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusMessage >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DBusMPRIS::*)(qlonglong );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::Seeked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::CanControlChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::CanShowInUIChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::CanGoNextChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::CanGoPreviousChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::CanPauseChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::CanPlayChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::CanSeekChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::LoopStatusChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::MaximumRateChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(const QVariantMap & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::MetadataChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::MinimumRateChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::PlaybackStatusChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(qlonglong );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::PositionChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::RateChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::ShuffleChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (DBusMPRIS::*)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBusMPRIS::VolumeChanged)) {
                *result = 16;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DBusMPRIS *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->canControl(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->canShowInUI(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->canGoNext(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->canGoPrevious(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->canPause(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->canPlay(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->canSeek(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->loopStatus(); break;
        case 8: *reinterpret_cast< double*>(_v) = _t->maximumRate(); break;
        case 9: *reinterpret_cast< QVariantMap*>(_v) = _t->metadata(); break;
        case 10: *reinterpret_cast< double*>(_v) = _t->minimumRate(); break;
        case 11: *reinterpret_cast< QString*>(_v) = _t->playbackStatus(); break;
        case 12: *reinterpret_cast< qlonglong*>(_v) = _t->position(); break;
        case 13: *reinterpret_cast< double*>(_v) = _t->rate(); break;
        case 14: *reinterpret_cast< bool*>(_v) = _t->shuffle(); break;
        case 15: *reinterpret_cast< double*>(_v) = _t->volume(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DBusMPRIS *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 7: _t->setLoopStatus(*reinterpret_cast< QString*>(_v)); break;
        case 13: _t->setRate(*reinterpret_cast< double*>(_v)); break;
        case 14: _t->setShuffle(*reinterpret_cast< bool*>(_v)); break;
        case 15: _t->setVolume(*reinterpret_cast< double*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DBusMPRIS::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_meta_stringdata_DBusMPRIS.data,
    qt_meta_data_DBusMPRIS,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DBusMPRIS::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusMPRIS::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DBusMPRIS.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusMPRIS::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 16;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 16;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void DBusMPRIS::Seeked(qlonglong _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DBusMPRIS::CanControlChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DBusMPRIS::CanShowInUIChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DBusMPRIS::CanGoNextChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void DBusMPRIS::CanGoPreviousChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void DBusMPRIS::CanPauseChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void DBusMPRIS::CanPlayChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void DBusMPRIS::CanSeekChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void DBusMPRIS::LoopStatusChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void DBusMPRIS::MaximumRateChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void DBusMPRIS::MetadataChanged(const QVariantMap & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void DBusMPRIS::MinimumRateChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void DBusMPRIS::PlaybackStatusChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void DBusMPRIS::PositionChanged(qlonglong _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void DBusMPRIS::RateChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void DBusMPRIS::ShuffleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void DBusMPRIS::VolumeChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
