/****************************************************************************
** Meta object code from reading C++ file 'dtitlebareditpanel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/widgets/private/dtitlebareditpanel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dtitlebareditpanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__PlaceHoderWidget_t {
    QByteArrayData data[1];
    char stringdata0[30];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__PlaceHoderWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__PlaceHoderWidget_t qt_meta_stringdata_Dtk__Widget__PlaceHoderWidget = {
    {
QT_MOC_LITERAL(0, 0, 29) // "Dtk::Widget::PlaceHoderWidget"

    },
    "Dtk::Widget::PlaceHoderWidget"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__PlaceHoderWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Dtk::Widget::PlaceHoderWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::PlaceHoderWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__PlaceHoderWidget.data,
    qt_meta_data_Dtk__Widget__PlaceHoderWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::PlaceHoderWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::PlaceHoderWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__PlaceHoderWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::PlaceHoderWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Widget__DragDropWidget_t {
    QByteArrayData data[1];
    char stringdata0[28];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DragDropWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DragDropWidget_t qt_meta_stringdata_Dtk__Widget__DragDropWidget = {
    {
QT_MOC_LITERAL(0, 0, 27) // "Dtk::Widget::DragDropWidget"

    },
    "Dtk::Widget::DragDropWidget"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DragDropWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Dtk::Widget::DragDropWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DragDropWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DIconButton::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DragDropWidget.data,
    qt_meta_data_Dtk__Widget__DragDropWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DragDropWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DragDropWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DragDropWidget.stringdata0))
        return static_cast<void*>(this);
    return DIconButton::qt_metacast(_clname);
}

int Dtk::Widget::DragDropWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DIconButton::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Widget__IconTextWidget_t {
    QByteArrayData data[1];
    char stringdata0[28];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__IconTextWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__IconTextWidget_t qt_meta_stringdata_Dtk__Widget__IconTextWidget = {
    {
QT_MOC_LITERAL(0, 0, 27) // "Dtk::Widget::IconTextWidget"

    },
    "Dtk::Widget::IconTextWidget"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__IconTextWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Dtk::Widget::IconTextWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::IconTextWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__IconTextWidget.data,
    qt_meta_data_Dtk__Widget__IconTextWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::IconTextWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::IconTextWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__IconTextWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::IconTextWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Widget__DCollapseWidget_t {
    QByteArrayData data[1];
    char stringdata0[29];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DCollapseWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DCollapseWidget_t qt_meta_stringdata_Dtk__Widget__DCollapseWidget = {
    {
QT_MOC_LITERAL(0, 0, 28) // "Dtk::Widget::DCollapseWidget"

    },
    "Dtk::Widget::DCollapseWidget"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DCollapseWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Dtk::Widget::DCollapseWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DCollapseWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DCollapseWidget.data,
    qt_meta_data_Dtk__Widget__DCollapseWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DCollapseWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DCollapseWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DCollapseWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Dtk::Widget::DCollapseWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Widget__DTitlebarCustomWidget_t {
    QByteArrayData data[1];
    char stringdata0[35];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DTitlebarCustomWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DTitlebarCustomWidget_t qt_meta_stringdata_Dtk__Widget__DTitlebarCustomWidget = {
    {
QT_MOC_LITERAL(0, 0, 34) // "Dtk::Widget::DTitlebarCustomW..."

    },
    "Dtk::Widget::DTitlebarCustomWidget"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DTitlebarCustomWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Dtk::Widget::DTitlebarCustomWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DTitlebarCustomWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DCollapseWidget::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DTitlebarCustomWidget.data,
    qt_meta_data_Dtk__Widget__DTitlebarCustomWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DTitlebarCustomWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DTitlebarCustomWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DTitlebarCustomWidget.stringdata0))
        return static_cast<void*>(this);
    return DCollapseWidget::qt_metacast(_clname);
}

int Dtk::Widget::DTitlebarCustomWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DCollapseWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Dtk__Widget__DTitlebarEditPanel_t {
    QByteArrayData data[9];
    char stringdata0[116];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DTitlebarEditPanel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DTitlebarEditPanel_t qt_meta_stringdata_Dtk__Widget__DTitlebarEditPanel = {
    {
QT_MOC_LITERAL(0, 0, 31), // "Dtk::Widget::DTitlebarEditPanel"
QT_MOC_LITERAL(1, 32, 14), // "addingToolView"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 3), // "key"
QT_MOC_LITERAL(4, 52, 3), // "pos"
QT_MOC_LITERAL(5, 56, 15), // "removedToolView"
QT_MOC_LITERAL(6, 72, 13), // "movedToolView"
QT_MOC_LITERAL(7, 86, 13), // "resetToolView"
QT_MOC_LITERAL(8, 100, 15) // "startScreenShot"

    },
    "Dtk::Widget::DTitlebarEditPanel\0"
    "addingToolView\0\0key\0pos\0removedToolView\0"
    "movedToolView\0resetToolView\0startScreenShot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DTitlebarEditPanel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   39,    2, 0x06 /* Public */,
       5,    2,   44,    2, 0x06 /* Public */,
       6,    2,   49,    2, 0x06 /* Public */,
       7,    0,   54,    2, 0x06 /* Public */,
       8,    0,   55,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    3,    4,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    3,    4,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    3,    4,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Dtk::Widget::DTitlebarEditPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DTitlebarEditPanel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->addingToolView((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const int(*)>(_a[2]))); break;
        case 1: _t->removedToolView((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const int(*)>(_a[2]))); break;
        case 2: _t->movedToolView((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const int(*)>(_a[2]))); break;
        case 3: _t->resetToolView(); break;
        case 4: _t->startScreenShot(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DTitlebarEditPanel::*)(const QString & , const int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTitlebarEditPanel::addingToolView)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DTitlebarEditPanel::*)(const QString & , const int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTitlebarEditPanel::removedToolView)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DTitlebarEditPanel::*)(const QString & , const int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTitlebarEditPanel::movedToolView)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DTitlebarEditPanel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTitlebarEditPanel::resetToolView)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DTitlebarEditPanel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DTitlebarEditPanel::startScreenShot)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DTitlebarEditPanel::staticMetaObject = { {
    QMetaObject::SuperData::link<DCollapseWidget::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DTitlebarEditPanel.data,
    qt_meta_data_Dtk__Widget__DTitlebarEditPanel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DTitlebarEditPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DTitlebarEditPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DTitlebarEditPanel.stringdata0))
        return static_cast<void*>(this);
    return DCollapseWidget::qt_metacast(_clname);
}

int Dtk::Widget::DTitlebarEditPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DCollapseWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DTitlebarEditPanel::addingToolView(const QString & _t1, const int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Widget::DTitlebarEditPanel::removedToolView(const QString & _t1, const int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Dtk::Widget::DTitlebarEditPanel::movedToolView(const QString & _t1, const int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Widget::DTitlebarEditPanel::resetToolView()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Widget::DTitlebarEditPanel::startScreenShot()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
struct qt_meta_stringdata_Dtk__Widget__DToolbarEditPanel_t {
    QByteArrayData data[4];
    char stringdata0[70];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DToolbarEditPanel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DToolbarEditPanel_t qt_meta_stringdata_Dtk__Widget__DToolbarEditPanel = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Dtk::Widget::DToolbarEditPanel"
QT_MOC_LITERAL(1, 31, 17), // "confirmBtnClicked"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 19) // "onConfirmBtnClicked"

    },
    "Dtk::Widget::DToolbarEditPanel\0"
    "confirmBtnClicked\0\0onConfirmBtnClicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DToolbarEditPanel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   25,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void Dtk::Widget::DToolbarEditPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DToolbarEditPanel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->confirmBtnClicked(); break;
        case 1: _t->onConfirmBtnClicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DToolbarEditPanel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DToolbarEditPanel::confirmBtnClicked)) {
                *result = 0;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DToolbarEditPanel::staticMetaObject = { {
    QMetaObject::SuperData::link<DBlurEffectWidget::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DToolbarEditPanel.data,
    qt_meta_data_Dtk__Widget__DToolbarEditPanel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DToolbarEditPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DToolbarEditPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DToolbarEditPanel.stringdata0))
        return static_cast<void*>(this);
    return DBlurEffectWidget::qt_metacast(_clname);
}

int Dtk::Widget::DToolbarEditPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DBlurEffectWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DToolbarEditPanel::confirmBtnClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
