/****************************************************************************
** Meta object code from reading C++ file 'editexample.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../examples/collections/editexample.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editexample.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17EditExampleWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto EditExampleWindow::qt_create_metaobjectdata<qt_meta_tag_ZN17EditExampleWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditExampleWindow"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditExampleWindow, qt_meta_tag_ZN17EditExampleWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EditExampleWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<PageWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EditExampleWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EditExampleWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17EditExampleWindowE_t>.metaTypes,
    nullptr
} };

void EditExampleWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditExampleWindow *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *EditExampleWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditExampleWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EditExampleWindowE_t>.strings))
        return static_cast<void*>(this);
    return PageWindowInterface::qt_metacast(_clname);
}

int EditExampleWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PageWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18DSearchEditExampleE_t {};
} // unnamed namespace

template <> constexpr inline auto DSearchEditExample::qt_create_metaobjectdata<qt_meta_tag_ZN18DSearchEditExampleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DSearchEditExample"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DSearchEditExample, qt_meta_tag_ZN18DSearchEditExampleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DSearchEditExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DSearchEditExampleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DSearchEditExampleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18DSearchEditExampleE_t>.metaTypes,
    nullptr
} };

void DSearchEditExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DSearchEditExample *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DSearchEditExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DSearchEditExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DSearchEditExampleE_t>.strings))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DSearchEditExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN16DLineEditExampleE_t {};
} // unnamed namespace

template <> constexpr inline auto DLineEditExample::qt_create_metaobjectdata<qt_meta_tag_ZN16DLineEditExampleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DLineEditExample"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DLineEditExample, qt_meta_tag_ZN16DLineEditExampleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DLineEditExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DLineEditExampleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DLineEditExampleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DLineEditExampleE_t>.metaTypes,
    nullptr
} };

void DLineEditExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DLineEditExample *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DLineEditExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DLineEditExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DLineEditExampleE_t>.strings))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DLineEditExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN20DIpv4LineEditExampleE_t {};
} // unnamed namespace

template <> constexpr inline auto DIpv4LineEditExample::qt_create_metaobjectdata<qt_meta_tag_ZN20DIpv4LineEditExampleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DIpv4LineEditExample"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DIpv4LineEditExample, qt_meta_tag_ZN20DIpv4LineEditExampleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DIpv4LineEditExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DIpv4LineEditExampleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DIpv4LineEditExampleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20DIpv4LineEditExampleE_t>.metaTypes,
    nullptr
} };

void DIpv4LineEditExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DIpv4LineEditExample *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DIpv4LineEditExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DIpv4LineEditExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DIpv4LineEditExampleE_t>.strings))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DIpv4LineEditExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN20DPasswordEditExampleE_t {};
} // unnamed namespace

template <> constexpr inline auto DPasswordEditExample::qt_create_metaobjectdata<qt_meta_tag_ZN20DPasswordEditExampleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DPasswordEditExample"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DPasswordEditExample, qt_meta_tag_ZN20DPasswordEditExampleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DPasswordEditExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DPasswordEditExampleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DPasswordEditExampleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20DPasswordEditExampleE_t>.metaTypes,
    nullptr
} };

void DPasswordEditExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DPasswordEditExample *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DPasswordEditExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DPasswordEditExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DPasswordEditExampleE_t>.strings))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DPasswordEditExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN23DFileChooserEditExampleE_t {};
} // unnamed namespace

template <> constexpr inline auto DFileChooserEditExample::qt_create_metaobjectdata<qt_meta_tag_ZN23DFileChooserEditExampleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DFileChooserEditExample"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DFileChooserEditExample, qt_meta_tag_ZN23DFileChooserEditExampleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DFileChooserEditExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DFileChooserEditExampleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DFileChooserEditExampleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23DFileChooserEditExampleE_t>.metaTypes,
    nullptr
} };

void DFileChooserEditExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DFileChooserEditExample *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DFileChooserEditExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DFileChooserEditExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DFileChooserEditExampleE_t>.strings))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DFileChooserEditExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN15DSpinBoxExampleE_t {};
} // unnamed namespace

template <> constexpr inline auto DSpinBoxExample::qt_create_metaobjectdata<qt_meta_tag_ZN15DSpinBoxExampleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DSpinBoxExample"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DSpinBoxExample, qt_meta_tag_ZN15DSpinBoxExampleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DSpinBoxExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DSpinBoxExampleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DSpinBoxExampleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DSpinBoxExampleE_t>.metaTypes,
    nullptr
} };

void DSpinBoxExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DSpinBoxExample *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DSpinBoxExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DSpinBoxExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DSpinBoxExampleE_t>.strings))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DSpinBoxExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN16DTextEditExampleE_t {};
} // unnamed namespace

template <> constexpr inline auto DTextEditExample::qt_create_metaobjectdata<qt_meta_tag_ZN16DTextEditExampleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DTextEditExample"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DTextEditExample, qt_meta_tag_ZN16DTextEditExampleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DTextEditExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DTextEditExampleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DTextEditExampleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DTextEditExampleE_t>.metaTypes,
    nullptr
} };

void DTextEditExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DTextEditExample *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DTextEditExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DTextEditExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DTextEditExampleE_t>.strings))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DTextEditExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN23DCrumbTextFormatExampleE_t {};
} // unnamed namespace

template <> constexpr inline auto DCrumbTextFormatExample::qt_create_metaobjectdata<qt_meta_tag_ZN23DCrumbTextFormatExampleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DCrumbTextFormatExample"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DCrumbTextFormatExample, qt_meta_tag_ZN23DCrumbTextFormatExampleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DCrumbTextFormatExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DCrumbTextFormatExampleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DCrumbTextFormatExampleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23DCrumbTextFormatExampleE_t>.metaTypes,
    nullptr
} };

void DCrumbTextFormatExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DCrumbTextFormatExample *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DCrumbTextFormatExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DCrumbTextFormatExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DCrumbTextFormatExampleE_t>.strings))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DCrumbTextFormatExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN23DKeySequenceEditExampleE_t {};
} // unnamed namespace

template <> constexpr inline auto DKeySequenceEditExample::qt_create_metaobjectdata<qt_meta_tag_ZN23DKeySequenceEditExampleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DKeySequenceEditExample"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DKeySequenceEditExample, qt_meta_tag_ZN23DKeySequenceEditExampleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DKeySequenceEditExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DKeySequenceEditExampleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DKeySequenceEditExampleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23DKeySequenceEditExampleE_t>.metaTypes,
    nullptr
} };

void DKeySequenceEditExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DKeySequenceEditExample *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DKeySequenceEditExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DKeySequenceEditExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DKeySequenceEditExampleE_t>.strings))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DKeySequenceEditExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
