/****************************************************************************
** Meta object code from reading C++ file 'dsearchedit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dsearchedit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dsearchedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DSearchEdit_t {
    QByteArrayData data[9];
    char stringdata0[135];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DSearchEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DSearchEdit_t qt_meta_stringdata_Dtk__Widget__DSearchEdit = {
    {
QT_MOC_LITERAL(0, 0, 24), // "Dtk::Widget::DSearchEdit"
QT_MOC_LITERAL(1, 25, 18), // "voiceInputFinished"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 13), // "searchAborted"
QT_MOC_LITERAL(4, 59, 12), // "voiceChanged"
QT_MOC_LITERAL(5, 72, 13), // "_q_toEditMode"
QT_MOC_LITERAL(6, 86, 23), // "_q_onVoiceActionTrigger"
QT_MOC_LITERAL(7, 110, 13), // "_q_clearFocus"
QT_MOC_LITERAL(8, 124, 10) // "voiceInput"

    },
    "Dtk::Widget::DSearchEdit\0voiceInputFinished\0"
    "\0searchAborted\0voiceChanged\0_q_toEditMode\0"
    "_q_onVoiceActionTrigger\0_q_clearFocus\0"
    "voiceInput"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DSearchEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       1,   54, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,
       3,    0,   45,    2, 0x06 /* Public */,
       4,    0,   46,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   47,    2, 0x09 /* Protected */,
       6,    1,   50,    2, 0x09 /* Protected */,
       7,    0,   53,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,

 // properties: name, type, flags
       8, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       2,

       0        // eod
};

void Dtk::Widget::DSearchEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DSearchEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->voiceInputFinished(); break;
        case 1: _t->searchAborted(); break;
        case 2: _t->voiceChanged(); break;
        case 3: _t->d_func()->_q_toEditMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->d_func()->_q_onVoiceActionTrigger((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->d_func()->_q_clearFocus(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DSearchEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DSearchEdit::voiceInputFinished)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DSearchEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DSearchEdit::searchAborted)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DSearchEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DSearchEdit::voiceChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DSearchEdit *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isVoiceInput(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DSearchEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<DLineEdit::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DSearchEdit.data,
    qt_meta_data_Dtk__Widget__DSearchEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DSearchEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DSearchEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DSearchEdit.stringdata0))
        return static_cast<void*>(this);
    return DLineEdit::qt_metacast(_clname);
}

int Dtk::Widget::DSearchEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DSearchEdit::voiceInputFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DSearchEdit::searchAborted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DSearchEdit::voiceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
