/****************************************************************************
** Meta object code from reading C++ file 'dflowlayout.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dflowlayout.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dflowlayout.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget11DFlowLayoutE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DFlowLayout::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget11DFlowLayoutE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DFlowLayout",
        "horizontalSpacingChanged",
        "",
        "horizontalSpacing",
        "verticalSpacingChanged",
        "verticalSpacing",
        "countChanged",
        "count",
        "flowChanged",
        "Flow",
        "flow",
        "sizeHintChanged",
        "QSize",
        "sizeHint",
        "setHorizontalSpacing",
        "setVerticalSpacing",
        "setSpacing",
        "spacing",
        "setFlow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'horizontalSpacingChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'verticalSpacingChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'flowChanged'
        QtMocHelpers::SignalData<void(Flow)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'sizeHintChanged'
        QtMocHelpers::SignalData<void(QSize) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setHorizontalSpacing'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setVerticalSpacing'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setSpacing'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setFlow'
        QtMocHelpers::SlotData<void(Flow)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'horizontalSpacing'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'verticalSpacing'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'count'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'flow'
        QtMocHelpers::PropertyData<Flow>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'sizeHint'
        QtMocHelpers::PropertyData<QSize>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DFlowLayout, qt_meta_tag_ZN3Dtk6Widget11DFlowLayoutE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DFlowLayout::staticMetaObject = { {
    QMetaObject::SuperData::link<QLayout::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DFlowLayoutE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DFlowLayoutE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget11DFlowLayoutE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DFlowLayout::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DFlowLayout *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->horizontalSpacingChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->verticalSpacingChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->countChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->flowChanged((*reinterpret_cast<std::add_pointer_t<Flow>>(_a[1]))); break;
        case 4: _t->sizeHintChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 5: _t->setHorizontalSpacing((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setVerticalSpacing((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->setSpacing((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setFlow((*reinterpret_cast<std::add_pointer_t<Flow>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DFlowLayout::*)(int )>(_a, &DFlowLayout::horizontalSpacingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DFlowLayout::*)(int )>(_a, &DFlowLayout::verticalSpacingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DFlowLayout::*)(int )>(_a, &DFlowLayout::countChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DFlowLayout::*)(Flow )>(_a, &DFlowLayout::flowChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DFlowLayout::*)(QSize ) const>(_a, &DFlowLayout::sizeHintChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->horizontalSpacing(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->verticalSpacing(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 3: *reinterpret_cast<Flow*>(_v) = _t->flow(); break;
        case 4: *reinterpret_cast<QSize*>(_v) = _t->sizeHint(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHorizontalSpacing(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setVerticalSpacing(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setFlow(*reinterpret_cast<Flow*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DFlowLayout::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DFlowLayout::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DFlowLayoutE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QLayout::qt_metacast(_clname);
}

int Dtk::Widget::DFlowLayout::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLayout::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DFlowLayout::horizontalSpacingChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DFlowLayout::verticalSpacingChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Dtk::Widget::DFlowLayout::countChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Dtk::Widget::DFlowLayout::flowChanged(Flow _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Dtk::Widget::DFlowLayout::sizeHintChanged(QSize _t1)const
{
    QMetaObject::activate<void>(const_cast< Dtk::Widget::DFlowLayout *>(this), &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
