/****************************************************************************
** Meta object code from reading C++ file 'ddialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/ddialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ddialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DDialog_t {
    QByteArrayData data[66];
    char stringdata0[792];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DDialog_t qt_meta_stringdata_Dtk__Widget__DDialog = {
    {
QT_MOC_LITERAL(0, 0, 20), // "Dtk::Widget::DDialog"
QT_MOC_LITERAL(1, 21, 12), // "aboutToClose"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 6), // "closed"
QT_MOC_LITERAL(4, 42, 13), // "buttonClicked"
QT_MOC_LITERAL(5, 56, 5), // "index"
QT_MOC_LITERAL(6, 62, 4), // "text"
QT_MOC_LITERAL(7, 67, 12), // "titleChanged"
QT_MOC_LITERAL(8, 80, 5), // "title"
QT_MOC_LITERAL(9, 86, 14), // "messageChanged"
QT_MOC_LITERAL(10, 101, 7), // "massage"
QT_MOC_LITERAL(11, 109, 17), // "textFormatChanged"
QT_MOC_LITERAL(12, 127, 14), // "Qt::TextFormat"
QT_MOC_LITERAL(13, 142, 10), // "textFormat"
QT_MOC_LITERAL(14, 153, 11), // "sizeChanged"
QT_MOC_LITERAL(15, 165, 4), // "size"
QT_MOC_LITERAL(16, 170, 14), // "visibleChanged"
QT_MOC_LITERAL(17, 185, 7), // "visible"
QT_MOC_LITERAL(18, 193, 9), // "addButton"
QT_MOC_LITERAL(19, 203, 9), // "isDefault"
QT_MOC_LITERAL(20, 213, 10), // "ButtonType"
QT_MOC_LITERAL(21, 224, 4), // "type"
QT_MOC_LITERAL(22, 229, 10), // "addButtons"
QT_MOC_LITERAL(23, 240, 12), // "insertButton"
QT_MOC_LITERAL(24, 253, 16), // "QAbstractButton*"
QT_MOC_LITERAL(25, 270, 6), // "button"
QT_MOC_LITERAL(26, 277, 13), // "insertButtons"
QT_MOC_LITERAL(27, 291, 12), // "removeButton"
QT_MOC_LITERAL(28, 304, 18), // "removeButtonByText"
QT_MOC_LITERAL(29, 323, 12), // "clearButtons"
QT_MOC_LITERAL(30, 336, 16), // "setDefaultButton"
QT_MOC_LITERAL(31, 353, 3), // "str"
QT_MOC_LITERAL(32, 357, 10), // "addContent"
QT_MOC_LITERAL(33, 368, 8), // "QWidget*"
QT_MOC_LITERAL(34, 377, 6), // "widget"
QT_MOC_LITERAL(35, 384, 13), // "Qt::Alignment"
QT_MOC_LITERAL(36, 398, 9), // "alignment"
QT_MOC_LITERAL(37, 408, 13), // "insertContent"
QT_MOC_LITERAL(38, 422, 13), // "removeContent"
QT_MOC_LITERAL(39, 436, 8), // "isDelete"
QT_MOC_LITERAL(40, 445, 13), // "clearContents"
QT_MOC_LITERAL(41, 459, 10), // "setSpacing"
QT_MOC_LITERAL(42, 470, 7), // "spacing"
QT_MOC_LITERAL(43, 478, 10), // "addSpacing"
QT_MOC_LITERAL(44, 489, 13), // "insertSpacing"
QT_MOC_LITERAL(45, 503, 12), // "clearSpacing"
QT_MOC_LITERAL(46, 516, 13), // "setButtonText"
QT_MOC_LITERAL(47, 530, 13), // "setButtonIcon"
QT_MOC_LITERAL(48, 544, 4), // "icon"
QT_MOC_LITERAL(49, 549, 8), // "setTitle"
QT_MOC_LITERAL(50, 558, 16), // "setWordWrapTitle"
QT_MOC_LITERAL(51, 575, 8), // "wordWrap"
QT_MOC_LITERAL(52, 584, 10), // "setMessage"
QT_MOC_LITERAL(53, 595, 7), // "message"
QT_MOC_LITERAL(54, 603, 18), // "setWordWrapMessage"
QT_MOC_LITERAL(55, 622, 7), // "setIcon"
QT_MOC_LITERAL(56, 630, 12), // "expectedSize"
QT_MOC_LITERAL(57, 643, 13), // "setIconPixmap"
QT_MOC_LITERAL(58, 657, 10), // "iconPixmap"
QT_MOC_LITERAL(59, 668, 13), // "setTextFormat"
QT_MOC_LITERAL(60, 682, 23), // "setOnButtonClickedClose"
QT_MOC_LITERAL(61, 706, 20), // "onButtonClickedClose"
QT_MOC_LITERAL(62, 727, 21), // "setCloseButtonVisible"
QT_MOC_LITERAL(63, 749, 18), // "closeButtonVisible"
QT_MOC_LITERAL(64, 768, 4), // "exec"
QT_MOC_LITERAL(65, 773, 18) // "_q_onButtonClicked"

    },
    "Dtk::Widget::DDialog\0aboutToClose\0\0"
    "closed\0buttonClicked\0index\0text\0"
    "titleChanged\0title\0messageChanged\0"
    "massage\0textFormatChanged\0Qt::TextFormat\0"
    "textFormat\0sizeChanged\0size\0visibleChanged\0"
    "visible\0addButton\0isDefault\0ButtonType\0"
    "type\0addButtons\0insertButton\0"
    "QAbstractButton*\0button\0insertButtons\0"
    "removeButton\0removeButtonByText\0"
    "clearButtons\0setDefaultButton\0str\0"
    "addContent\0QWidget*\0widget\0Qt::Alignment\0"
    "alignment\0insertContent\0removeContent\0"
    "isDelete\0clearContents\0setSpacing\0"
    "spacing\0addSpacing\0insertSpacing\0"
    "clearSpacing\0setButtonText\0setButtonIcon\0"
    "icon\0setTitle\0setWordWrapTitle\0wordWrap\0"
    "setMessage\0message\0setWordWrapMessage\0"
    "setIcon\0expectedSize\0setIconPixmap\0"
    "iconPixmap\0setTextFormat\0"
    "setOnButtonClickedClose\0onButtonClickedClose\0"
    "setCloseButtonVisible\0closeButtonVisible\0"
    "exec\0_q_onButtonClicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      51,   14, // methods
       6,  454, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  269,    2, 0x06 /* Public */,
       3,    0,  270,    2, 0x06 /* Public */,
       4,    2,  271,    2, 0x06 /* Public */,
       7,    1,  276,    2, 0x06 /* Public */,
       9,    1,  279,    2, 0x06 /* Public */,
      11,    1,  282,    2, 0x06 /* Public */,
      14,    1,  285,    2, 0x06 /* Public */,
      16,    1,  288,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      18,    3,  291,    2, 0x0a /* Public */,
      18,    2,  298,    2, 0x2a /* Public | MethodCloned */,
      18,    1,  303,    2, 0x2a /* Public | MethodCloned */,
      22,    1,  306,    2, 0x0a /* Public */,
      23,    4,  309,    2, 0x0a /* Public */,
      23,    3,  318,    2, 0x2a /* Public | MethodCloned */,
      23,    2,  325,    2, 0x2a /* Public | MethodCloned */,
      23,    3,  330,    2, 0x0a /* Public */,
      23,    2,  337,    2, 0x2a /* Public | MethodCloned */,
      26,    2,  342,    2, 0x0a /* Public */,
      27,    1,  347,    2, 0x0a /* Public */,
      27,    1,  350,    2, 0x0a /* Public */,
      28,    1,  353,    2, 0x0a /* Public */,
      29,    0,  356,    2, 0x0a /* Public */,
      30,    1,  357,    2, 0x0a /* Public */,
      30,    1,  360,    2, 0x0a /* Public */,
      30,    1,  363,    2, 0x0a /* Public */,
      32,    2,  366,    2, 0x0a /* Public */,
      32,    1,  371,    2, 0x2a /* Public | MethodCloned */,
      37,    3,  374,    2, 0x0a /* Public */,
      37,    2,  381,    2, 0x2a /* Public | MethodCloned */,
      38,    2,  386,    2, 0x0a /* Public */,
      38,    1,  391,    2, 0x2a /* Public | MethodCloned */,
      40,    1,  394,    2, 0x0a /* Public */,
      40,    0,  397,    2, 0x2a /* Public | MethodCloned */,
      41,    1,  398,    2, 0x0a /* Public */,
      43,    1,  401,    2, 0x0a /* Public */,
      44,    2,  404,    2, 0x0a /* Public */,
      45,    0,  409,    2, 0x0a /* Public */,
      46,    2,  410,    2, 0x0a /* Public */,
      47,    2,  415,    2, 0x0a /* Public */,
      49,    1,  420,    2, 0x0a /* Public */,
      50,    1,  423,    2, 0x0a /* Public */,
      52,    1,  426,    2, 0x0a /* Public */,
      54,    1,  429,    2, 0x0a /* Public */,
      55,    1,  432,    2, 0x0a /* Public */,
      55,    2,  435,    2, 0x0a /* Public */,
      57,    1,  440,    2, 0x0a /* Public */,
      59,    1,  443,    2, 0x0a /* Public */,
      60,    1,  446,    2, 0x0a /* Public */,
      62,    1,  449,    2, 0x0a /* Public */,
      64,    0,  452,    2, 0x0a /* Public */,
      65,    0,  453,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    5,    6,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, QMetaType::QSize,   15,
    QMetaType::Void, QMetaType::Bool,   17,

 // slots: parameters
    QMetaType::Int, QMetaType::QString, QMetaType::Bool, 0x80000000 | 20,    6,   19,   21,
    QMetaType::Int, QMetaType::QString, QMetaType::Bool,    6,   19,
    QMetaType::Int, QMetaType::QString,    6,
    QMetaType::Int, QMetaType::QStringList,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::Bool, 0x80000000 | 20,    5,    6,   19,   21,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::Bool,    5,    6,   19,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    5,    6,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 24, QMetaType::Bool,    5,   25,   19,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 24,    5,   25,
    QMetaType::Void, QMetaType::Int, QMetaType::QStringList,    5,    6,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Bool, QMetaType::QString,   31,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void, 0x80000000 | 33, 0x80000000 | 35,   34,   36,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 33, 0x80000000 | 35,    5,   34,   36,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 33,    5,   34,
    QMetaType::Void, 0x80000000 | 33, QMetaType::Bool,   34,   39,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void, QMetaType::Bool,   39,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   42,
    QMetaType::Void, QMetaType::Int,   42,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    5,   42,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    5,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::QIcon,    5,   48,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::Bool,   51,
    QMetaType::Void, QMetaType::QString,   53,
    QMetaType::Void, QMetaType::Bool,   51,
    QMetaType::Void, QMetaType::QIcon,   48,
    QMetaType::Void, QMetaType::QIcon, QMetaType::QSize,   48,   56,
    QMetaType::Void, QMetaType::QPixmap,   58,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, QMetaType::Bool,   61,
    QMetaType::Void, QMetaType::Bool,   63,
    QMetaType::Int,
    QMetaType::Void,

 // properties: name, type, flags
       8, QMetaType::QString, 0x00495103,
      53, QMetaType::QString, 0x00495103,
      48, QMetaType::QIcon, 0x00095103,
      13, 0x80000000 | 12, 0x0049510b,
      61, QMetaType::Bool, 0x00095103,
      63, QMetaType::Bool, 0x00095103,

 // properties: notify_signal_id
       3,
       4,
       0,
       5,
       0,
       0,

       0        // eod
};

void Dtk::Widget::DDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->aboutToClose(); break;
        case 1: _t->closed(); break;
        case 2: _t->buttonClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->titleChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: _t->messageChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->textFormatChanged((*reinterpret_cast< Qt::TextFormat(*)>(_a[1]))); break;
        case 6: _t->sizeChanged((*reinterpret_cast< QSize(*)>(_a[1]))); break;
        case 7: _t->visibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: { int _r = _t->addButton((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< ButtonType(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->addButton((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->addButton((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->addButtons((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->insertButton((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< ButtonType(*)>(_a[4]))); break;
        case 13: _t->insertButton((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 14: _t->insertButton((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 15: _t->insertButton((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QAbstractButton*(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 16: _t->insertButton((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QAbstractButton*(*)>(_a[2]))); break;
        case 17: _t->insertButtons((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 18: _t->removeButton((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->removeButton((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 20: _t->removeButtonByText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->clearButtons(); break;
        case 22: { bool _r = _t->setDefaultButton((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->setDefaultButton((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->setDefaultButton((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 25: _t->addContent((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< Qt::Alignment(*)>(_a[2]))); break;
        case 26: _t->addContent((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 27: _t->insertContent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2])),(*reinterpret_cast< Qt::Alignment(*)>(_a[3]))); break;
        case 28: _t->insertContent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
        case 29: _t->removeContent((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 30: _t->removeContent((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 31: _t->clearContents((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->clearContents(); break;
        case 33: _t->setSpacing((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 34: _t->addSpacing((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 35: _t->insertSpacing((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 36: _t->clearSpacing(); break;
        case 37: _t->setButtonText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 38: _t->setButtonIcon((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QIcon(*)>(_a[2]))); break;
        case 39: _t->setTitle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 40: _t->setWordWrapTitle((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 41: _t->setMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 42: _t->setWordWrapMessage((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 43: _t->setIcon((*reinterpret_cast< const QIcon(*)>(_a[1]))); break;
        case 44: _t->setIcon((*reinterpret_cast< const QIcon(*)>(_a[1])),(*reinterpret_cast< const QSize(*)>(_a[2]))); break;
        case 45: _t->setIconPixmap((*reinterpret_cast< const QPixmap(*)>(_a[1]))); break;
        case 46: _t->setTextFormat((*reinterpret_cast< Qt::TextFormat(*)>(_a[1]))); break;
        case 47: _t->setOnButtonClickedClose((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 48: _t->setCloseButtonVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 49: { int _r = _t->exec();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 50: _t->d_func()->_q_onButtonClicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDialog::aboutToClose)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDialog::closed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DDialog::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDialog::buttonClicked)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DDialog::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDialog::titleChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DDialog::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDialog::messageChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DDialog::*)(Qt::TextFormat );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDialog::textFormatChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DDialog::*)(QSize );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDialog::sizeChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DDialog::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DDialog::visibleChanged)) {
                *result = 7;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->message(); break;
        case 2: *reinterpret_cast< QIcon*>(_v) = _t->icon(); break;
        case 3: *reinterpret_cast< Qt::TextFormat*>(_v) = _t->textFormat(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->onButtonClickedClose(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->closeButtonVisible(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTitle(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setMessage(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setIcon(*reinterpret_cast< QIcon*>(_v)); break;
        case 3: _t->setTextFormat(*reinterpret_cast< Qt::TextFormat*>(_v)); break;
        case 4: _t->setOnButtonClickedClose(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setCloseButtonVisible(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<DAbstractDialog::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DDialog.data,
    qt_meta_data_Dtk__Widget__DDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Widget::DDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DDialog.stringdata0))
        return static_cast<void*>(this);
    return DAbstractDialog::qt_metacast(_clname);
}

int Dtk::Widget::DDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DAbstractDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DDialog::aboutToClose()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DDialog::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DDialog::buttonClicked(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Dtk::Widget::DDialog::titleChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Dtk::Widget::DDialog::messageChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Dtk::Widget::DDialog::textFormatChanged(Qt::TextFormat _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Dtk::Widget::DDialog::sizeChanged(QSize _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Dtk::Widget::DDialog::visibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
