/****************************************************************************
** Meta object code from reading C++ file 'danchors.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/danchors.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'danchors.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget12DAnchorsBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DAnchorsBase::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget12DAnchorsBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DAnchorsBase",
        "enabledChanged",
        "",
        "enabled",
        "topChanged",
        "const DAnchorInfo*",
        "top",
        "bottomChanged",
        "bottom",
        "leftChanged",
        "left",
        "rightChanged",
        "right",
        "horizontalCenterChanged",
        "horizontalCenter",
        "verticalCenterChanged",
        "verticalCenter",
        "fillChanged",
        "QWidget*",
        "fill",
        "centerInChanged",
        "centerIn",
        "marginsChanged",
        "margins",
        "topMarginChanged",
        "topMargin",
        "bottomMarginChanged",
        "bottomMargin",
        "leftMarginChanged",
        "leftMargin",
        "rightMarginChanged",
        "rightMargin",
        "horizontalCenterOffsetChanged",
        "horizontalCenterOffset",
        "verticalCenterOffsetChanged",
        "verticalCenterOffset",
        "alignWhenCenteredChanged",
        "alignWhenCentered",
        "setEnabled",
        "setAnchor",
        "Qt::AnchorPoint",
        "p",
        "target",
        "point",
        "setTop",
        "setBottom",
        "setLeft",
        "setRight",
        "setHorizontalCenter",
        "setVerticalCenter",
        "setFill",
        "setCenterIn",
        "DAnchorsBase*",
        "setMargins",
        "setTopMargin",
        "setBottomMargin",
        "setLeftMargin",
        "setRightMargin",
        "setHorizontalCenterOffset",
        "setVerticalCenterOffset",
        "setAlignWhenCentered",
        "arg",
        "moveTop",
        "moveBottom",
        "moveLeft",
        "moveRight",
        "moveHorizontalCenter",
        "moveVerticalCenter",
        "moveCenter",
        "QPoint",
        "updateVertical",
        "updateHorizontal",
        "updateFill",
        "updateCenterIn",
        "anchors",
        "const DAnchorsBase*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'topChanged'
        QtMocHelpers::SignalData<void(const DAnchorInfo *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'bottomChanged'
        QtMocHelpers::SignalData<void(const DAnchorInfo *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 },
        }}),
        // Signal 'leftChanged'
        QtMocHelpers::SignalData<void(const DAnchorInfo *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 10 },
        }}),
        // Signal 'rightChanged'
        QtMocHelpers::SignalData<void(const DAnchorInfo *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 12 },
        }}),
        // Signal 'horizontalCenterChanged'
        QtMocHelpers::SignalData<void(const DAnchorInfo *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 14 },
        }}),
        // Signal 'verticalCenterChanged'
        QtMocHelpers::SignalData<void(const DAnchorInfo *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 16 },
        }}),
        // Signal 'fillChanged'
        QtMocHelpers::SignalData<void(QWidget *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'centerInChanged'
        QtMocHelpers::SignalData<void(QWidget *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 21 },
        }}),
        // Signal 'marginsChanged'
        QtMocHelpers::SignalData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Signal 'topMarginChanged'
        QtMocHelpers::SignalData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Signal 'bottomMarginChanged'
        QtMocHelpers::SignalData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Signal 'leftMarginChanged'
        QtMocHelpers::SignalData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Signal 'rightMarginChanged'
        QtMocHelpers::SignalData<void(int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Signal 'horizontalCenterOffsetChanged'
        QtMocHelpers::SignalData<void(int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Signal 'verticalCenterOffsetChanged'
        QtMocHelpers::SignalData<void(int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Signal 'alignWhenCenteredChanged'
        QtMocHelpers::SignalData<void(bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'setEnabled'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'setAnchor'
        QtMocHelpers::SlotData<bool(const Qt::AnchorPoint &, QWidget *, const Qt::AnchorPoint &)>(39, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 40, 41 }, { 0x80000000 | 18, 42 }, { 0x80000000 | 40, 43 },
        }}),
        // Slot 'setTop'
        QtMocHelpers::SlotData<bool(const DAnchorInfo *)>(44, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setBottom'
        QtMocHelpers::SlotData<bool(const DAnchorInfo *)>(45, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 8 },
        }}),
        // Slot 'setLeft'
        QtMocHelpers::SlotData<bool(const DAnchorInfo *)>(46, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 10 },
        }}),
        // Slot 'setRight'
        QtMocHelpers::SlotData<bool(const DAnchorInfo *)>(47, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 12 },
        }}),
        // Slot 'setHorizontalCenter'
        QtMocHelpers::SlotData<bool(const DAnchorInfo *)>(48, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 14 },
        }}),
        // Slot 'setVerticalCenter'
        QtMocHelpers::SlotData<bool(const DAnchorInfo *)>(49, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 16 },
        }}),
        // Slot 'setFill'
        QtMocHelpers::SlotData<bool(QWidget *)>(50, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'setCenterIn'
        QtMocHelpers::SlotData<bool(QWidget *)>(51, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 18, 21 },
        }}),
        // Slot 'setFill'
        QtMocHelpers::SlotData<bool(DAnchorsBase *)>(50, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 52, 19 },
        }}),
        // Slot 'setCenterIn'
        QtMocHelpers::SlotData<bool(DAnchorsBase *)>(51, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 52, 21 },
        }}),
        // Slot 'setMargins'
        QtMocHelpers::SlotData<void(int)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'setTopMargin'
        QtMocHelpers::SlotData<void(int)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Slot 'setBottomMargin'
        QtMocHelpers::SlotData<void(int)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setLeftMargin'
        QtMocHelpers::SlotData<void(int)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'setRightMargin'
        QtMocHelpers::SlotData<void(int)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Slot 'setHorizontalCenterOffset'
        QtMocHelpers::SlotData<void(int)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'setVerticalCenterOffset'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Slot 'setAlignWhenCentered'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'setTop'
        QtMocHelpers::SlotData<void(int, Qt::AnchorPoint)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 }, { 0x80000000 | 40, 43 },
        }}),
        // Slot 'setBottom'
        QtMocHelpers::SlotData<void(int, Qt::AnchorPoint)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 }, { 0x80000000 | 40, 43 },
        }}),
        // Slot 'setLeft'
        QtMocHelpers::SlotData<void(int, Qt::AnchorPoint)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 }, { 0x80000000 | 40, 43 },
        }}),
        // Slot 'setRight'
        QtMocHelpers::SlotData<void(int, Qt::AnchorPoint)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 }, { 0x80000000 | 40, 43 },
        }}),
        // Slot 'setHorizontalCenter'
        QtMocHelpers::SlotData<void(int, Qt::AnchorPoint)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 }, { 0x80000000 | 40, 43 },
        }}),
        // Slot 'setVerticalCenter'
        QtMocHelpers::SlotData<void(int, Qt::AnchorPoint)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 }, { 0x80000000 | 40, 43 },
        }}),
        // Slot 'moveTop'
        QtMocHelpers::SlotData<void(int)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Slot 'moveBottom'
        QtMocHelpers::SlotData<void(int)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Slot 'moveLeft'
        QtMocHelpers::SlotData<void(int)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Slot 'moveRight'
        QtMocHelpers::SlotData<void(int)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Slot 'moveHorizontalCenter'
        QtMocHelpers::SlotData<void(int)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Slot 'moveVerticalCenter'
        QtMocHelpers::SlotData<void(int)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 61 },
        }}),
        // Slot 'moveCenter'
        QtMocHelpers::SlotData<void(const QPoint &)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 69, 61 },
        }}),
        // Slot 'updateVertical'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateHorizontal'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFill'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateCenterIn'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'target'
        QtMocHelpers::PropertyData<QWidget*>(42, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'anchors'
        QtMocHelpers::PropertyData<const DAnchorsBase*>(74, 0x80000000 | 75, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'top'
        QtMocHelpers::PropertyData<const DAnchorInfo*>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'bottom'
        QtMocHelpers::PropertyData<const DAnchorInfo*>(8, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'left'
        QtMocHelpers::PropertyData<const DAnchorInfo*>(10, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'right'
        QtMocHelpers::PropertyData<const DAnchorInfo*>(12, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'horizontalCenter'
        QtMocHelpers::PropertyData<const DAnchorInfo*>(14, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'verticalCenter'
        QtMocHelpers::PropertyData<const DAnchorInfo*>(16, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'fill'
        QtMocHelpers::PropertyData<QWidget*>(19, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'centerIn'
        QtMocHelpers::PropertyData<QWidget*>(21, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'margins'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'topMargin'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'bottomMargin'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'leftMargin'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'rightMargin'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'horizontalCenterOffset'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'verticalCenterOffset'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'alignWhenCentered'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DAnchorsBase, qt_meta_tag_ZN3Dtk6Widget12DAnchorsBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DAnchorsBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DAnchorsBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DAnchorsBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget12DAnchorsBaseE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DAnchorsBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DAnchorsBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->topChanged((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1]))); break;
        case 2: _t->bottomChanged((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1]))); break;
        case 3: _t->leftChanged((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1]))); break;
        case 4: _t->rightChanged((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1]))); break;
        case 5: _t->horizontalCenterChanged((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1]))); break;
        case 6: _t->verticalCenterChanged((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1]))); break;
        case 7: _t->fillChanged((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 8: _t->centerInChanged((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 9: _t->marginsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->topMarginChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->bottomMarginChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->leftMarginChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->rightMarginChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->horizontalCenterOffsetChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->verticalCenterOffsetChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->alignWhenCenteredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: { bool _r = _t->setAnchor((*reinterpret_cast<std::add_pointer_t<Qt::AnchorPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::AnchorPoint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->setTop((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->setBottom((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->setLeft((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->setRight((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->setHorizontalCenter((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->setVerticalCenter((*reinterpret_cast<std::add_pointer_t<const DAnchorInfo*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->setFill((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->setCenterIn((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->setFill((*reinterpret_cast<std::add_pointer_t<DAnchorsBase*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->setCenterIn((*reinterpret_cast<std::add_pointer_t<DAnchorsBase*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->setMargins((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->setTopMargin((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->setBottomMargin((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->setLeftMargin((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->setRightMargin((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->setHorizontalCenterOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->setVerticalCenterOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->setAlignWhenCentered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->setTop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::AnchorPoint>>(_a[2]))); break;
        case 38: _t->setBottom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::AnchorPoint>>(_a[2]))); break;
        case 39: _t->setLeft((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::AnchorPoint>>(_a[2]))); break;
        case 40: _t->setRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::AnchorPoint>>(_a[2]))); break;
        case 41: _t->setHorizontalCenter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::AnchorPoint>>(_a[2]))); break;
        case 42: _t->setVerticalCenter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::AnchorPoint>>(_a[2]))); break;
        case 43: _t->moveTop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->moveBottom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 45: _t->moveLeft((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 46: _t->moveRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->moveHorizontalCenter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->moveVerticalCenter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: _t->moveCenter((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 50: _t->updateVertical(); break;
        case 51: _t->updateHorizontal(); break;
        case 52: _t->updateFill(); break;
        case 53: _t->updateCenterIn(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DAnchorsBase* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DAnchorsBase* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(bool )>(_a, &DAnchorsBase::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(const DAnchorInfo * )>(_a, &DAnchorsBase::topChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(const DAnchorInfo * )>(_a, &DAnchorsBase::bottomChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(const DAnchorInfo * )>(_a, &DAnchorsBase::leftChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(const DAnchorInfo * )>(_a, &DAnchorsBase::rightChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(const DAnchorInfo * )>(_a, &DAnchorsBase::horizontalCenterChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(const DAnchorInfo * )>(_a, &DAnchorsBase::verticalCenterChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(QWidget * )>(_a, &DAnchorsBase::fillChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(QWidget * )>(_a, &DAnchorsBase::centerInChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(int )>(_a, &DAnchorsBase::marginsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(int )>(_a, &DAnchorsBase::topMarginChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(int )>(_a, &DAnchorsBase::bottomMarginChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(int )>(_a, &DAnchorsBase::leftMarginChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(int )>(_a, &DAnchorsBase::rightMarginChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(int )>(_a, &DAnchorsBase::horizontalCenterOffsetChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(int )>(_a, &DAnchorsBase::verticalCenterOffsetChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DAnchorsBase::*)(bool )>(_a, &DAnchorsBase::alignWhenCenteredChanged, 16))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
        case 9:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QWidget**>(_v) = _t->target(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 2: *reinterpret_cast<const DAnchorsBase**>(_v) = _t->anchors(); break;
        case 3: *reinterpret_cast<const DAnchorInfo**>(_v) = _t->top(); break;
        case 4: *reinterpret_cast<const DAnchorInfo**>(_v) = _t->bottom(); break;
        case 5: *reinterpret_cast<const DAnchorInfo**>(_v) = _t->left(); break;
        case 6: *reinterpret_cast<const DAnchorInfo**>(_v) = _t->right(); break;
        case 7: *reinterpret_cast<const DAnchorInfo**>(_v) = _t->horizontalCenter(); break;
        case 8: *reinterpret_cast<const DAnchorInfo**>(_v) = _t->verticalCenter(); break;
        case 9: *reinterpret_cast<QWidget**>(_v) = _t->fill(); break;
        case 10: *reinterpret_cast<QWidget**>(_v) = _t->centerIn(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->margins(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->topMargin(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->bottomMargin(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->leftMargin(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->rightMargin(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->horizontalCenterOffset(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->verticalCenterOffset(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->alignWhenCentered(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setTop(*reinterpret_cast<const DAnchorInfo**>(_v)); break;
        case 4: _t->setBottom(*reinterpret_cast<const DAnchorInfo**>(_v)); break;
        case 5: _t->setLeft(*reinterpret_cast<const DAnchorInfo**>(_v)); break;
        case 6: _t->setRight(*reinterpret_cast<const DAnchorInfo**>(_v)); break;
        case 7: _t->setHorizontalCenter(*reinterpret_cast<const DAnchorInfo**>(_v)); break;
        case 8: _t->setVerticalCenter(*reinterpret_cast<const DAnchorInfo**>(_v)); break;
        case 9: _t->setFill(*reinterpret_cast<QWidget**>(_v)); break;
        case 10: _t->setCenterIn(*reinterpret_cast<QWidget**>(_v)); break;
        case 11: _t->setMargins(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setTopMargin(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setBottomMargin(*reinterpret_cast<int*>(_v)); break;
        case 14: _t->setLeftMargin(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setRightMargin(*reinterpret_cast<int*>(_v)); break;
        case 16: _t->setHorizontalCenterOffset(*reinterpret_cast<int*>(_v)); break;
        case 17: _t->setVerticalCenterOffset(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setAlignWhenCentered(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DAnchorsBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DAnchorsBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget12DAnchorsBaseE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dtk::Widget::DAnchorsBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DAnchorsBase::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DAnchorsBase::topChanged(const DAnchorInfo * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Dtk::Widget::DAnchorsBase::bottomChanged(const DAnchorInfo * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Dtk::Widget::DAnchorsBase::leftChanged(const DAnchorInfo * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Dtk::Widget::DAnchorsBase::rightChanged(const DAnchorInfo * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Dtk::Widget::DAnchorsBase::horizontalCenterChanged(const DAnchorInfo * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Dtk::Widget::DAnchorsBase::verticalCenterChanged(const DAnchorInfo * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Dtk::Widget::DAnchorsBase::fillChanged(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Dtk::Widget::DAnchorsBase::centerInChanged(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Dtk::Widget::DAnchorsBase::marginsChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Dtk::Widget::DAnchorsBase::topMarginChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Dtk::Widget::DAnchorsBase::bottomMarginChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Dtk::Widget::DAnchorsBase::leftMarginChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Dtk::Widget::DAnchorsBase::rightMarginChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Dtk::Widget::DAnchorsBase::horizontalCenterOffsetChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Dtk::Widget::DAnchorsBase::verticalCenterOffsetChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Dtk::Widget::DAnchorsBase::alignWhenCenteredChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}
QT_WARNING_POP
