/****************************************************************************
** Meta object code from reading C++ file 'dloadingindicator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dloadingindicator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dloadingindicator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget17DLoadingIndicatorE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DLoadingIndicator::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget17DLoadingIndicatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DLoadingIndicator",
        "directionChanged",
        "",
        "RotationDirection",
        "direction",
        "rotateChanged",
        "rotate",
        "start",
        "stop",
        "setLoading",
        "flag",
        "setAniDuration",
        "msecs",
        "setAniEasingCurve",
        "QEasingCurve",
        "easing",
        "setBackgroundColor",
        "QColor",
        "color",
        "setRotate",
        "QVariant",
        "angle",
        "setWidgetSource",
        "QWidget*",
        "widgetSource",
        "setImageSource",
        "QPixmap",
        "imageSource",
        "setAniEasingType",
        "QEasingCurve::Type",
        "aniEasingType",
        "setSmooth",
        "smooth",
        "setDirection",
        "backgroundColor",
        "loading",
        "aniDuration",
        "Clockwise",
        "Counterclockwise"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'directionChanged'
        QtMocHelpers::SignalData<void(enum RotationDirection)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'rotateChanged'
        QtMocHelpers::SignalData<void(qreal)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 6 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setLoading'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'setAniDuration'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'setAniEasingCurve'
        QtMocHelpers::SlotData<void(const QEasingCurve &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setBackgroundColor'
        QtMocHelpers::SlotData<void(const QColor &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setRotate'
        QtMocHelpers::SlotData<void(QVariant)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setWidgetSource'
        QtMocHelpers::SlotData<void(QWidget *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'setImageSource'
        QtMocHelpers::SlotData<void(const QPixmap &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'setAniEasingType'
        QtMocHelpers::SlotData<void(QEasingCurve::Type)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'setSmooth'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'setDirection'
        QtMocHelpers::SlotData<void(enum RotationDirection)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(34, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'smooth'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'imageSource'
        QtMocHelpers::PropertyData<QPixmap>(27, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'widgetSource'
        QtMocHelpers::PropertyData<QWidget*>(24, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'aniDuration'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'aniEasingType'
        QtMocHelpers::PropertyData<QEasingCurve::Type>(30, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'direction'
        QtMocHelpers::PropertyData<enum RotationDirection>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'rotate'
        QtMocHelpers::PropertyData<qreal>(6, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'RotationDirection'
        QtMocHelpers::EnumData<enum RotationDirection>(3, 3, QMC::EnumFlags{}).add({
            {   37, RotationDirection::Clockwise },
            {   38, RotationDirection::Counterclockwise },
        }),
    };
    return QtMocHelpers::metaObjectData<DLoadingIndicator, qt_meta_tag_ZN3Dtk6Widget17DLoadingIndicatorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3Dtk6Widget17DLoadingIndicatorE[] = {
    QMetaObject::SuperData::link<QEasingCurve::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Dtk::Widget::DLoadingIndicator::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget17DLoadingIndicatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget17DLoadingIndicatorE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3Dtk6Widget17DLoadingIndicatorE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget17DLoadingIndicatorE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DLoadingIndicator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DLoadingIndicator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->directionChanged((*reinterpret_cast<std::add_pointer_t<enum RotationDirection>>(_a[1]))); break;
        case 1: _t->rotateChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 2: _t->start(); break;
        case 3: _t->stop(); break;
        case 4: _t->setLoading((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setAniDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setAniEasingCurve((*reinterpret_cast<std::add_pointer_t<QEasingCurve>>(_a[1]))); break;
        case 7: _t->setBackgroundColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 8: _t->setRotate((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 9: _t->setWidgetSource((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 10: _t->setImageSource((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1]))); break;
        case 11: _t->setAniEasingType((*reinterpret_cast<std::add_pointer_t<QEasingCurve::Type>>(_a[1]))); break;
        case 12: _t->setSmooth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setDirection((*reinterpret_cast<std::add_pointer_t<enum RotationDirection>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DLoadingIndicator::*)(RotationDirection )>(_a, &DLoadingIndicator::directionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DLoadingIndicator::*)(qreal )>(_a, &DLoadingIndicator::rotateChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->smooth(); break;
        case 3: *reinterpret_cast<QPixmap*>(_v) = _t->imageSource(); break;
        case 4: *reinterpret_cast<QWidget**>(_v) = _t->widgetSource(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->aniDuration(); break;
        case 6: *reinterpret_cast<QEasingCurve::Type*>(_v) = _t->aniEasingType(); break;
        case 7: *reinterpret_cast<enum RotationDirection*>(_v) = _t->direction(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->rotate(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 1: _t->setLoading(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setSmooth(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setImageSource(*reinterpret_cast<QPixmap*>(_v)); break;
        case 4: _t->setWidgetSource(*reinterpret_cast<QWidget**>(_v)); break;
        case 5: _t->setAniDuration(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setAniEasingType(*reinterpret_cast<QEasingCurve::Type*>(_v)); break;
        case 7: _t->setDirection(*reinterpret_cast<enum RotationDirection*>(_v)); break;
        case 8: _t->setRotate(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DLoadingIndicator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DLoadingIndicator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget17DLoadingIndicatorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int Dtk::Widget::DLoadingIndicator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DLoadingIndicator::directionChanged(RotationDirection _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Dtk::Widget::DLoadingIndicator::rotateChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
