/****************************************************************************
** Meta object code from reading C++ file 'listviewexample.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../examples/collections/listviewexample.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'listviewexample.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ListViewExampleWindow_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ListViewExampleWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ListViewExampleWindow_t qt_meta_stringdata_ListViewExampleWindow = {
    {
QT_MOC_LITERAL(0, 0, 21) // "ListViewExampleWindow"

    },
    "ListViewExampleWindow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ListViewExampleWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ListViewExampleWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ListViewExampleWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<PageWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_ListViewExampleWindow.data,
    qt_meta_data_ListViewExampleWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ListViewExampleWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ListViewExampleWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ListViewExampleWindow.stringdata0))
        return static_cast<void*>(this);
    return PageWindowInterface::qt_metacast(_clname);
}

int ListViewExampleWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PageWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DBackgroundGroupExample_t {
    QByteArrayData data[1];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DBackgroundGroupExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DBackgroundGroupExample_t qt_meta_stringdata_DBackgroundGroupExample = {
    {
QT_MOC_LITERAL(0, 0, 23) // "DBackgroundGroupExample"

    },
    "DBackgroundGroupExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DBackgroundGroupExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DBackgroundGroupExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DBackgroundGroupExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DBackgroundGroupExample.data,
    qt_meta_data_DBackgroundGroupExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DBackgroundGroupExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBackgroundGroupExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DBackgroundGroupExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DBackgroundGroupExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DListViewExample_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DListViewExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DListViewExample_t qt_meta_stringdata_DListViewExample = {
    {
QT_MOC_LITERAL(0, 0, 16) // "DListViewExample"

    },
    "DListViewExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DListViewExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DListViewExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DListViewExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DListViewExample.data,
    qt_meta_data_DListViewExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DListViewExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DListViewExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DListViewExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DListViewExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DGroupBoxExample_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DGroupBoxExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DGroupBoxExample_t qt_meta_stringdata_DGroupBoxExample = {
    {
QT_MOC_LITERAL(0, 0, 16) // "DGroupBoxExample"

    },
    "DGroupBoxExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DGroupBoxExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DGroupBoxExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DGroupBoxExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DGroupBoxExample.data,
    qt_meta_data_DGroupBoxExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DGroupBoxExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DGroupBoxExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DGroupBoxExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DGroupBoxExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DTreeViewExample_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DTreeViewExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DTreeViewExample_t qt_meta_stringdata_DTreeViewExample = {
    {
QT_MOC_LITERAL(0, 0, 16) // "DTreeViewExample"

    },
    "DTreeViewExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DTreeViewExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DTreeViewExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DTreeViewExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DTreeViewExample.data,
    qt_meta_data_DTreeViewExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DTreeViewExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DTreeViewExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DTreeViewExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DTreeViewExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DHeaderViewExample_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DHeaderViewExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DHeaderViewExample_t qt_meta_stringdata_DHeaderViewExample = {
    {
QT_MOC_LITERAL(0, 0, 18) // "DHeaderViewExample"

    },
    "DHeaderViewExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DHeaderViewExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DHeaderViewExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DHeaderViewExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DHeaderViewExample.data,
    qt_meta_data_DHeaderViewExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DHeaderViewExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DHeaderViewExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DHeaderViewExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DHeaderViewExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DColumnViewExample_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DColumnViewExample_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DColumnViewExample_t qt_meta_stringdata_DColumnViewExample = {
    {
QT_MOC_LITERAL(0, 0, 18) // "DColumnViewExample"

    },
    "DColumnViewExample"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DColumnViewExample[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DColumnViewExample::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DColumnViewExample::staticMetaObject = { {
    QMetaObject::SuperData::link<ExampleWindowInterface::staticMetaObject>(),
    qt_meta_stringdata_DColumnViewExample.data,
    qt_meta_data_DColumnViewExample,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DColumnViewExample::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DColumnViewExample::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DColumnViewExample.stringdata0))
        return static_cast<void*>(this);
    return ExampleWindowInterface::qt_metacast(_clname);
}

int DColumnViewExample::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ExampleWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
