/****************************************************************************
** Meta object code from reading C++ file 'dmainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../include/widgets/dmainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dmainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk6Widget11DMainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Widget::DMainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk6Widget11DMainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Widget::DMainWindow",
        "windowRadiusChanged",
        "",
        "borderWidthChanged",
        "borderColorChanged",
        "shadowRadiusChanged",
        "shadowOffsetChanged",
        "shadowColorChanged",
        "clipPathChanged",
        "frameMaskChanged",
        "frameMarginsChanged",
        "translucentBackgroundChanged",
        "enableSystemResizeChanged",
        "enableSystemMoveChanged",
        "enableBlurWindowChanged",
        "autoInputMaskByClipPathChanged",
        "sidebarVisbleChanged",
        "visible",
        "sidebarExpanedChanged",
        "expaned",
        "setWindowRadius",
        "windowRadius",
        "setBorderWidth",
        "borderWidth",
        "setBorderColor",
        "QColor",
        "borderColor",
        "setShadowRadius",
        "shadowRadius",
        "setShadowOffset",
        "QPoint",
        "shadowOffset",
        "setShadowColor",
        "shadowColor",
        "setClipPath",
        "QPainterPath",
        "clipPath",
        "setFrameMask",
        "QRegion",
        "frameMask",
        "setTranslucentBackground",
        "translucentBackground",
        "setEnableSystemResize",
        "enableSystemResize",
        "setEnableSystemMove",
        "enableSystemMove",
        "setEnableBlurWindow",
        "enableBlurWindow",
        "setAutoInputMaskByClipPath",
        "autoInputMaskByClipPath",
        "sendMessage",
        "QIcon",
        "icon",
        "message",
        "DFloatingMessage*",
        "setTitlebarShadowEnabled",
        "titlebarShadowEnabled",
        "_q_autoShowFeatureDialog",
        "frameMargins",
        "QMargins"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'windowRadiusChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderWidthChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderColorChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowRadiusChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowOffsetChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowColorChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipPathChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameMaskChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameMarginsChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'translucentBackgroundChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableSystemResizeChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableSystemMoveChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableBlurWindowChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoInputMaskByClipPathChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidebarVisbleChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'sidebarExpanedChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'setWindowRadius'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'setBorderWidth'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'setBorderColor'
        QtMocHelpers::SlotData<void(const QColor &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'setShadowRadius'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setShadowOffset'
        QtMocHelpers::SlotData<void(const QPoint &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setShadowColor'
        QtMocHelpers::SlotData<void(const QColor &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 33 },
        }}),
        // Slot 'setClipPath'
        QtMocHelpers::SlotData<void(const QPainterPath &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'setFrameMask'
        QtMocHelpers::SlotData<void(const QRegion &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'setTranslucentBackground'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'setEnableSystemResize'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'setEnableSystemMove'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'setEnableBlurWindow'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
        // Slot 'setAutoInputMaskByClipPath'
        QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 49 },
        }}),
        // Slot 'sendMessage'
        QtMocHelpers::SlotData<void(const QIcon &, const QString &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 }, { QMetaType::QString, 53 },
        }}),
        // Slot 'sendMessage'
        QtMocHelpers::SlotData<void(DFloatingMessage *)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 53 },
        }}),
        // Slot 'setTitlebarShadowEnabled'
        QtMocHelpers::SlotData<void(bool)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 56 },
        }}),
        // Slot '_q_autoShowFeatureDialog'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'windowRadius'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'borderWidth'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'borderColor'
        QtMocHelpers::PropertyData<QColor>(26, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'shadowRadius'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'shadowOffset'
        QtMocHelpers::PropertyData<QPoint>(31, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'shadowColor'
        QtMocHelpers::PropertyData<QColor>(33, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'clipPath'
        QtMocHelpers::PropertyData<QPainterPath>(36, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'frameMask'
        QtMocHelpers::PropertyData<QRegion>(39, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'frameMargins'
        QtMocHelpers::PropertyData<QMargins>(58, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'translucentBackground'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'enableSystemResize'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'enableSystemMove'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'enableBlurWindow'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'autoInputMaskByClipPath'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'titlebarShadowEnabled'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DMainWindow, qt_meta_tag_ZN3Dtk6Widget11DMainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dtk::Widget::DMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DMainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DMainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk6Widget11DMainWindowE_t>.metaTypes,
    nullptr
} };

void Dtk::Widget::DMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DMainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->windowRadiusChanged(); break;
        case 1: _t->borderWidthChanged(); break;
        case 2: _t->borderColorChanged(); break;
        case 3: _t->shadowRadiusChanged(); break;
        case 4: _t->shadowOffsetChanged(); break;
        case 5: _t->shadowColorChanged(); break;
        case 6: _t->clipPathChanged(); break;
        case 7: _t->frameMaskChanged(); break;
        case 8: _t->frameMarginsChanged(); break;
        case 9: _t->translucentBackgroundChanged(); break;
        case 10: _t->enableSystemResizeChanged(); break;
        case 11: _t->enableSystemMoveChanged(); break;
        case 12: _t->enableBlurWindowChanged(); break;
        case 13: _t->autoInputMaskByClipPathChanged(); break;
        case 14: _t->sidebarVisbleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->sidebarExpanedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->setWindowRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setBorderWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setBorderColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 19: _t->setShadowRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setShadowOffset((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 21: _t->setShadowColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 22: _t->setClipPath((*reinterpret_cast<std::add_pointer_t<QPainterPath>>(_a[1]))); break;
        case 23: _t->setFrameMask((*reinterpret_cast<std::add_pointer_t<QRegion>>(_a[1]))); break;
        case 24: _t->setTranslucentBackground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setEnableSystemResize((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->setEnableSystemMove((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->setEnableBlurWindow((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->setAutoInputMaskByClipPath((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: _t->sendMessage((*reinterpret_cast<std::add_pointer_t<DFloatingMessage*>>(_a[1]))); break;
        case 31: _t->setTitlebarShadowEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->d_func()->_q_autoShowFeatureDialog(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DFloatingMessage* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::windowRadiusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::borderWidthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::borderColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::shadowRadiusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::shadowOffsetChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::shadowColorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::clipPathChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::frameMaskChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::frameMarginsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::translucentBackgroundChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::enableSystemResizeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::enableSystemMoveChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::enableBlurWindowChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)()>(_a, &DMainWindow::autoInputMaskByClipPathChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)(bool )>(_a, &DMainWindow::sidebarVisbleChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DMainWindow::*)(bool )>(_a, &DMainWindow::sidebarExpanedChanged, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->windowRadius(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->borderWidth(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->borderColor(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->shadowRadius(); break;
        case 4: *reinterpret_cast<QPoint*>(_v) = _t->shadowOffset(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->shadowColor(); break;
        case 6: *reinterpret_cast<QPainterPath*>(_v) = _t->clipPath(); break;
        case 7: *reinterpret_cast<QRegion*>(_v) = _t->frameMask(); break;
        case 8: *reinterpret_cast<QMargins*>(_v) = _t->frameMargins(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->translucentBackground(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->enableSystemResize(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->enableSystemMove(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->enableBlurWindow(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->autoInputMaskByClipPath(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->titlebarShadowIsEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWindowRadius(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setBorderWidth(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setBorderColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setShadowRadius(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setShadowOffset(*reinterpret_cast<QPoint*>(_v)); break;
        case 5: _t->setShadowColor(*reinterpret_cast<QColor*>(_v)); break;
        case 6: _t->setClipPath(*reinterpret_cast<QPainterPath*>(_v)); break;
        case 7: _t->setFrameMask(*reinterpret_cast<QRegion*>(_v)); break;
        case 9: _t->setTranslucentBackground(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setEnableSystemResize(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setEnableSystemMove(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setEnableBlurWindow(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setAutoInputMaskByClipPath(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setTitlebarShadowEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Widget::DMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk6Widget11DMainWindowE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int Dtk::Widget::DMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DMainWindow::windowRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Widget::DMainWindow::borderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Widget::DMainWindow::borderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Widget::DMainWindow::shadowRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Widget::DMainWindow::shadowOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Widget::DMainWindow::shadowColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Widget::DMainWindow::clipPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Widget::DMainWindow::frameMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Widget::DMainWindow::frameMarginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dtk::Widget::DMainWindow::translucentBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Dtk::Widget::DMainWindow::enableSystemResizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Dtk::Widget::DMainWindow::enableSystemMoveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Dtk::Widget::DMainWindow::enableBlurWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Dtk::Widget::DMainWindow::autoInputMaskByClipPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Dtk::Widget::DMainWindow::sidebarVisbleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Dtk::Widget::DMainWindow::sidebarExpanedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}
QT_WARNING_POP
