/****************************************************************************
** Meta object code from reading C++ file 'dloadingindicator.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../include/widgets/dloadingindicator.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dloadingindicator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Widget__DLoadingIndicator_t {
    QByteArrayData data[36];
    char stringdata0[433];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Widget__DLoadingIndicator_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Widget__DLoadingIndicator_t qt_meta_stringdata_Dtk__Widget__DLoadingIndicator = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Dtk::Widget::DLoadingIndicator"
QT_MOC_LITERAL(1, 31, 16), // "directionChanged"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 17), // "RotationDirection"
QT_MOC_LITERAL(4, 67, 9), // "direction"
QT_MOC_LITERAL(5, 77, 13), // "rotateChanged"
QT_MOC_LITERAL(6, 91, 6), // "rotate"
QT_MOC_LITERAL(7, 98, 5), // "start"
QT_MOC_LITERAL(8, 104, 4), // "stop"
QT_MOC_LITERAL(9, 109, 10), // "setLoading"
QT_MOC_LITERAL(10, 120, 4), // "flag"
QT_MOC_LITERAL(11, 125, 14), // "setAniDuration"
QT_MOC_LITERAL(12, 140, 5), // "msecs"
QT_MOC_LITERAL(13, 146, 17), // "setAniEasingCurve"
QT_MOC_LITERAL(14, 164, 12), // "QEasingCurve"
QT_MOC_LITERAL(15, 177, 6), // "easing"
QT_MOC_LITERAL(16, 184, 18), // "setBackgroundColor"
QT_MOC_LITERAL(17, 203, 5), // "color"
QT_MOC_LITERAL(18, 209, 9), // "setRotate"
QT_MOC_LITERAL(19, 219, 5), // "angle"
QT_MOC_LITERAL(20, 225, 15), // "setWidgetSource"
QT_MOC_LITERAL(21, 241, 8), // "QWidget*"
QT_MOC_LITERAL(22, 250, 12), // "widgetSource"
QT_MOC_LITERAL(23, 263, 14), // "setImageSource"
QT_MOC_LITERAL(24, 278, 11), // "imageSource"
QT_MOC_LITERAL(25, 290, 16), // "setAniEasingType"
QT_MOC_LITERAL(26, 307, 18), // "QEasingCurve::Type"
QT_MOC_LITERAL(27, 326, 13), // "aniEasingType"
QT_MOC_LITERAL(28, 340, 9), // "setSmooth"
QT_MOC_LITERAL(29, 350, 6), // "smooth"
QT_MOC_LITERAL(30, 357, 12), // "setDirection"
QT_MOC_LITERAL(31, 370, 15), // "backgroundColor"
QT_MOC_LITERAL(32, 386, 7), // "loading"
QT_MOC_LITERAL(33, 394, 11), // "aniDuration"
QT_MOC_LITERAL(34, 406, 9), // "Clockwise"
QT_MOC_LITERAL(35, 416, 16) // "Counterclockwise"

    },
    "Dtk::Widget::DLoadingIndicator\0"
    "directionChanged\0\0RotationDirection\0"
    "direction\0rotateChanged\0rotate\0start\0"
    "stop\0setLoading\0flag\0setAniDuration\0"
    "msecs\0setAniEasingCurve\0QEasingCurve\0"
    "easing\0setBackgroundColor\0color\0"
    "setRotate\0angle\0setWidgetSource\0"
    "QWidget*\0widgetSource\0setImageSource\0"
    "imageSource\0setAniEasingType\0"
    "QEasingCurve::Type\0aniEasingType\0"
    "setSmooth\0smooth\0setDirection\0"
    "backgroundColor\0loading\0aniDuration\0"
    "Clockwise\0Counterclockwise"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Widget__DLoadingIndicator[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       9,  122, // properties
       1,  158, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       5,    1,   87,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   90,    2, 0x0a /* Public */,
       8,    0,   91,    2, 0x0a /* Public */,
       9,    1,   92,    2, 0x0a /* Public */,
      11,    1,   95,    2, 0x0a /* Public */,
      13,    1,   98,    2, 0x0a /* Public */,
      16,    1,  101,    2, 0x0a /* Public */,
      18,    1,  104,    2, 0x0a /* Public */,
      20,    1,  107,    2, 0x0a /* Public */,
      23,    1,  110,    2, 0x0a /* Public */,
      25,    1,  113,    2, 0x0a /* Public */,
      28,    1,  116,    2, 0x0a /* Public */,
      30,    1,  119,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QReal,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, QMetaType::QColor,   17,
    QMetaType::Void, QMetaType::QVariant,   19,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void, QMetaType::QPixmap,   24,
    QMetaType::Void, 0x80000000 | 26,   27,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void, 0x80000000 | 3,    4,

 // properties: name, type, flags
      31, QMetaType::QColor, 0x00095103,
      32, QMetaType::Bool, 0x00095103,
      29, QMetaType::Bool, 0x00095103,
      24, QMetaType::QPixmap, 0x00095103,
      22, 0x80000000 | 21, 0x0009510b,
      33, QMetaType::Int, 0x00095103,
      27, 0x80000000 | 26, 0x0009510b,
       4, 0x80000000 | 3, 0x0049510b,
       6, QMetaType::QReal, 0x00495103,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       1,

 // enums: name, alias, flags, count, data
       3,    3, 0x0,    2,  163,

 // enum data: key, value
      34, uint(Dtk::Widget::DLoadingIndicator::Clockwise),
      35, uint(Dtk::Widget::DLoadingIndicator::Counterclockwise),

       0        // eod
};

void Dtk::Widget::DLoadingIndicator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DLoadingIndicator *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->directionChanged((*reinterpret_cast< RotationDirection(*)>(_a[1]))); break;
        case 1: _t->rotateChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 2: _t->start(); break;
        case 3: _t->stop(); break;
        case 4: _t->setLoading((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->setAniDuration((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->setAniEasingCurve((*reinterpret_cast< const QEasingCurve(*)>(_a[1]))); break;
        case 7: _t->setBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 8: _t->setRotate((*reinterpret_cast< QVariant(*)>(_a[1]))); break;
        case 9: _t->setWidgetSource((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 10: _t->setImageSource((*reinterpret_cast< const QPixmap(*)>(_a[1]))); break;
        case 11: _t->setAniEasingType((*reinterpret_cast< QEasingCurve::Type(*)>(_a[1]))); break;
        case 12: _t->setSmooth((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->setDirection((*reinterpret_cast< RotationDirection(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DLoadingIndicator::*)(RotationDirection );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DLoadingIndicator::directionChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DLoadingIndicator::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DLoadingIndicator::rotateChanged)) {
                *result = 1;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DLoadingIndicator *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QColor*>(_v) = _t->backgroundColor(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->loading(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->smooth(); break;
        case 3: *reinterpret_cast< QPixmap*>(_v) = _t->imageSource(); break;
        case 4: *reinterpret_cast< QWidget**>(_v) = _t->widgetSource(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->aniDuration(); break;
        case 6: *reinterpret_cast< QEasingCurve::Type*>(_v) = _t->aniEasingType(); break;
        case 7: *reinterpret_cast< RotationDirection*>(_v) = _t->direction(); break;
        case 8: *reinterpret_cast< qreal*>(_v) = _t->rotate(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DLoadingIndicator *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 1: _t->setLoading(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setSmooth(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setImageSource(*reinterpret_cast< QPixmap*>(_v)); break;
        case 4: _t->setWidgetSource(*reinterpret_cast< QWidget**>(_v)); break;
        case 5: _t->setAniDuration(*reinterpret_cast< int*>(_v)); break;
        case 6: _t->setAniEasingType(*reinterpret_cast< QEasingCurve::Type*>(_v)); break;
        case 7: _t->setDirection(*reinterpret_cast< RotationDirection*>(_v)); break;
        case 8: _t->setRotate(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_Dtk__Widget__DLoadingIndicator[] = {
    QMetaObject::SuperData::link<QEasingCurve::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Dtk::Widget::DLoadingIndicator::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Widget__DLoadingIndicator.data,
    qt_meta_data_Dtk__Widget__DLoadingIndicator,
    qt_static_metacall,
    qt_meta_extradata_Dtk__Widget__DLoadingIndicator,
    nullptr
} };


const QMetaObject *Dtk::Widget::DLoadingIndicator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Widget::DLoadingIndicator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Widget__DLoadingIndicator.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int Dtk::Widget::DLoadingIndicator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Widget::DLoadingIndicator::directionChanged(RotationDirection _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Dtk::Widget::DLoadingIndicator::rotateChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
